diff --git a/books/tangle.lisp b/books/tangle.lisp
index ec108f4..a51d914 100644
--- a/books/tangle.lisp
+++ b/books/tangle.lisp
@@ -447,6 +447,30 @@
   (allchunks PAT (concatenate 'string BOOKS "/bookvol10.4.pamphlet") HELP t)
   (allchunks PAT (concatenate 'string BOOKS "/bookvol10.5.pamphlet") HELP t)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;; 13 makeInputFiles
+;;;
+;;; The makeInputFiles function creates all of the input files in a single
+;;; pass over the file. The usual method of extracting each individual
+;;; input file requires hundreds of passes over the file.
+;;;
+;;; An example call is:
+;;;
+;;; (makeInputFiles)
+;;;
+;;; This will find all of the .input chunks in the books
+;;; and write each chunk to the target directory in its own filename.
+;;; So if a chunk name is <<somedomain.input>> the above call will create
+;;; the file "/tmp/help/somedomain.input" containing the chunk value.
+
+(defun makeInputFiles ()
+ (let ((SPD (si::getenv "SPD")) (BOOKS (si::getenv "BOOKS")) INPUT PAT)
+  (setq INPUT (concatenate 'string SPD "/int/input"))
+  (setq PAT ".input>>")
+  (allchunks PAT (concatenate 'string BOOKS "/bookvol10.2.pamphlet") INPUT t)
+  (allchunks PAT (concatenate 'string BOOKS "/bookvol10.3.pamphlet") INPUT t)
+  (allchunks PAT (concatenate 'string BOOKS "/bookvol10.4.pamphlet") INPUT t)
+  (allchunks PAT (concatenate 'string BOOKS "/bookvol10.5.pamphlet") INPUT t)))
 
 
 
diff --git a/changelog b/changelog
index 923d11c..b68ca45 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,6 @@
+20101024 tpd src/axiom-website/patches.html 20101024.04.tpd.patch
+20101024 tpd src/algebra/Makefile automate making input files
+20101024 tpd books/tangle.lisp automate making input files
 20101024 tpd src/axiom-website/patches.html 20101024.03.tpd.patch
 20101024 tpd Makefile.pamphlet automate making help files
 20101024 tpd Makefile automate making help files
diff --git a/src/algebra/Makefile.pamphlet b/src/algebra/Makefile.pamphlet
index 6fa2199..e84da92 100644
--- a/src/algebra/Makefile.pamphlet
+++ b/src/algebra/Makefile.pamphlet
@@ -16637,9 +16637,6 @@ The [[OUTSRC=${MNT}/${SYS}/src/algebra]] subdirectory contains the
 algebra source files extracted from the pamphlet files. These sources 
 allow the end user to change the algebra if needed.
 
-The HELP variable points to the location of the files used for the
-[[)help]] system command. These are flat files used to provide command
-line help to Axiom. They are extracted from the algebra pamphlets.
 <<environment>>=
 
 IN=${SRC}/algebra
@@ -16648,7 +16645,6 @@ OUT=${MNT}/${SYS}/algebra
 DOC=${MNT}/${SYS}/doc/src/algebra
 OUTSRC=${MNT}/${SYS}/src/algebra
 INPUT=${INT}/input
-HELP=${MNT}/${SYS}/doc/spadhelp
 LISP=${OBJ}/${SYS}/bin/lisp
 BOOKSRC=${SPD}/books/bookvol5.pamphlet
 
@@ -17173,94 +17169,7 @@ layer24done:
 	@ echo ==================================
 
 @
-\section{help command documentation}
-Axiom supports a )help command that takes a single argument.
-This argument is interpreted as the name of a flat ascii file
-which should live in \$AXIOM/doc/src/spadhelp.
-
-To add a new syntax help file, add the name of the chunk to this list
-and add the appropriate chunk to book volume 5.
-
-<<environment>>=
-
-SYNTAXHELP=\
-abbreviations.help assignment.help blocks.help   boot.help      \
-browse.help        cd.help         clear.help    clef.help      \
-close.help         collection.help compile.help  copyright.help \
-display.help       describe.help   edit.help     fin.help       \
-for.help           frame.help      help.help     history.help   \
-if.help            include.help    iterate.help  leave.help     \
-library.help       lisp.help       load.help     ltrace.help    \
-parallel.help      pquit.help      quit.help     read.help      \
-repeat.help        savesystem.help set.help      show.help      \
-spool.help         suchthat.help   summary.help  synonym.help   \
-syntax.help        system.help     trace.help    undo.help      \
-what.help          while.help      with.help
-
-@
-\subsection{help documentation for algebra}
-The help documentation for algebra files lives within the algebra
-pamphlet. The help chunk contains the name of the domain, thus:
-
-\begin{verbatim}
-<<thisdomain.help>>=
-====================================================================
-thisdomain examples
-====================================================================
-
-   (documentation for this domain)
-
-  examplefunction foo
-   output
-                Type: thetype
-
-See Also:
-o )show thisdomain
-o $AXIOM/bin/src/doc/algebra/thisfile.spad.dvi
-
-@
-\end{verbatim}
-
-The documentation starts off with the domain enclosed in two lines
-of equal signs. The documentation is free format. Generally the
-functions are indented two spaces, the output is indented 3 spaces,
-and the Type field has been moved toward the center of the line.
-
-The ``See Also:'' section lists the domain with the ``show'' command
-and the path to the source file in dvi format.
-
-\subsection{adding help documentation in Makefile}
-
-There is a section in the src/algebra/Makefile.pamphlet that reads:
-\begin{verbatim}
-SPADHELP=\
- ${HELP}/AssociationList.help  ${HELP}/BalancedBinaryTree.help \
-\end{verbatim}
-which is essentially a list of all of the algebra help files. Each item
-in this list refers to a stanza that looks like:
-
-\begin{verbatim}
-${HELP}/AssociationList.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7000 create AssociationList.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AssociationList.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/AssociationList.help
-	@cp ${HELP}/AssociationList.help ${HELP}/ALIST.help
-	@${TANGLE} -R"AssociationList.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AssociationList.input
-\end{verbatim}
-
-Notice that the first line has an connection between the help file and 
-the spad file that contains it. The second line gives debugging output
-containing a unique number. The third line extracts the help file. The
-fourth line copies the file with the long name of the domain to a file
-with the abbreviation of the domain so the user can query the domain
-with either form.
-
-\subsection{Using help documentation for regression testing}
-
-The last line extracts an input test file for the algebra. In general
-each help file is used to create an input test file for regression testing.
+\subsection{Regression testing}
 
 There is a Makefile variable called REGRESS in the algebra Makefile:
 \begin{verbatim}
@@ -17300,698 +17209,6 @@ make to process this file.
 
 This keeps the regression test list in the algebra Makefile.
 
-<<environment>>=
-HELPFILE=${HELP}/help.help
-
-SPADHELP=\
- ${HELP}/AbelianGroup.help \
- ${HELP}/AbelianMonoid.help \
- ${HELP}/AbelianMonoidRing.help \
- ${HELP}/AbelianSemiGroup.help \
- ${HELP}/AffineAlgebraicSetComputeWithGroebnerBasis.help \
- ${HELP}/AffineAlgebraicSetComputeWithResultant.help \
- ${HELP}/AffinePlane.help \
- ${HELP}/AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.help \
- ${HELP}/AffineSpace.help \
- ${HELP}/AffineSpaceCategory.help \
- ${HELP}/Aggregate.help \
- ${HELP}/Algebra.help \
- ${HELP}/AlgebraGivenByStructuralConstants.help \
- ${HELP}/AlgebraicallyClosedField.help \
- ${HELP}/AlgebraicallyClosedFunctionSpace.help \
- ${HELP}/AlgebraicFunctionField.help \
- ${HELP}/AlgebraicNumber.help \
- ${HELP}/AnonymousFunction.help \
- ${HELP}/AntiSymm.help \
- ${HELP}/Any.help \
- ${HELP}/ApplicationProgramInterface.help \
- ${HELP}/ArcHyperbolicFunctionCategory.help \
- ${HELP}/ArcTrigonometricFunctionCategory.help \
- ${HELP}/ArrayStack.help \
- ${HELP}/Asp1.help \
- ${HELP}/Asp10.help \
- ${HELP}/Asp12.help \
- ${HELP}/Asp19.help \
- ${HELP}/Asp20.help \
- ${HELP}/Asp24.help \
- ${HELP}/Asp27.help \
- ${HELP}/Asp28.help \
- ${HELP}/Asp29.help \
- ${HELP}/Asp30.help \
- ${HELP}/Asp31.help \
- ${HELP}/Asp33.help \
- ${HELP}/Asp34.help \
- ${HELP}/Asp35.help \
- ${HELP}/Asp4.help \
- ${HELP}/Asp41.help \
- ${HELP}/Asp42.help \
- ${HELP}/Asp49.help \
- ${HELP}/Asp50.help \
- ${HELP}/Asp55.help \
- ${HELP}/Asp6.help \
- ${HELP}/Asp7.help \
- ${HELP}/Asp73.help \
- ${HELP}/Asp74.help \
- ${HELP}/Asp77.help \
- ${HELP}/Asp78.help \
- ${HELP}/Asp8.help \
- ${HELP}/Asp80.help \
- ${HELP}/Asp9.help \
- ${HELP}/AssociatedJordanAlgebra.help \
- ${HELP}/AssociatedLieAlgebra.help \
- ${HELP}/AssociationList.help \
- ${HELP}/AssociationListAggregate.help \
- ${HELP}/AttributeButtons.help \
- ${HELP}/Automorphism.help \
- ${HELP}/BalancedBinaryTree.help \
- ${HELP}/BalancedPAdicInteger.help \
- ${HELP}/BalancedPAdicRational.help \
- ${HELP}/BagAggregate.help \
- ${HELP}/BasicFunctions.help \
- ${HELP}/BasicOperator.help \
- ${HELP}/BasicType.help \
- ${HELP}/Bezier.help \
- ${HELP}/BiModule.help \
- ${HELP}/BinaryExpansion.help \
- ${HELP}/BinaryFile.help \
- ${HELP}/BinaryRecursiveAggregate.help \
- ${HELP}/BinarySearchTree.help \
- ${HELP}/BinaryTournament.help \
- ${HELP}/BinaryTree.help \
- ${HELP}/BinaryTreeCategory.help \
- ${HELP}/BitAggregate.help \
- ${HELP}/Bits.help \
- ${HELP}/BlasLevelOne.help \
- ${HELP}/BlowUpMethodCategory.help \
- ${HELP}/BlowUpPackage.help \
- ${HELP}/BlowUpWithHamburgerNoether.help \
- ${HELP}/BlowUpWithQuadTrans.help \
- ${HELP}/Boolean.help \
- ${HELP}/CachableSet.help \
- ${HELP}/CancellationAbelianMonoid.help \
- ${HELP}/CardinalNumber.help \
- ${HELP}/CartesianTensor.help \
- ${HELP}/Character.help \
- ${HELP}/CharacterClass.help \
- ${HELP}/CharacteristicNonZero.help \
- ${HELP}/CharacteristicZero.help \
- ${HELP}/CliffordAlgebra.help \
- ${HELP}/CoercibleTo.help \
- ${HELP}/Collection.help \
- ${HELP}/Color.help \
- ${HELP}/CombinatorialFunction.help \
- ${HELP}/CombinatorialFunctionCategory.help \
- ${HELP}/CombinatorialOpsCategory.help \
- ${HELP}/CommutativeRing.help \
- ${HELP}/Commutator.help \
- ${HELP}/Complex.help \
- ${HELP}/ComplexCategory.help \
- ${HELP}/ComplexDoubleFloatMatrix.help \
- ${HELP}/ComplexDoubleFloatVector.help \
- ${HELP}/ContinuedFraction.help \
- ${HELP}/ConvertibleTo.help \
- ${HELP}/CycleIndicators.help \
- ${HELP}/Database.help \
- ${HELP}/DataList.help \
- ${HELP}/DecimalExpansion.help \
- ${HELP}/Dequeue.help \
- ${HELP}/DequeueAggregate.help \
- ${HELP}/DeRhamComplex.help \
- ${HELP}/DesingTree.help \
- ${HELP}/DesingTreeCategory.help \
- ${HELP}/DesingTreePackage.help \
- ${HELP}/Dictionary.help \
- ${HELP}/DictionaryOperations.help \
- ${HELP}/DifferentialExtension.help \
- ${HELP}/DifferentialPolynomialCategory.help \
- ${HELP}/DifferentialRing.help \
- ${HELP}/DifferentialSparseMultivariatePolynomial.help \
- ${HELP}/DifferentialVariableCategory.help \
- ${HELP}/DirectProduct.help \
- ${HELP}/DirectProductCategory.help \
- ${HELP}/DirectProductMatrixModule.help \
- ${HELP}/DirectProductModule.help \
- ${HELP}/DirichletRing.help \
- ${HELP}/DistributedMultivariatePolynomial.help \
- ${HELP}/DivisionRing.help \
- ${HELP}/Divisor.help \
- ${HELP}/DivisorCategory.help \
- ${HELP}/DoubleFloat.help \
- ${HELP}/DoubleFloatMatrix.help \
- ${HELP}/DoubleFloatSpecialFunctions.help \
- ${HELP}/DoubleFloatVector.help \
- ${HELP}/DoublyLinkedAggregate.help \
- ${HELP}/DrawOption.help \
- ${HELP}/d01ajfAnnaType.help \
- ${HELP}/d01akfAnnaType.help \
- ${HELP}/d01alfAnnaType.help \
- ${HELP}/d01amfAnnaType.help \
- ${HELP}/d01anfAnnaType.help \
- ${HELP}/d01apfAnnaType.help \
- ${HELP}/d01aqfAnnaType.help \
- ${HELP}/d01asfAnnaType.help \
- ${HELP}/d01fcfAnnaType.help \
- ${HELP}/d01gbfAnnaType.help \
- ${HELP}/d01TransformFunctionType.help \
- ${HELP}/d02bbfAnnaType.help \
- ${HELP}/d02bhfAnnaType.help \
- ${HELP}/d02cjfAnnaType.help \
- ${HELP}/d02ejfAnnaType.help \
- ${HELP}/d03eefAnnaType.help \
- ${HELP}/d03fafAnnaType.help \
- ${HELP}/ElementaryFunction.help \
- ${HELP}/ElementaryFunctionCategory.help \
- ${HELP}/Eltable.help \
- ${HELP}/EltableAggregate.help \
- ${HELP}/EntireRing.help \
- ${HELP}/EqTable.help \
- ${HELP}/Equation.help \
- ${HELP}/EuclideanDomain.help \
- ${HELP}/EuclideanGroebnerBasisPackage.help \
- ${HELP}/EuclideanModularRing.help \
- ${HELP}/Evalable.help \
- ${HELP}/Export3D.help \
- ${HELP}/Expression.help \
- ${HELP}/ExpressionSpace.help \
- ${HELP}/ExponentialExpansion.help \
- ${HELP}/ExponentialOfUnivariatePuiseuxSeries.help \
- ${HELP}/ExtAlgBasis.help \
- ${HELP}/ExtensibleLinearAggregate.help \
- ${HELP}/ExtensionField.help \
- ${HELP}/e04dgfAnnaType.help \
- ${HELP}/e04fdfAnnaType.help \
- ${HELP}/e04gcfAnnaType.help \
- ${HELP}/e04jafAnnaType.help \
- ${HELP}/e04mbfAnnaType.help \
- ${HELP}/e04nafAnnaType.help \
- ${HELP}/e04ucfAnnaType.help \
- ${HELP}/Factored.help \
- ${HELP}/FactoredFunctions2.help \
- ${HELP}/FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.help \
- ${HELP}/FactorisationOverPseudoAlgebraicClosureOfRationalNumber.help \
- ${HELP}/Field.help \
- ${HELP}/FieldOfPrimeCharacteristic.help \
- ${HELP}/File.help \
- ${HELP}/FileCategory.help \
- ${HELP}/FileName.help \
- ${HELP}/FileNameCategory.help \
- ${HELP}/Finite.help \
- ${HELP}/FiniteAbelianMonoidRing.help \
- ${HELP}/FiniteAlgebraicExtensionField.help \
- ${HELP}/FiniteDivisor.help \
- ${HELP}/FiniteDivisorCategory.help \
- ${HELP}/FiniteField.help \
- ${HELP}/FiniteFieldCategory.help \
- ${HELP}/FiniteFieldCyclicGroup.help \
- ${HELP}/FiniteFieldCyclicGroupExtension.help \
- ${HELP}/FiniteFieldCyclicGroupExtensionByPolynomial.help \
- ${HELP}/FiniteFieldExtension.help \
- ${HELP}/FiniteFieldExtensionByPolynomial.help \
- ${HELP}/FiniteFieldFactorizationWithSizeParseBySideEffect.help \
- ${HELP}/FiniteFieldNormalBasis.help \
- ${HELP}/FiniteFieldNormalBasisExtension.help \
- ${HELP}/FiniteFieldNormalBasisExtensionByPolynomial.help \
- ${HELP}/FiniteFieldSquareFreeDecomposition.help \
- ${HELP}/FiniteLinearAggregate.help \
- ${HELP}/FiniteRankAlgebra.help \
- ${HELP}/FiniteRankNonAssociativeAlgebra.help \
- ${HELP}/FiniteSetAggregate.help \
- ${HELP}/FlexibleArray.help \
- ${HELP}/Float.help \
- ${HELP}/FloatingPointSystem.help \
- ${HELP}/FortranCode.help \
- ${HELP}/FortranExpression.help \
- ${HELP}/FortranFunctionCategory.help \
- ${HELP}/FortranMachineTypeCategory.help \
- ${HELP}/FortranMatrixCategory.help \
- ${HELP}/FortranMatrixFunctionCategory.help \
- ${HELP}/FortranProgram.help \
- ${HELP}/FortranProgramCategory.help \
- ${HELP}/FortranScalarType.help \
- ${HELP}/FortranTemplate.help \
- ${HELP}/FortranType.help \
- ${HELP}/FortranVectorCategory.help \
- ${HELP}/FortranVectorFunctionCategory.help \
- ${HELP}/FourierComponent.help \
- ${HELP}/FourierSeries.help \
- ${HELP}/Fraction.help \
- ${HELP}/FractionalIdeal.help \
- ${HELP}/FramedAlgebra.help \
- ${HELP}/FramedModule.help \
- ${HELP}/FramedNonAssociativeAlgebra.help \
- ${HELP}/FreeAbelianGroup.help \
- ${HELP}/FreeAbelianMonoid.help \
- ${HELP}/FreeAbelianMonoidCategory.help \
- ${HELP}/FreeGroup.help \
- ${HELP}/FreeLieAlgebra.help \
- ${HELP}/FreeModuleCat.help \
- ${HELP}/FreeModule.help \
- ${HELP}/FreeModule1.help \
- ${HELP}/FreeMonoid.help \
- ${HELP}/FreeNilpotentLie.help \
- ${HELP}/FullPartialFractionExpansion.help \
- ${HELP}/FullyEvalableOver.help \
- ${HELP}/FullyLinearlyExplicitRingOver.help \
- ${HELP}/FullyPatternMatchable.help \
- ${HELP}/FullyRetractableTo.help \
- ${HELP}/FunctionCalled.help \
- ${HELP}/FunctionFieldCategory.help \
- ${HELP}/FunctionSpace.help \
- ${HELP}/GcdDomain.help \
- ${HELP}/GeneralDistributedMultivariatePolynomial.help \
- ${HELP}/GeneralModulePolynomial.help \
- ${HELP}/GeneralPackageForAlgebraicFunctionField.help \
- ${HELP}/GeneralSparseTable.help \
- ${HELP}/GenericNonAssociativeAlgebra.help \
- ${HELP}/GeneralPolynomialSet.help \
- ${HELP}/GeneralTriangularSet.help \
- ${HELP}/GeneralUnivariatePowerSeries.help \
- ${HELP}/GnuDraw.help \
- ${HELP}/GradedAlgebra.help \
- ${HELP}/GradedModule.help \
- ${HELP}/GraphImage.help \
- ${HELP}/GroebnerFactorizationPackage.help \
- ${HELP}/GroebnerPackage.help \
- ${HELP}/Group.help \
- ${HELP}/GuessOption.help \
- ${HELP}/GuessOptionFunctions0.help \
- ${HELP}/HashTable.help \
- ${HELP}/Heap.help \
- ${HELP}/HexadecimalExpansion.help \
- ${HELP}/HTMLFormat.help \
- ${HELP}/HomogeneousAggregate.help \
- ${HELP}/HomogeneousDirectProduct.help \
- ${HELP}/HomogeneousDistributedMultivariatePolynomial.help \
- ${HELP}/HyperbolicFunctionCategory.help \
- ${HELP}/HyperellipticFiniteDivisor.help \
- ${HELP}/IndexCard.help \
- ${HELP}/IndexedAggregate.help \
- ${HELP}/IndexedBits.help \
- ${HELP}/IndexedDirectProductAbelianGroup.help \
- ${HELP}/IndexedDirectProductAbelianMonoid.help \
- ${HELP}/IndexedDirectProductCategory.help \
- ${HELP}/IndexedDirectProductObject.help \
- ${HELP}/IndexedDirectProductOrderedAbelianMonoid.help \
- ${HELP}/IndexedDirectProductOrderedAbelianMonoidSup.help \
- ${HELP}/IndexedExponents.help \
- ${HELP}/IndexedFlexibleArray.help \
- ${HELP}/IndexedList.help \
- ${HELP}/IndexedMatrix.help \
- ${HELP}/IndexedOneDimensionalArray.help \
- ${HELP}/IndexedString.help \
- ${HELP}/IndexedTwoDimensionalArray.help \
- ${HELP}/IndexedVector.help \
- ${HELP}/InfClsPt.help \
- ${HELP}/InfiniteTuple.help \
- ${HELP}/InfinitlyClosePoint.help \
- ${HELP}/InfinitlyClosePointCategory.help \
- ${HELP}/InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.help \
- ${HELP}/InnerAlgebraicNumber.help \
- ${HELP}/InnerEvalable.help \
- ${HELP}/InnerFiniteField.help \
- ${HELP}/InnerFreeAbelianMonoid.help \
- ${HELP}/InnerIndexedTwoDimensionalArray.help \
- ${HELP}/InnerPAdicInteger.help \
- ${HELP}/InnerPrimeField.help \
- ${HELP}/InnerSparseUnivariatePowerSeries.help \
- ${HELP}/InnerTable.help \
- ${HELP}/InnerTaylorSeries.help \
- ${HELP}/InputForm.help \
- ${HELP}/Integer.help \
- ${HELP}/IntegerCombinatoricFunctions.help \
- ${HELP}/IntegerLinearDependence.help \
- ${HELP}/IntegerMod.help \
- ${HELP}/IntegerNumberSystem.help \
- ${HELP}/IntegerNumberTheoryFunctions.help \
- ${HELP}/IntegralDomain.help \
- ${HELP}/IntegrationFunctionsTable.help \
- ${HELP}/IntegrationResult.help \
- ${HELP}/InterfaceGroebnerPackage.help \
- ${HELP}/InterpolateFormsPackage.help \
- ${HELP}/IntersectionDivisorPackage.help \
- ${HELP}/Interval.help \
- ${HELP}/IntervalCategory.help \
- ${HELP}/Kernel.help \
- ${HELP}/KeyedAccessFile.help \
- ${HELP}/KeyedDictionary.help \
- ${HELP}/LaurentPolynomial.help \
- ${HELP}/LazyStreamAggregate.help \
- ${HELP}/LazardSetSolvingPackage.help \
- ${HELP}/LeftAlgebra.help \
- ${HELP}/LeftModule.help \
- ${HELP}/LexTriangularPackage.help \
- ${HELP}/Library.help \
- ${HELP}/LieAlgebra.help \
- ${HELP}/LieExponentials.help \
- ${HELP}/LiePolynomial.help \
- ${HELP}/LieSquareMatrix.help \
- ${HELP}/LinearlyExplicitRingOver.help \
- ${HELP}/LinearAggregate.help \
- ${HELP}/LinearOrdinaryDifferentialOperator.help \
- ${HELP}/LinearOrdinaryDifferentialOperator1.help \
- ${HELP}/LinearOrdinaryDifferentialOperator2.help \
- ${HELP}/LinearOrdinaryDifferentialOperatorCategory.help \
- ${HELP}/LinearSystemFromPowerSeriesPackage.help \
- ${HELP}/ListAggregate.help \
- ${HELP}/ListMonoidOps.help \
- ${HELP}/ListMultiDictionary.help \
- ${HELP}/LiouvillianFunctionCategory.help \
- ${HELP}/List.help \
- ${HELP}/LinesOpPack.help \
- ${HELP}/LocalAlgebra.help \
- ${HELP}/Localize.help \
- ${HELP}/LocalParametrizationOfSimplePointPackage.help \
- ${HELP}/LocalPowerSeriesCategory.help \
- ${HELP}/Logic.help \
- ${HELP}/LyndonWord.help \
- ${HELP}/MachineComplex.help \
- ${HELP}/MachineFloat.help \
- ${HELP}/MachineInteger.help \
- ${HELP}/Magma.help \
- ${HELP}/MakeCachableSet.help \
- ${HELP}/MakeFunction.help \
- ${HELP}/MathMLFormat.help \
- ${HELP}/MappingPackage1.help \
- ${HELP}/MappingPackage2.help \
- ${HELP}/MappingPackage3.help \
- ${HELP}/Matrix.help \
- ${HELP}/MatrixCategory.help \
- ${HELP}/ModMonic.help \
- ${HELP}/ModularField.help \
- ${HELP}/ModularRing.help \
- ${HELP}/Module.help \
- ${HELP}/ModuleMonomial.help \
- ${HELP}/ModuleOperator.help \
- ${HELP}/MoebiusTransform.help \
- ${HELP}/Monad.help \
- ${HELP}/MonadWithUnit.help \
- ${HELP}/MonogenicAlgebra.help \
- ${HELP}/MonogenicLinearOperator.help \
- ${HELP}/Monoid.help \
- ${HELP}/MonoidRing.help \
- ${HELP}/MultiDictionary.help \
- ${HELP}/Multiset.help \
- ${HELP}/MultisetAggregate.help \
- ${HELP}/MultivariatePolynomial.help \
- ${HELP}/MultivariateTaylorSeriesCategory.help \
- ${HELP}/MyExpression.help \
- ${HELP}/MyUnivariatePolynomial.help \
- ${HELP}/NagEigenPackage.help \
- ${HELP}/NagFittingPackage.help \
- ${HELP}/NagLinearEquationSolvingPackage.help \
- ${HELP}/NagIntegrationPackage.help \
- ${HELP}/NagInterpolationPackage.help \
- ${HELP}/NagLapack.help \
- ${HELP}/NagMatrixOperationsPackage.help \
- ${HELP}/NagOptimisationPackage.help \
- ${HELP}/NagOrdinaryDifferentialEquationsPackage.help \
- ${HELP}/NagPartialDifferentialEquationsPackage.help \
- ${HELP}/NagPolynomialRootsPackage.help \
- ${HELP}/NagRootFindingPackage.help \
- ${HELP}/NagSeriesSummationPackage.help \
- ${HELP}/NagSpecialFunctionsPackage.help \
- ${HELP}/NeitherSparseOrDensePowerSeries.help \
- ${HELP}/NewSparseMultivariatePolynomial.help \
- ${HELP}/NewSparseUnivariatePolynomial.help \
- ${HELP}/NewtonPolygon.help \
- ${HELP}/NonAssociativeAlgebra.help \
- ${HELP}/NonAssociativeRing.help \
- ${HELP}/NonAssociativeRng.help \
- ${HELP}/None.help \
- ${HELP}/NonNegativeInteger.help \
- ${HELP}/NormalizedTriangularSetCategory.help \
- ${HELP}/NottinghamGroup.help \
- ${HELP}/NumericalIntegrationCategory.help \
- ${HELP}/NumericalIntegrationProblem.help \
- ${HELP}/NumericalODEProblem.help \
- ${HELP}/NumericalOptimizationCategory.help \
- ${HELP}/NumericalOptimizationProblem.help \
- ${HELP}/NumericalPDEProblem.help \
- ${HELP}/Octonion.help \
- ${HELP}/OctonionCategory.help \
- ${HELP}/ODEIntensityFunctionsTable.help \
- ${HELP}/OneDimensionalArray.help \
- ${HELP}/OneDimensionalArrayAggregate.help \
- ${HELP}/OnePointCompletion.help \
- ${HELP}/OpenMath.help \
- ${HELP}/OpenMathConnection.help \
- ${HELP}/OpenMathDevice.help \
- ${HELP}/OpenMathEncoding.help \
- ${HELP}/OpenMathError.help \
- ${HELP}/OpenMathErrorKind.help \
- ${HELP}/Operator.help \
- ${HELP}/OppositeMonogenicLinearOperator.help \
- ${HELP}/OrderedAbelianGroup.help \
- ${HELP}/OrderedAbelianMonoid.help \
- ${HELP}/OrderedAbelianMonoidSup.help \
- ${HELP}/OrderedAbelianSemiGroup.help \
- ${HELP}/OrderedCancellationAbelianMonoid.help \
- ${HELP}/OrderedCompletion.help \
- ${HELP}/OrderedDirectProduct.help \
- ${HELP}/OrderedFinite.help \
- ${HELP}/OrderedFreeMonoid.help \
- ${HELP}/OrderedIntegralDomain.help \
- ${HELP}/OrderedMonoid.help \
- ${HELP}/OrderedMultisetAggregate.help \
- ${HELP}/OrderedRing.help \
- ${HELP}/OrderedSet.help \
- ${HELP}/OrderedVariableList.help \
- ${HELP}/OrderlyDifferentialPolynomial.help \
- ${HELP}/OrderlyDifferentialVariable.help \
- ${HELP}/OrdinaryDifferentialEquationsSolverCategory.help \
- ${HELP}/OrdinaryDifferentialRing.help \
- ${HELP}/OrdinaryWeightedPolynomials.help \
- ${HELP}/OrdSetInts.help \
- ${HELP}/OutputForm.help \
- ${HELP}/PackageForAlgebraicFunctionField.help \
- ${HELP}/PackageForAlgebraicFunctionFieldOverFiniteField.help \
- ${HELP}/PackageForPoly.help \
- ${HELP}/PAdicInteger.help \
- ${HELP}/PAdicIntegerCategory.help \
- ${HELP}/PAdicRational.help \
- ${HELP}/PAdicRationalConstructor.help \
- ${HELP}/Palette.help \
- ${HELP}/ParametricPlaneCurve.help \
- ${HELP}/ParametricSpaceCurve.help \
- ${HELP}/ParametricSurface.help \
- ${HELP}/ParametrizationPackage.help \
- ${HELP}/PartialDifferentialEquationsSolverCategory.help \
- ${HELP}/PartialDifferentialRing.help \
- ${HELP}/PartialFraction.help \
- ${HELP}/PartialFractionPackage.help \
- ${HELP}/PartialTranscendentalFunctions.help \
- ${HELP}/Partition.help \
- ${HELP}/Pattern.help \
- ${HELP}/Patternable.help \
- ${HELP}/PatternMatchable.help \
- ${HELP}/PatternMatchListResult.help \
- ${HELP}/PatternMatchResult.help \
- ${HELP}/PendantTree.help \
- ${HELP}/Permanent.help \
- ${HELP}/Permutation.help \
- ${HELP}/PermutationCategory.help \
- ${HELP}/PermutationGroup.help \
- ${HELP}/Pi.help \
- ${HELP}/Places.help \
- ${HELP}/PlacesCategory.help \
- ${HELP}/PlacesOverPseudoAlgebraicClosureOfFiniteField.help \
- ${HELP}/PlaneAlgebraicCurvePlot.help \
- ${HELP}/Plcs.help \
- ${HELP}/Plot.help \
- ${HELP}/Plot3D.help \
- ${HELP}/PlottablePlaneCurveCategory.help \
- ${HELP}/PlottableSpaceCurveCategory.help \
- ${HELP}/PoincareBirkhoffWittLyndonBasis.help \
- ${HELP}/Point.help \
- ${HELP}/PointCategory.help \
- ${HELP}/Polynomial.help \
- ${HELP}/PolynomialCategory.help \
- ${HELP}/PolynomialFactorizationExplicit.help \
- ${HELP}/PolynomialIdeals.help \
- ${HELP}/PolynomialPackageForCurve.help \
- ${HELP}/PolynomialRing.help \
- ${HELP}/PolynomialSetCategory.help \
- ${HELP}/PositiveInteger.help \
- ${HELP}/PowerSeriesCategory.help \
- ${HELP}/PrimeField.help \
- ${HELP}/PrimitiveArray.help \
- ${HELP}/PrimitiveFunctionCategory.help \
- ${HELP}/PrincipalIdealDomain.help \
- ${HELP}/PriorityQueueAggregate.help \
- ${HELP}/Product.help \
- ${HELP}/ProjectiveAlgebraicSetPackage.help \
- ${HELP}/ProjectivePlane.help \
- ${HELP}/ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.help \
- ${HELP}/ProjectiveSpace.help \
- ${HELP}/ProjectiveSpaceCategory.help \
- ${HELP}/PseudoAlgebraicClosureOfAlgExtOfRationalNumber.help \
- ${HELP}/PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.help \
- ${HELP}/PseudoAlgebraicClosureOfFiniteField.help \
- ${HELP}/PseudoAlgebraicClosureOfFiniteFieldCategory.help \
- ${HELP}/PseudoAlgebraicClosureOfPerfectFieldCategory.help \
- ${HELP}/PseudoAlgebraicClosureOfRationalNumber.help \
- ${HELP}/PseudoAlgebraicClosureOfRationalNumberCategory.help \
- ${HELP}/QuadraticForm.help \
- ${HELP}/QuasiAlgebraicSet.help \
- ${HELP}/Quaternion.help \
- ${HELP}/QuaternionCategory.help \
- ${HELP}/QuaternionCategoryFunctions2.help \
- ${HELP}/QueryEquation.help \
- ${HELP}/Queue.help \
- ${HELP}/QueueAggregate.help \
- ${HELP}/QuotientFieldCategory.help \
- ${HELP}/RadicalCategory.help \
- ${HELP}/RadicalFunctionField.help \
- ${HELP}/RadicalSolvePackage.help \
- ${HELP}/RadixExpansion.help \
- ${HELP}/RationalFunctionSum.help \
- ${HELP}/RealClosedField.help \
- ${HELP}/RealClosure.help \
- ${HELP}/RealConstant.help \
- ${HELP}/RealNumberSystem.help \
- ${HELP}/RealRootCharacterizationCategory.help \
- ${HELP}/RealSolvePackage.help \
- ${HELP}/RectangularMatrix.help \
- ${HELP}/RectangularMatrixCategory.help \
- ${HELP}/RecursiveAggregate.help \
- ${HELP}/RecursivePolynomialCategory.help \
- ${HELP}/Reference.help \
- ${HELP}/RegularChain.help \
- ${HELP}/RegularTriangularSet.help \
- ${HELP}/RegularTriangularSetCategory.help \
- ${HELP}/ResidueRing.help \
- ${HELP}/Result.help \
- ${HELP}/RetractableTo.help \
- ${HELP}/RewriteRule.help \
- ${HELP}/RightModule.help \
- ${HELP}/RightOpenIntervalRootCharacterization.help \
- ${HELP}/Ring.help \
- ${HELP}/Rng.help \
- ${HELP}/RomanNumeral.help \
- ${HELP}/RootsFindingPackage.help \
- ${HELP}/RoutinesTable.help \
- ${HELP}/RuleCalled.help \
- ${HELP}/Ruleset.help \
- ${HELP}/ScriptFormulaFormat.help \
- ${HELP}/Segment.help \
- ${HELP}/SegmentBinding.help \
- ${HELP}/SegmentCategory.help \
- ${HELP}/SegmentExpansionCategory.help \
- ${HELP}/SemiGroup.help \
- ${HELP}/Set.help \
- ${HELP}/SetAggregate.help \
- ${HELP}/SetCategory.help \
- ${HELP}/SetCategoryWithDegree.help \
- ${HELP}/SetOfMIntegersInOneToN.help \
- ${HELP}/SequentialDifferentialPolynomial.help \
- ${HELP}/SequentialDifferentialVariable.help \
- ${HELP}/SExpression.help \
- ${HELP}/SExpressionCategory.help \
- ${HELP}/SExpressionOf.help \
- ${HELP}/SimpleAlgebraicExtension.help \
- ${HELP}/SimpleFortranProgram.help \
- ${HELP}/SingleInteger.help \
- ${HELP}/SingletonAsOrderedSet.help \
- ${HELP}/SparseTable.help \
- ${HELP}/SparseMultivariatePolynomial.help \
- ${HELP}/SparseMultivariateTaylorSeries.help \
- ${HELP}/SparseUnivariateLaurentSeries.help \
- ${HELP}/SparseUnivariatePolynomial.help \
- ${HELP}/SparseUnivariatePolynomialExpressions.help \
- ${HELP}/SparseUnivariatePuiseuxSeries.help \
- ${HELP}/SparseUnivariateSkewPolynomial.help \
- ${HELP}/SparseUnivariateTaylorSeries.help \
- ${HELP}/SpecialFunctionCategory.help \
- ${HELP}/SplitHomogeneousDirectProduct.help \
- ${HELP}/SplittingNode.help \
- ${HELP}/SplittingTree.help \
- ${HELP}/SquareMatrix.help \
- ${HELP}/SquareFreeNormalizedTriangularSetCategory.help \
- ${HELP}/SquareFreeRegularTriangularSet.help \
- ${HELP}/SquareFreeRegularTriangularSetCategory.help \
- ${HELP}/SquareMatrixCategory.help \
- ${HELP}/Stack.help \
- ${HELP}/StackAggregate.help \
- ${HELP}/StepThrough.help \
- ${HELP}/Stream.help \
- ${HELP}/StreamAggregate.help \
- ${HELP}/StreamTensor.help \
- ${HELP}/String.help \
- ${HELP}/StringAggregate.help \
- ${HELP}/StringCategory.help \
- ${HELP}/StringTable.help \
- ${HELP}/SubSpace.help \
- ${HELP}/SubSpaceComponentProperty.help \
- ${HELP}/SuchThat.help \
- ${HELP}/Switch.help \
- ${HELP}/Symbol.help \
- ${HELP}/SymbolTable.help \
- ${HELP}/SymmetricPolynomial.help \
- ${HELP}/Table.help \
- ${HELP}/TableAggregate.help \
- ${HELP}/Tableau.help \
- ${HELP}/TaylorSeries.help \
- ${HELP}/TexFormat.help \
- ${HELP}/TextFile.help \
- ${HELP}/TheSymbolTable.help \
- ${HELP}/ThreeDimensionalMatrix.help \
- ${HELP}/ThreeDimensionalViewport.help \
- ${HELP}/ThreeSpace.help \
- ${HELP}/ThreeSpaceCategory.help \
- ${HELP}/TranscendentalFunctionCategory.help \
- ${HELP}/TransSolvePackage.help \
- ${HELP}/Tree.help \
- ${HELP}/TriangularSetCategory.help \
- ${HELP}/TrigonometricFunctionCategory.help \
- ${HELP}/TubePlot.help \
- ${HELP}/Tuple.help \
- ${HELP}/TwoDimensionalArray.help   \
- ${HELP}/TwoDimensionalArrayCategory.help \
- ${HELP}/TwoDimensionalViewport.help \
- ${HELP}/UnaryRecursiveAggregate.help \
- ${HELP}/UniqueFactorizationDomain.help \
- ${HELP}/UnivariateFormalPowerSeries.help \
- ${HELP}/UnivariateLaurentSeries.help \
- ${HELP}/UnivariateLaurentSeriesCategory.help \
- ${HELP}/UnivariateLaurentSeriesConstructor.help \
- ${HELP}/UnivariateLaurentSeriesConstructorCategory.help \
- ${HELP}/UnivariatePolynomial.help \
- ${HELP}/UnivariatePolynomialCategory.help \
- ${HELP}/UnivariatePowerSeriesCategory.help \
- ${HELP}/UnivariatePuiseuxSeries.help \
- ${HELP}/UnivariatePuiseuxSeriesCategory.help \
- ${HELP}/UnivariatePuiseuxSeriesConstructor.help \
- ${HELP}/UnivariatePuiseuxSeriesConstructorCategory.help \
- ${HELP}/UnivariatePuiseuxSeriesWithExponentialSingularity.help \
- ${HELP}/UnivariateSkewPolynomial.help \
- ${HELP}/UnivariateSkewPolynomialCategory.help \
- ${HELP}/UnivariateTaylorSeries.help \
- ${HELP}/UnivariateTaylorSeriesCZero.help \
- ${HELP}/UnivariateTaylorSeriesCategory.help \
- ${HELP}/UniversalSegment.help \
- ${HELP}/U32Vector.help \
- ${HELP}/Variable.help \
- ${HELP}/Vector.help \
- ${HELP}/VectorCategory.help \
- ${HELP}/VectorSpace.help \
- ${HELP}/Void.help \
- ${HELP}/WeightedPolynomials.help \
- ${HELP}/WuWenTsunTriangularSet.help \
- ${HELP}/XAlgebra.help \
- ${HELP}/XDistributedPolynomial.help \
- ${HELP}/XFreeAlgebra.help \
- ${HELP}/XPBWPolynomial.help \
- ${HELP}/XPolynomial.help \
- ${HELP}/XPolynomialRing.help \
- ${HELP}/XPolynomialsCat.help \
- ${HELP}/XRecursivePolynomial.help \
- ${HELP}/ZeroDimensionalSolvePackage.help \
- ${HELP}/dcabs1.help \
- ${HELP}/dasum.help \
- ${HELP}/daxpy.help \
- ${HELP}/dcopy.help
-
-@
 The algebra files contain input chunks in regress format.
 This stanza is extracted by the src/input/Makefile after
 all of the other regression tests are complete. This stanza
@@ -18694,8281 +17911,6 @@ REGRESS= \
 all: ${REGRESS}
 	@echo algebra test cases complete.
 @
-<<spadhelp>>=
-${HELP}/AbelianGroup.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create AbelianGroup.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"AbelianGroup.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/AbelianGroup.help
-	@cp -f ${HELP}/AbelianGroup.help ${HELP}/ABELGRP.help
-	@${TANGLE} -R"AbelianGroup.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/AbelianGroup.input
-	@echo "AbelianGroup (ABELGRP)" >>${HELPFILE}
-
-${HELP}/AbelianMonoid.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create AbelianMonoid.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"AbelianMonoid.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/AbelianMonoid.help
-	@cp -f ${HELP}/AbelianMonoid.help ${HELP}/ABELMON.help
-	@${TANGLE} -R"AbelianMonoid.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/AbelianMonoid.input
-	@echo "AbelianMonoid (ABELMON)" >>${HELPFILE}
-
-${HELP}/AbelianMonoidRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create AbelianMonoidRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"AbelianMonoidRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/AbelianMonoidRing.help
-	@cp -f ${HELP}/AbelianMonoidRing.help ${HELP}/AMR.help
-	@${TANGLE} -R"AbelianMonoidRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/AbelianMonoidRing.input
-	@echo "AbelianMonoidRing (AMR)" >>${HELPFILE}
-
-${HELP}/AbelianSemiGroup.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create AbelianSemiGroup.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"AbelianSemiGroup.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/AbelianSemiGroup.help
-	@cp -f ${HELP}/AbelianSemiGroup.help ${HELP}/ABELSG.help
-	@${TANGLE} -R"AbelianSemiGroup.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/AbelianSemiGroup.input
-	@echo "AbelianSemiGroup (ABELSG)" >>${HELPFILE}
-
-${HELP}/AffineAlgebraicSetComputeWithGroebnerBasis.help: \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7000 create \
-            AffineAlgebraicSetComputeWithGroebnerBasis.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} \
-            -R"AffineAlgebraicSetComputeWithGroebnerBasis.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/AffineAlgebraicSetComputeWithGroebnerBasis.help
-	@cp -f ${HELP}/AffineAlgebraicSetComputeWithGroebnerBasis.help \
-            ${HELP}/AFALGGRO.help
-	@${TANGLE} \
-            -R"AffineAlgebraicSetComputeWithGroebnerBasis.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/AffineAlgebraicSetComputeWithGroebnerBasis.input
-	@echo "AffineAlgebraicSetComputeWithGroebnerBasis (AFALGGRO)" \
-            >>${HELPFILE}
-
-${HELP}/AffineAlgebraicSetComputeWithResultant.help: \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7001 create \
-            AffineAlgebraicSetComputeWithResultant.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} \
-            -R"AffineAlgebraicSetComputeWithResultant.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/AffineAlgebraicSetComputeWithResultant.help
-	@cp -f ${HELP}/AffineAlgebraicSetComputeWithResultant.help \
-            ${HELP}/AFALGRES.help
-	@${TANGLE} \
-            -R"AffineAlgebraicSetComputeWithResultant.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/AffineAlgebraicSetComputeWithResultant.input
-	@echo "AffineAlgebraicSetComputeWithResultant (AFALGRES)" \
-            >>${HELPFILE}
-
-${HELP}/AffinePlane.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7002 create AffinePlane.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AffinePlane.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/AffinePlane.help
-	@cp -f ${HELP}/AffinePlane.help ${HELP}/AFFPL.help
-	@${TANGLE} -R"AffinePlane.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AffinePlane.input
-	@echo "AffinePlane (AFFPL)" >>${HELPFILE}
-
-${HELP}/AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.help: \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7003 create \
-            AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} \
-            -R"AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.help
-	@cp -f ${HELP}/AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.help \
-            ${HELP}/AFFPLPS.help
-	@${TANGLE} \
-            -R"AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AffinePlaneOverPseudoAlgebraicClosureOfFiniteField.input
-	@echo "AffinePlaneOverPseudoAlgebraicClosureOfFiniteField (AFFPLPS)" \
-            >>${HELPFILE}
-
-${HELP}/AffineSpace.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7004 create AffineSpace.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AffineSpace.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/AffineSpace.help
-	@cp -f ${HELP}/AffineSpace.help ${HELP}/AFFSP.help
-	@${TANGLE} -R"AffineSpace.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AffineSpace.input
-	@echo "AffineSpace (AFFSP)" >>${HELPFILE}
-
-${HELP}/AffineSpaceCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7005 create AffineSpaceCategory.help from \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"AffineSpaceCategory.help" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${HELP}/AffineSpaceCategory.help
-	@cp -f ${HELP}/AffineSpaceCategory.help ${HELP}/AFSPCAT.help
-	@${TANGLE} -R"AffineSpaceCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/AffineSpaceCategory.input
-	@echo "AffineSpaceCategory (AFSPCAT)" >>${HELPFILE}
-
-${HELP}/Aggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Aggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Aggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Aggregate.help
-	@cp -f ${HELP}/Aggregate.help ${HELP}/AGG.help
-	@${TANGLE} -R"Aggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Aggregate.input
-	@echo "Aggregate (AGG)" >>${HELPFILE}
-
-${HELP}/Algebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Algebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Algebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Algebra.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	   cp -f ${HELP}/Algebra.help ${HELP}/ALGEBRA.help ; \
-	 fi
-	@${TANGLE} -R"Algebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Algebra.input
-	@echo "Algebra (ALGEBRA)" >>${HELPFILE}
-
-${HELP}/AlgebraGivenByStructuralConstants.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create AlgebraGivenByStructuralConstants.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AlgebraGivenByStructuralConstants.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/AlgebraGivenByStructuralConstants.help
-	@cp -f ${HELP}/AlgebraGivenByStructuralConstants.help \
-            ${HELP}/ALGSC.help
-	@${TANGLE} -R"AlgebraGivenByStructuralConstants.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AlgebraGivenByStructuralConstants.input
-	@echo "AlgebraGivenByStructuralConstants (ALGSC)" >>${HELPFILE}
-
-${HELP}/AlgebraicallyClosedField.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7006 create AlgebraicallyClosedField.help from \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"AlgebraicallyClosedField.help" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${HELP}/AlgebraicallyClosedField.help
-	@cp -f ${HELP}/AlgebraicallyClosedField.help ${HELP}/ACF.help
-	@${TANGLE} -R"AlgebraicallyClosedField.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/AlgebraicallyClosedField.input
-	@echo "AlgebraicallyClosedField (ACF)" >>${HELPFILE}
-
-${HELP}/AlgebraicallyClosedFunctionSpace.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create AlgebraicallyClosedFunctionSpace.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"AlgebraicallyClosedFunctionSpace.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/AlgebraicallyClosedFunctionSpace.help
-	@cp -f ${HELP}/AlgebraicallyClosedFunctionSpace.help ${HELP}/ACFS.help
-	@${TANGLE} -R"AlgebraicallyClosedFunctionSpace.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/AlgebraicallyClosedFunctionSpace.input
-	@echo "AlgebraicallyClosedFunctionSpace (ACFS)" >>${HELPFILE}
-
-${HELP}/AlgebraicFunctionField.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create AlgebraicFunctionField.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AlgebraicFunctionField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/AlgebraicFunctionField.help
-	@cp -f ${HELP}/AlgebraicFunctionField.help ${HELP}/ALGFF.help
-	@${TANGLE} -R"AlgebraicFunctionField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AlgebraicFunctionField.input
-	@echo "AlgebraicFunctionField (ALGFF)" >>${HELPFILE}
-
-${HELP}/AlgebraicNumber.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create AlgebraicNumber.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AlgebraicNumber.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/AlgebraicNumber.help
-	@cp -f ${HELP}/AlgebraicNumber.help ${HELP}/AN.help
-	@${TANGLE} -R"AlgebraicNumber.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AlgebraicNumber.input
-	@echo "AlgebraicNumber (AN)" >>${HELPFILE}
-
-${HELP}/AnonymousFunction.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create AnonymousFunction.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AnonymousFunction.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/AnonymousFunction.help
-	@cp -f ${HELP}/AnonymousFunction.help ${HELP}/ANON.help
-	@${TANGLE} -R"AnonymousFunction.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AnonymousFunction.input
-	@echo "AnonymousFunction (ANON)" >>${HELPFILE}
-
-${HELP}/AntiSymm.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create AntiSymm.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AntiSymm.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/AntiSymm.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/AntiSymm.help ${HELP}/ANTISYM.help ; \
-	 fi
-	@${TANGLE} -R"AntiSymm.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AntiSymm.input
-	@echo "AntiSymm (ANTISYM)" >>${HELPFILE}
-
-${HELP}/Any.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7007 create Any.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Any.help" ${BOOKS}/bookvol10.3.pamphlet >${HELP}/Any.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Any.help ${HELP}/ANY.help ; \
-	 fi
-	@${TANGLE} -R"Any.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Any.input
-	@echo "Any (ANY)" >>${HELPFILE}
-
-${HELP}/ApplicationProgramInterface.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7008 create ApplicationProgramInterface.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"ApplicationProgramInterface.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/ApplicationProgramInterface.help
-	@cp -f ${HELP}/ApplicationProgramInterface.help ${HELP}/API.help
-	@${TANGLE} -R"ApplicationProgramInterface.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/ApplicationProgramInterface.input
-	@echo "ApplicationProgramInterface (API)" >>${HELPFILE}
-
-${HELP}/ArcHyperbolicFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ArcHyperbolicFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ArcHyperbolicFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ArcHyperbolicFunctionCategory.help
-	@cp -f ${HELP}/ArcHyperbolicFunctionCategory.help ${HELP}/AHYP.help
-	@${TANGLE} -R"ArcHyperbolicFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ArcHyperbolicFunctionCategory.input
-	@echo "ArcHyperbolicFunctionCategory (AHYP)" >>${HELPFILE}
-
-${HELP}/ArcTrigonometricFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ArcTrigonometricFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ArcTrigonometricFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ArcTrigonometricFunctionCategory.help
-	@cp -f ${HELP}/ArcTrigonometricFunctionCategory.help ${HELP}/ATRIG.help
-	@${TANGLE} -R"ArcTrigonometricFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ArcTrigonometricFunctionCategory.input
-	@echo "ArcTrigonometricFunctionCategory (ATRIG)" >>${HELPFILE}
-
-${HELP}/ArrayStack.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7010 create ArrayStack.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ArrayStack.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ArrayStack.help
-	@cp -f ${HELP}/ArrayStack.help ${HELP}/ASTACK.help
-	@${TANGLE} -R"ArrayStack.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ArrayStack.input
-	@echo "ArrayStack (ASTACK)" >>${HELPFILE}
-
-${HELP}/Asp1.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp1.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp1.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp1.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp1.help ${HELP}/ASP1.help ; \
-	 fi
-	@${TANGLE} -R"Asp1.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp1.input
-	@echo "Asp1 (ASP1)" >>${HELPFILE}
-
-${HELP}/Asp10.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp10.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp10.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp10.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp10.help ${HELP}/ASP10.help ; \
-	 fi
-	@${TANGLE} -R"Asp10.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp10.input
-	@echo "Asp10 (ASP10)" >>${HELPFILE}
-
-${HELP}/Asp12.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp12.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp12.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp12.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp12.help ${HELP}/ASP12.help ; \
-	 fi
-	@${TANGLE} -R"Asp12.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp12.input
-	@echo "Asp12 (ASP12)" >>${HELPFILE}
-
-${HELP}/Asp19.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp19.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp19.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp19.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp19.help ${HELP}/ASP19.help ; \
-	 fi
-	@${TANGLE} -R"Asp19.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp19.input
-	@echo "Asp19 (ASP19)" >>${HELPFILE}
-
-${HELP}/Asp20.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp20.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp20.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp20.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp20.help ${HELP}/ASP20.help ; \
-	 fi
-	@${TANGLE} -R"Asp20.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp20.input
-	@echo "Asp20 (ASP20)" >>${HELPFILE}
-
-${HELP}/Asp24.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp24.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp24.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp24.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp24.help ${HELP}/ASP24.help ; \
-	 fi
-	@${TANGLE} -R"Asp24.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp24.input
-	@echo "Asp24 (ASP24)" >>${HELPFILE}
-
-${HELP}/Asp27.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp27.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp27.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp27.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp27.help ${HELP}/ASP27.help ; \
-	 fi
-	@${TANGLE} -R"Asp27.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp27.input
-	@echo "Asp27 (ASP27)" >>${HELPFILE}
-
-${HELP}/Asp28.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp28.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp28.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp28.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp28.help ${HELP}/ASP28.help ; \
-	 fi
-	@${TANGLE} -R"Asp28.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp28.input
-	@echo "Asp28 (ASP28)" >>${HELPFILE}
-
-${HELP}/Asp29.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp29.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp29.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp29.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp29.help ${HELP}/ASP29.help ; \
-	 fi
-	@${TANGLE} -R"Asp29.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp29.input
-	@echo "Asp29 (ASP29)" >>${HELPFILE}
-
-${HELP}/Asp30.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp30.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp30.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp30.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp30.help ${HELP}/ASP30.help ; \
-	 fi
-	@${TANGLE} -R"Asp30.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp30.input
-	@echo "Asp30 (ASP30)" >>${HELPFILE}
-
-${HELP}/Asp31.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp31.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp31.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp31.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp31.help ${HELP}/ASP31.help ; \
-	 fi
-	@${TANGLE} -R"Asp31.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp31.input
-	@echo "Asp31 (ASP31)" >>${HELPFILE}
-
-${HELP}/Asp33.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp33.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp33.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp33.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp33.help ${HELP}/ASP33.help ; \
-	 fi
-	@${TANGLE} -R"Asp33.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp33.input
-	@echo "Asp33 (ASP33)" >>${HELPFILE}
-
-${HELP}/Asp34.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp34.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp34.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp34.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp34.help ${HELP}/ASP34.help ; \
-	 fi
-	@${TANGLE} -R"Asp34.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp34.input
-	@echo "Asp34 (ASP34)" >>${HELPFILE}
-
-${HELP}/Asp35.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp35.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp35.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp35.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp35.help ${HELP}/ASP35.help ; \
-	 fi
-	@${TANGLE} -R"Asp35.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp35.input
-	@echo "Asp35 (ASP35)" >>${HELPFILE}
-
-${HELP}/Asp4.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp4.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp4.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp4.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp4.help ${HELP}/ASP4.help ; \
-	 fi
-	@${TANGLE} -R"Asp4.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp4.input
-	@echo "Asp4 (ASP4)" >>${HELPFILE}
-
-${HELP}/Asp41.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp41.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp41.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp41.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp41.help ${HELP}/ASP41.help ; \
-	 fi
-	@${TANGLE} -R"Asp41.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp41.input
-	@echo "Asp41 (ASP41)" >>${HELPFILE}
-
-${HELP}/Asp42.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp42.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp42.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp42.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp42.help ${HELP}/ASP42.help ; \
-	 fi
-	@${TANGLE} -R"Asp42.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp42.input
-	@echo "Asp42 (ASP42)" >>${HELPFILE}
-
-${HELP}/Asp49.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp49.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp49.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp49.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp49.help ${HELP}/ASP49.help ; \
-	 fi
-	@${TANGLE} -R"Asp49.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp49.input
-	@echo "Asp49 (ASP49)" >>${HELPFILE}
-
-${HELP}/Asp50.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp50.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp50.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp50.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp50.help ${HELP}/ASP50.help ; \
-	 fi
-	@${TANGLE} -R"Asp50.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp50.input
-	@echo "Asp50 (ASP50)" >>${HELPFILE}
-
-${HELP}/Asp55.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp55.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp55.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp55.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp55.help ${HELP}/ASP55.help ; \
-	 fi
-	@${TANGLE} -R"Asp55.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp55.input
-	@echo "Asp55 (ASP55)" >>${HELPFILE}
-
-${HELP}/Asp6.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp6.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp6.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp6.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp6.help ${HELP}/ASP6.help ; \
-	 fi
-	@${TANGLE} -R"Asp6.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp6.input
-	@echo "Asp6 (ASP6)" >>${HELPFILE}
-
-${HELP}/Asp7.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp7.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp7.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp7.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp7.help ${HELP}/ASP7.help ; \
-	 fi
-	@${TANGLE} -R"Asp7.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp7.input
-	@echo "Asp7 (ASP7)" >>${HELPFILE}
-
-${HELP}/Asp73.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp73.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp73.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp73.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp73.help ${HELP}/ASP73.help ; \
-	 fi
-	@${TANGLE} -R"Asp73.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp73.input
-	@echo "Asp73 (ASP73)" >>${HELPFILE}
-
-${HELP}/Asp74.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp74.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp74.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp74.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp74.help ${HELP}/ASP74.help ; \
-	 fi
-	@${TANGLE} -R"Asp74.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp74.input
-	@echo "Asp74 (ASP74)" >>${HELPFILE}
-
-${HELP}/Asp77.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp77.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp77.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp77.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp77.help ${HELP}/ASP77.help ; \
-	 fi
-	@${TANGLE} -R"Asp77.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp77.input
-	@echo "Asp77 (ASP77)" >>${HELPFILE}
-
-${HELP}/Asp78.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp78.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp78.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp78.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp78.help ${HELP}/ASP78.help ; \
-	 fi
-	@${TANGLE} -R"Asp78.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp78.input
-	@echo "Asp78 (ASP78)" >>${HELPFILE}
-
-${HELP}/Asp8.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp8.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp8.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp8.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp8.help ${HELP}/ASP8.help ; \
-	 fi
-	@${TANGLE} -R"Asp8.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp8.input
-	@echo "Asp8 (ASP8)" >>${HELPFILE}
-
-${HELP}/Asp80.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp80.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp80.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp80.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp80.help ${HELP}/ASP80.help ; \
-	 fi
-	@${TANGLE} -R"Asp80.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp80.input
-	@echo "Asp80 (ASP80)" >>${HELPFILE}
-
-${HELP}/Asp9.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Asp9.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Asp9.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Asp9.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Asp9.help ${HELP}/ASP9.help ; \
-	 fi
-	@${TANGLE} -R"Asp9.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Asp9.input
-	@echo "Asp9 (ASP9)" >>${HELPFILE}
-
-${HELP}/AssociatedJordanAlgebra.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create AssociatedJordanAlgebra.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AssociatedJordanAlgebra.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/AssociatedJordanAlgebra.help
-	@cp -f ${HELP}/AssociatedJordanAlgebra.help ${HELP}/JORDAN.help
-	@${TANGLE} -R"AssociatedJordanAlgebra.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AssociatedJordanAlgebra.input
-	@echo "AssociatedJordanAlgebra (JORDAN)" >>${HELPFILE}
-
-${HELP}/AssociatedLieAlgebra.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create AssociatedLieAlgebra.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AssociatedLieAlgebra.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/AssociatedLieAlgebra.help
-	@cp -f ${HELP}/AssociatedLieAlgebra.help ${HELP}/LIE.help
-	@${TANGLE} -R"AssociatedLieAlgebra.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AssociatedLieAlgebra.input
-	@echo "AssociatedLieAlgebra (LIE)" >>${HELPFILE}
-
-${HELP}/AssociationList.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7020 create AssociationList.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AssociationList.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/AssociationList.help
-	@cp -f ${HELP}/AssociationList.help ${HELP}/ALIST.help
-	@${TANGLE} -R"AssociationList.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AssociationList.input
-	@echo "AssociationList (ALIST)" >>${HELPFILE}
-
-${HELP}/AssociationListAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create AssociationListAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"AssociationListAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/AssociationListAggregate.help
-	@cp -f ${HELP}/AssociationListAggregate.help ${HELP}/ALAGG.help
-	@${TANGLE} -R"AssociationListAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/AssociationListAggregate.input
-	@echo "AssociationListAggregate (ALAGG)" >>${HELPFILE}
-
-${HELP}/AttributeButtons.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create AttributeButtons.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"AttributeButtons.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/AttributeButtons.help
-	@cp -f ${HELP}/AttributeButtons.help ${HELP}/ATTRBUT.help
-	@${TANGLE} -R"AttributeButtons.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/AttributeButtons.input
-	@echo "AttributeButtons (ATTRBUT)" >>${HELPFILE}
-
-${HELP}/Automorphism.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Automorphism.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Automorphism.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Automorphism.help
-	@cp -f ${HELP}/Automorphism.help ${HELP}/AUTOMOR.help
-	@${TANGLE} -R"Automorphism.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Automorphism.input
-	@echo "Automorphism (AUTOMOR)" >>${HELPFILE}
-
-${HELP}/BalancedBinaryTree.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7030 create BalancedBinaryTree.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BalancedBinaryTree.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/BalancedBinaryTree.help
-	@cp -f ${HELP}/BalancedBinaryTree.help ${HELP}/BBTREE.help
-	@${TANGLE} -R"BalancedBinaryTree.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BalancedBinaryTree.input
-	@echo "BalancedBinaryTree (BBTREE)" >>${HELPFILE}
-
-${HELP}/BalancedPAdicInteger.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create BalancedPAdicInteger.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BalancedPAdicInteger.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/BalancedPAdicInteger.help
-	@cp -f ${HELP}/BalancedPAdicInteger.help ${HELP}/BPADIC.help
-	@${TANGLE} -R"BalancedPAdicInteger.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BalancedPAdicInteger.input
-	@echo "BalancedPAdicInteger (BPADIC)" >>${HELPFILE}
-
-${HELP}/BalancedPAdicRational.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create BalancedPAdicRational.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BalancedPAdicRational.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/BalancedPAdicRational.help
-	@cp -f ${HELP}/BalancedPAdicRational.help ${HELP}/BPADICRT.help
-	@${TANGLE} -R"BalancedPAdicRational.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BalancedPAdicRational.input
-	@echo "BalancedPAdicRational (BPADICRT)" >>${HELPFILE}
-
-${HELP}/BagAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create BagAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"BagAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/BagAggregate.help
-	@cp -f ${HELP}/BagAggregate.help ${HELP}/BGAGG.help
-	@${TANGLE} -R"BagAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/BagAggregate.input
-	@echo "BagAggregate (BGAGG)" >>${HELPFILE}
-
-${HELP}/BasicFunctions.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create BasicFunctions.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BasicFunctions.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/BasicFunctions.help
-	@cp -f ${HELP}/BasicFunctions.help ${HELP}/BFUNCT.help
-	@${TANGLE} -R"BasicFunctions.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BasicFunctions.input
-	@echo "BasicFunctions (BFUNCT)" >>${HELPFILE}
-
-${HELP}/BasicOperator.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7040 create BasicOperator.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BasicOperator.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/BasicOperator.help
-	@cp -f ${HELP}/BasicOperator.help ${HELP}/BOP.help
-	@${TANGLE} -R"BasicOperator.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BasicOperator.input
-	@echo "BasicOperator (BOP)" >>${HELPFILE}
-
-${HELP}/BasicType.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create BasicType.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"BasicType.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/BasicType.help
-	@cp -f ${HELP}/BasicType.help ${HELP}/BASTYPE.help
-	@${TANGLE} -R"BasicType.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/BasicType.input
-	@echo "BasicType (BASTYPE)" >>${HELPFILE}
-
-${HELP}/Bezier.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7050 create Bezier.help from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"Bezier.help" ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/Bezier.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Bezier.help ${HELP}/BEZIER.help ; \
-	 fi
-	@${TANGLE} -R"Bezier.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/Bezier.input
-	@echo "Bezier (BEZIER)" >>${HELPFILE}
-
-${HELP}/BiModule.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create BiModule.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"BiModule.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/BiModule.help
-	@cp -f ${HELP}/BiModule.help ${HELP}/BMODULE.help
-	@${TANGLE} -R"BiModule.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/BiModule.input
-	@echo "BiModule (BMODULE)" >>${HELPFILE}
-
-${HELP}/BinaryExpansion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7060 create BinaryExpansion.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BinaryExpansion.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/BinaryExpansion.help
-	@cp -f ${HELP}/BinaryExpansion.help ${HELP}/BINARY.help
-	@${TANGLE} -R"BinaryExpansion.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BinaryExpansion.input
-	@echo "BinaryExpansion (BINARY)" >>${HELPFILE}
-
-${HELP}/BinaryFile.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create BinaryFile.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BinaryFile.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/BinaryFile.help
-	@cp -f ${HELP}/BinaryFile.help ${HELP}/BINFILE.help
-	@${TANGLE} -R"BinaryFile.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BinaryFile.input
-	@echo "BinaryFile (BINFILE)" >>${HELPFILE}
-
-${HELP}/BinaryRecursiveAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create BinaryRecursiveAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"BinaryRecursiveAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/BinaryRecursiveAggregate.help
-	@cp -f ${HELP}/BinaryRecursiveAggregate.help ${HELP}/BRAGG.help
-	@${TANGLE} -R"BinaryRecursiveAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/BinaryRecursiveAggregate.input
-	@echo "BinaryRecursiveAggregate (BRAGG)" >>${HELPFILE}
-
-${HELP}/BinarySearchTree.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7070 create BinarySearchTree.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BinarySearchTree.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/BinarySearchTree.help
-	@cp -f ${HELP}/BinarySearchTree.help ${HELP}/BSTREE.help
-	@${TANGLE} -R"BinarySearchTree.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BinarySearchTree.input
-	@echo "BinarySearchTree (BSTREE)" >>${HELPFILE}
-
-${HELP}/BinaryTournament.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create BinaryTournament.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BinaryTournament.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/BinaryTournament.help
-	@cp -f ${HELP}/BinaryTournament.help ${HELP}/BTOURN.help
-	@${TANGLE} -R"BinaryTournament.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BinaryTournament.input
-	@echo "BinaryTournament (BTOURN)" >>${HELPFILE}
-
-${HELP}/BinaryTree.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create BinaryTree.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BinaryTree.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/BinaryTree.help
-	@cp -f ${HELP}/BinaryTree.help ${HELP}/BTREE.help
-	@${TANGLE} -R"BinaryTree.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BinaryTree.input
-	@echo "BinaryTree (BTREE)" >>${HELPFILE}
-
-${HELP}/BinaryTreeCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create BinaryTreeCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"BinaryTreeCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/BinaryTreeCategory.help
-	@cp -f ${HELP}/BinaryTreeCategory.help ${HELP}/BTCAT.help
-	@${TANGLE} -R"BinaryTreeCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/BinaryTreeCategory.input
-	@echo "BinaryTreeCategory (BTCAT)" >>${HELPFILE}
-
-${HELP}/BitAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create BitAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"BitAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/BitAggregate.help
-	@cp -f ${HELP}/BitAggregate.help ${HELP}/BTAGG.help
-	@${TANGLE} -R"BitAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/BitAggregate.input
-	@echo "BitAggregate (BTAGG)" >>${HELPFILE}
-
-${HELP}/Bits.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Bits.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Bits.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Bits.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Bits.help ${HELP}/BITS.help ; \
-	 fi
-	@${TANGLE} -R"Bits.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Bits.input
-	@echo "Bits (BITS)" >>${HELPFILE}
-
-${HELP}/BlasLevelOne.help: ${BOOKS}/bookvol10.5.pamphlet
-	@echo 7080 create BlasLevelOne.help from \
-                ${BOOKS}/bookvol10.5.pamphlet
-	@${TANGLE} -R"BlasLevelOne.help" ${BOOKS}/bookvol10.5.pamphlet \
-            >${HELP}/BlasLevelOne.help
-	@cp -f ${HELP}/BlasLevelOne.help ${HELP}/BLAS1.help
-	@${TANGLE} -R"BlasLevelOne.input" ${BOOKS}/bookvol10.5.pamphlet \
-            >${INPUT}/BlasLevelOne.input
-	@echo "BlasLevelOne (BLAS1)" >>${HELPFILE}
-
-${HELP}/BlowUpMethodCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7082 create BlowUpMethodCategory.help from \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"BlowUpMethodCategory.help" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${HELP}/BlowUpMethodCategory.help
-	@cp -f ${HELP}/BlowUpMethodCategory.help ${HELP}/BLMETCT.help
-	@${TANGLE} -R"BlowUpMethodCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/BlowUpMethodCategory.input
-	@echo "BlowUpMethodCategory (BLMETCT)" >>${HELPFILE}
-
-${HELP}/BlowUpPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7083 create BlowUpPackage.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"BlowUpPackage.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/BlowUpPackage.help
-	@cp -f ${HELP}/BlowUpPackage.help ${HELP}/BLUPPACK.help
-	@${TANGLE} -R"BlowUpPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/BlowUpPackage.input
-	@echo "BlowUpPackage (BLUPPACK)" >>${HELPFILE}
-
-${HELP}/BlowUpWithHamburgerNoether.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7084 create BlowUpWithHamburgerNoether.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BlowUpWithHamburgerNoether.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/BlowUpWithHamburgerNoether.help
-	@cp -f ${HELP}/BlowUpWithHamburgerNoether.help ${HELP}/BLHN.help
-	@${TANGLE} -R"BlowUpWithHamburgerNoether.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BlowUpWithHamburgerNoether.input
-	@echo "BlowUpWithHamburgerNoether (BLHN)" >>${HELPFILE}
-
-${HELP}/BlowUpWithQuadTrans.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7085 create BlowUpWithQuadTrans.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"BlowUpWithQuadTrans.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/BlowUpWithQuadTrans.help
-	@cp -f ${HELP}/BlowUpWithQuadTrans.help ${HELP}/BLQT.help
-	@${TANGLE} -R"BlowUpWithQuadTrans.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/BlowUpWithQuadTrans.input
-	@echo "BlowUpWithQuadTrans (BLQT)" >>${HELPFILE}
-
-${HELP}/Boolean.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Boolean.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Boolean.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Boolean.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Boolean.help ${HELP}/BOOLEAN.help ; \
-	 fi
-	@${TANGLE} -R"Boolean.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Boolean.input
-	@echo "Boolean (BOOLEAN)" >>${HELPFILE}
-
-${HELP}/CachableSet.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create CachableSet.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"CachableSet.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/CachableSet.help
-	@cp -f ${HELP}/CachableSet.help ${HELP}/CACHSET.help
-	@${TANGLE} -R"CachableSet.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/CachableSet.input
-	@echo "CachableSet (CACHSET)" >>${HELPFILE}
-
-${HELP}/CancellationAbelianMonoid.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create CancellationAbelianMonoid.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"CancellationAbelianMonoid.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/CancellationAbelianMonoid.help
-	@cp -f ${HELP}/CancellationAbelianMonoid.help ${HELP}/CABMON.help
-	@${TANGLE} -R"CancellationAbelianMonoid.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/CancellationAbelianMonoid.input
-	@echo "CancellationAbelianMonoid (CABMON)" >>${HELPFILE}
-
-${HELP}/CardinalNumber.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7086 create CardinalNumber.help from \
-                ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"CardinalNumber.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/CardinalNumber.help
-	@cp -f ${HELP}/CardinalNumber.help ${HELP}/CARD.help
-	@${TANGLE} -R"CardinalNumber.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/CardinalNumber.input
-	@echo "CardinalNumber (CARD)" >>${HELPFILE}
-
-${HELP}/CartesianTensor.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7090 create CartesianTensor.help from \
-             ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"CartesianTensor.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/CartesianTensor.help
-	@cp -f ${HELP}/CartesianTensor.help ${HELP}/CARTEN.help
-	@${TANGLE} -R"CartesianTensor.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/CartesianTensor.input
-	@echo "CartesianTensor (CARTEN)" >>${HELPFILE}
-
-${HELP}/Character.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7100 create Character.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Character.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Character.help
-	@cp -f ${HELP}/Character.help ${HELP}/CHAR.help
-	@${TANGLE} -R"Character.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Character.input
-	@echo "Character (CHAR)" >>${HELPFILE}
-
-${HELP}/CharacterClass.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7110 create CharacterClass.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"CharacterClass.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/CharacterClass.help
-	@cp -f ${HELP}/CharacterClass.help ${HELP}/CCLASS.help
-	@${TANGLE} -R"CharacterClass.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/CharacterClass.input
-	@echo "CharacterClass (CCLASS)" >>${HELPFILE}
-
-${HELP}/CharacteristicNonZero.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create CharacteristicNonZero.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"CharacteristicNonZero.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/CharacteristicNonZero.help
-	@cp -f ${HELP}/CharacteristicNonZero.help ${HELP}/CHARNZ.help
-	@${TANGLE} -R"CharacteristicNonZero.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/CharacteristicNonZero.input
-	@echo "CharacteristicNonZero (CHARNZ)" >>${HELPFILE}
-
-${HELP}/CharacteristicZero.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create CharacteristicZero.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"CharacteristicZero.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/CharacteristicZero.help
-	@cp -f ${HELP}/CharacteristicZero.help ${HELP}/CHARZ.help
-	@${TANGLE} -R"CharacteristicZero.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/CharacteristicZero.input
-	@echo "CharacteristicZero (CHARZ)" >>${HELPFILE}
-
-${HELP}/CliffordAlgebra.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7120 create CliffordAlgebra.help from \
-          ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"CliffordAlgebra.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/CliffordAlgebra.help
-	@cp -f ${HELP}/CliffordAlgebra.help ${HELP}/CLIF.help
-	@${TANGLE} -R"CliffordAlgebra.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/CliffordAlgebra.input
-	@echo "CliffordAlgebra (CLIF)" >>${HELPFILE}
-
-${HELP}/CoercibleTo.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create CoercibleTo.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"CoercibleTo.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/CoercibleTo.help
-	@cp -f ${HELP}/CoercibleTo.help ${HELP}/KOERCE.help
-	@${TANGLE} -R"CoercibleTo.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/CoercibleTo.input
-	@echo "CoercibleTo (KOERCE)" >>${HELPFILE}
-
-${HELP}/Collection.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Collection.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Collection.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Collection.help
-	@cp -f ${HELP}/Collection.help ${HELP}/CLAGG.help
-	@${TANGLE} -R"Collection.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Collection.input
-	@echo "Collection (CLAGG)" >>${HELPFILE}
-
-${HELP}/Color.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Color.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Color.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Color.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Color.help ${HELP}/COLOR.help ; \
-	 fi
-	@${TANGLE} -R"Color.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Color.input
-	@echo "Color (COLOR)" >>${HELPFILE}
-
-${HELP}/CombinatorialFunction.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7130 create CombinatorialFunction.help from \
-          ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"CombinatorialFunction.help" \
-          ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/CombinatorialFunction.help
-	@cp -f ${HELP}/CombinatorialFunction.help ${HELP}/COMBF.help
-	@${TANGLE} -R"CombinatorialFunction.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/CombinatorialFunction.input
-	@echo "CombinatorialFunction (COMBF)" >>${HELPFILE}
-
-${HELP}/CombinatorialFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create CombinatorialFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"CombinatorialFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/CombinatorialFunctionCategory.help
-	@cp -f ${HELP}/CombinatorialFunctionCategory.help ${HELP}/CFCAT.help
-	@${TANGLE} -R"CombinatorialFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/CombinatorialFunctionCategory.input
-	@echo "CombinatorialFunctionCategory (CFCAT)" >>${HELPFILE}
-
-${HELP}/CombinatorialOpsCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create CombinatorialOpsCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"CombinatorialOpsCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/CombinatorialOpsCategory.help
-	@cp -f ${HELP}/CombinatorialOpsCategory.help ${HELP}/COMBOPC.help
-	@${TANGLE} -R"CombinatorialOpsCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/CombinatorialOpsCategory.input
-	@echo "CombinatorialOpsCategory (COMBOPC)" >>${HELPFILE}
-
-${HELP}/CommutativeRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create CommutativeRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"CommutativeRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/CommutativeRing.help
-	@cp -f ${HELP}/CommutativeRing.help ${HELP}/COMRING.help
-	@${TANGLE} -R"CommutativeRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/CommutativeRing.input
-	@echo "CommutativeRing (COMRING)" >>${HELPFILE}
-
-${HELP}/Commutator.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Commutator.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Commutator.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Commutator.help
-	@cp -f ${HELP}/Commutator.help ${HELP}/COMM.help
-	@${TANGLE} -R"Commutator.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Commutator.input
-	@echo "Commutator (COMM)" >>${HELPFILE}
-
-${HELP}/Complex.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7140 create Complex.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Complex.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Complex.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Complex.help ${HELP}/COMPLEX.help ; \
-	 fi
-	@${TANGLE} -R"Complex.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Complex.input
-	@echo "Complex (COMPLEX)" >>${HELPFILE}
-
-${HELP}/ComplexCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ComplexCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ComplexCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ComplexCategory.help
-	@cp -f ${HELP}/ComplexCategory.help ${HELP}/COMPCAT.help
-	@${TANGLE} -R"ComplexCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ComplexCategory.input
-	@echo "ComplexCategory (COMPCAT)" >>${HELPFILE}
-
-${HELP}/ContinuedFraction.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7150 create ContinuedFraction.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ContinuedFraction.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/ContinuedFraction.help
-	@cp -f ${HELP}/ContinuedFraction.help ${HELP}/CONTFRAC.help
-	@${TANGLE} -R"ContinuedFraction.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ContinuedFraction.input
-	@echo "ContinuedFraction (CONTFRAC)" >>${HELPFILE}
-
-${HELP}/ComplexDoubleFloatMatrix.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7150 create ComplexDoubleFloatMatrix.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ComplexDoubleFloatMatrix.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/ComplexDoubleFloatMatrix.help
-	@cp -f ${HELP}/ComplexDoubleFloatMatrix.help ${HELP}/CDFMAT.help
-	@${TANGLE} -R"ComplexDoubleFloatMatrix.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ComplexDoubleFloatMatrix.input
-	@echo "ComplexDoubleFloatMatrix (CDFMAT)" >>${HELPFILE}
-
-${HELP}/ComplexDoubleFloatVector.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7150 create ComplexDoubleFloatVector.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ComplexDoubleFloatVector.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/ComplexDoubleFloatVector.help
-	@cp -f ${HELP}/ComplexDoubleFloatVector.help ${HELP}/CDFVEC.help
-	@${TANGLE} -R"ComplexDoubleFloatVector.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ComplexDoubleFloatVector.input
-	@echo "ComplexDoubleFloatVector (CDFVEC)" >>${HELPFILE}
-
-${HELP}/ConvertibleTo.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ConvertibleTo.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ConvertibleTo.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ConvertibleTo.help
-	@cp -f ${HELP}/ConvertibleTo.help ${HELP}/KONVERT.help
-	@${TANGLE} -R"ConvertibleTo.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ConvertibleTo.input
-	@echo "ConvertibleTo (KONVERT)" >>${HELPFILE}
-
-${HELP}/CycleIndicators.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7160 create CycleIndicators.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"CycleIndicators.help" ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/CycleIndicators.help
-	@cp -f ${HELP}/CycleIndicators.help ${HELP}/CYCLES.help
-	@${TANGLE} -R"CycleIndicators.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/CycleIndicators.input
-	@echo "CycleIndicators (CYCLES)" >>${HELPFILE}
-
-${HELP}/Dequeue.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7190 create Dequeue.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Dequeue.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Dequeue.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Dequeue.help ${HELP}/DEQUEUE.help ; \
-	 fi
-	@${TANGLE} -R"Dequeue.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Dequeue.input
-	@echo "Dequeue (DEQUEUE)" >>${HELPFILE}
-
-${HELP}/DequeueAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DequeueAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DequeueAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DequeueAggregate.help
-	@cp -f ${HELP}/DequeueAggregate.help ${HELP}/DQAGG.help
-	@${TANGLE} -R"DequeueAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DequeueAggregate.input
-	@echo "DequeueAggregate (DQAGG)" >>${HELPFILE}
-
-${HELP}/DeRhamComplex.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7170 create DeRhamComplex.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DeRhamComplex.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/DeRhamComplex.help
-	@cp -f ${HELP}/DeRhamComplex.help ${HELP}/DERHAM.help
-	@${TANGLE} -R"DeRhamComplex.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DeRhamComplex.input
-	@echo "DeRhamComplex (DERHAM)" >>${HELPFILE}
-
-${HELP}/Database.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Database.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Database.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Database.help
-	@cp -f ${HELP}/Database.help ${HELP}/DBASE.help
-	@${TANGLE} -R"Database.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Database.input
-	@echo "Database (DBASE)" >>${HELPFILE}
-
-${HELP}/DataList.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create DataList.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DataList.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/DataList.help
-	@cp -f ${HELP}/DataList.help ${HELP}/DLIST.help
-	@${TANGLE} -R"DataList.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DataList.input
-	@echo "DataList (DLIST)" >>${HELPFILE}
-
-${HELP}/DecimalExpansion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7180 create DecimalExpansion.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DecimalExpansion.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/DecimalExpansion.help
-	@cp -f ${HELP}/DecimalExpansion.help ${HELP}/DECIMAL.help
-	@${TANGLE} -R"DecimalExpansion.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DecimalExpansion.input
-	@echo "DecimalExpansion (DECIMAL)" >>${HELPFILE}
-
-${HELP}/DesingTree.help: \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7295 create DesingTree.help \
-            from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DesingTree.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/DesingTree.help
-	@cp -f ${HELP}/DesingTree.help ${HELP}/DSTREE.help
-	@${TANGLE} -R"DesingTree.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DesingTree.input
-	@echo "DesingTree (DSTREE)" >>${HELPFILE}
-
-${HELP}/DesingTreeCategory.help: \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7296 create DesingTreeCategory.help \
-            from ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DesingTreeCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-            >${HELP}/DesingTreeCategory.help
-	@cp -f ${HELP}/DesingTreeCategory.help ${HELP}/DSTRCAT.help
-	@${TANGLE} -R"DesingTreeCategory.input" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DesingTreeCategory.input
-	@echo "DesingTreeCategory (DSTRCAT)" >>${HELPFILE}
-
-${HELP}/DesingTreePackage.help: \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7298 create DesingTreePackage.help \
-            from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"DesingTreePackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/DesingTreePackage.help
-	@cp -f ${HELP}/DesingTreePackage.help ${HELP}/DTP.help
-	@${TANGLE} -R"DesingTreePackage.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/DesingTreePackage.input
-	@echo "DesingTreePackage (DTP)" >>${HELPFILE}
-
-${HELP}/Dictionary.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Dictionary.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Dictionary.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Dictionary.help
-	@cp -f ${HELP}/Dictionary.help ${HELP}/DIAGG.help
-	@${TANGLE} -R"Dictionary.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Dictionary.input
-	@echo "Dictionary (DIAGG)" >>${HELPFILE}
-
-${HELP}/DictionaryOperations.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DictionaryOperations.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DictionaryOperations.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DictionaryOperations.help
-	@cp -f ${HELP}/DictionaryOperations.help ${HELP}/DIOPS.help
-	@${TANGLE} -R"DictionaryOperations.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DictionaryOperations.input
-	@echo "DictionaryOperations (DIOPS)" >>${HELPFILE}
-
-${HELP}/DifferentialExtension.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DifferentialExtension.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DifferentialExtension.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DifferentialExtension.help
-	@cp -f ${HELP}/DifferentialExtension.help ${HELP}/DIFEXT.help
-	@${TANGLE} -R"DifferentialExtension.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DifferentialExtension.input
-	@echo "DifferentialExtension (DIFEXT)" >>${HELPFILE}
-
-${HELP}/DifferentialPolynomialCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DifferentialPolynomialCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DifferentialPolynomialCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DifferentialPolynomialCategory.help
-	@cp -f ${HELP}/DifferentialPolynomialCategory.help ${HELP}/DPOLCAT.help
-	@${TANGLE} -R"DifferentialPolynomialCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DifferentialPolynomialCategory.input
-	@echo "DifferentialPolynomialCategory (DPOLCAT)" >>${HELPFILE}
-
-${HELP}/DifferentialRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DifferentialRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DifferentialRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DifferentialRing.help
-	@cp -f ${HELP}/DifferentialRing.help ${HELP}/DIFRING.help
-	@${TANGLE} -R"DifferentialRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DifferentialRing.input
-	@echo "DifferentialRing (DIFRING)" >>${HELPFILE}
-
-${HELP}/DifferentialSparseMultivariatePolynomial.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create DifferentialSparseMultivariatePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DifferentialSparseMultivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/DifferentialSparseMultivariatePolynomial.help
-	@cp -f ${HELP}/DifferentialSparseMultivariatePolynomial.help \
-            ${HELP}/DSMP.help
-	@${TANGLE} -R"DifferentialSparseMultivariatePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DifferentialSparseMultivariatePolynomial.input
-	@echo "DifferentialSparseMultivariatePolynomial (DSMP)" >>${HELPFILE}
-
-${HELP}/DifferentialVariableCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DifferentialVariableCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DifferentialVariableCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DifferentialVariableCategory.help
-	@cp -f ${HELP}/DifferentialVariableCategory.help ${HELP}/DVARCAT.help
-	@${TANGLE} -R"DifferentialVariableCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DifferentialVariableCategory.input
-	@echo "DifferentialVariableCategory (DVARCAT)" >>${HELPFILE}
-
-${HELP}/DirectProduct.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create DirectProduct.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DirectProduct.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/DirectProduct.help
-	@cp -f ${HELP}/DirectProduct.help ${HELP}/DIRPROD.help
-	@${TANGLE} -R"DirectProduct.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DirectProduct.input
-	@echo "DirectProduct (DIRPROD)" >>${HELPFILE}
-
-${HELP}/DirectProductCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DirectProductCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DirectProductCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DirectProductCategory.help
-	@cp -f ${HELP}/DirectProductCategory.help ${HELP}/DIRPCAT.help
-	@${TANGLE} -R"DirectProductCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DirectProductCategory.input
-	@echo "DirectProductCategory (DIRPCAT)" >>${HELPFILE}
-
-${HELP}/DirectProductMatrixModule.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create DirectProductMatrixModule.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DirectProductMatrixModule.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/DirectProductMatrixModule.help
-	@cp -f ${HELP}/DirectProductMatrixModule.help ${HELP}/DPMM.help
-	@${TANGLE} -R"DirectProductMatrixModule.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DirectProductMatrixModule.input
-	@echo "DirectProductMatrixModule (DPMM)" >>${HELPFILE}
-
-${HELP}/DirectProductModule.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create DirectProductModule.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DirectProductModule.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/DirectProductModule.help
-	@cp -f ${HELP}/DirectProductModule.help ${HELP}/DPMO.help
-	@${TANGLE} -R"DirectProductModule.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DirectProductModule.input
-	@echo "DirectProductModule (DPMO)" >>${HELPFILE}
-
-${HELP}/DirichletRing.help: \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7299 create DirichletRing.help \
-            from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DirichletRing.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/DirichletRing.help
-	@cp -f ${HELP}/DirichletRing.help ${HELP}/DIRRING.help
-	@${TANGLE} -R"DirichletRing.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DirichletRing.input
-	@echo "DirichletRing (DIRRING)" >>${HELPFILE}
-
-${HELP}/DistributedMultivariatePolynomial.help: \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7299 create DistributedMultivariatePolynomial.help \
-            from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DistributedMultivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/DistributedMultivariatePolynomial.help
-	@cp -f ${HELP}/DistributedMultivariatePolynomial.help ${HELP}/DMP.help
-	@${TANGLE} -R"DistributedMultivariatePolynomial.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DistributedMultivariatePolynomial.input
-	@echo "DistributedMultivariatePolynomial (DMP)" >>${HELPFILE}
-
-${HELP}/DivisionRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DivisionRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DivisionRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DivisionRing.help
-	@cp -f ${HELP}/DivisionRing.help ${HELP}/DIVRING.help
-	@${TANGLE} -R"DivisionRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DivisionRing.input
-	@echo "DivisionRing (DIVRING)" >>${HELPFILE}
-
-${HELP}/Divisor.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7205 create Divisor.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Divisor.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Divisor.help
-	@cp -f ${HELP}/Divisor.help ${HELP}/DIV.help
-	@${TANGLE} -R"Divisor.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Divisor.input
-	@echo "Divisor (DIV)" >>${HELPFILE}
-
-${HELP}/DivisorCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7207 create DivisorCategory.help from \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DivisorCategory.help" ${BOOKS}/bookvol10.2.pamphlet \
-            >${HELP}/DivisorCategory.help
-	@cp -f ${HELP}/DivisorCategory.help ${HELP}/DIVCAT.help
-	@${TANGLE} -R"DivisorCategory.input" ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DivisorCategory.input
-	@echo "DivisorCategory (DIVCAT)" >>${HELPFILE}
-
-${HELP}/DoubleFloat.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7210 create DoubleFloat.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DoubleFloat.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/DoubleFloat.help
-	@cp -f ${HELP}/DoubleFloat.help ${HELP}/DFLOAT.help
-	@${TANGLE} -R"DoubleFloat.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DoubleFloat.input
-	@echo "DoubleFloat (DFLOAT)" >>${HELPFILE}
-
-${HELP}/DoubleFloatMatrix.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7210 create DoubleFloatMatrix.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DoubleFloatMatrix.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/DoubleFloatMatrix.help
-	@cp -f ${HELP}/DoubleFloatMatrix.help ${HELP}/DFMAT.help
-	@${TANGLE} -R"DoubleFloatMatrix.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DoubleFloatMatrix.input
-	@echo "DoubleFloatMatrix (DFMAT)" >>${HELPFILE}
-
-${HELP}/DoubleFloatSpecialFunctions.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7210 create DoubleFloatSpecialFunctions.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"DoubleFloatSpecialFunctions.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/DoubleFloatSpecialFunctions.help
-	@cp -f ${HELP}/DoubleFloatSpecialFunctions.help ${HELP}/DFSFUN.help
-	@${TANGLE} -R"DoubleFloatSpecialFunctions.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/DoubleFloatSpecialFunctions.input
-	@echo "DoubleFloatSpecialFunctions (DFSFUN)" >>${HELPFILE}
-
-${HELP}/DoubleFloatVector.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7210 create DoubleFloatVector.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DoubleFloatVector.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/DoubleFloatVector.help
-	@cp -f ${HELP}/DoubleFloatVector.help ${HELP}/DFVEC.help
-	@${TANGLE} -R"DoubleFloatVector.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DoubleFloatVector.input
-	@echo "DoubleFloatVector (DFVEC)" >>${HELPFILE}
-
-${HELP}/DoublyLinkedAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create DoublyLinkedAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"DoublyLinkedAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/DoublyLinkedAggregate.help
-	@cp -f ${HELP}/DoublyLinkedAggregate.help ${HELP}/DLAGG.help
-	@${TANGLE} -R"DoublyLinkedAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/DoublyLinkedAggregate.input
-	@echo "DoublyLinkedAggregate (DLAGG)" >>${HELPFILE}
-
-${HELP}/DrawOption.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create DrawOption.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"DrawOption.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/DrawOption.help
-	@cp -f ${HELP}/DrawOption.help ${HELP}/DROPT.help
-	@${TANGLE} -R"DrawOption.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/DrawOption.input
-	@echo "DrawOption (DROPT)" >>${HELPFILE}
-
-${HELP}/d01ajfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01ajfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01ajfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01ajfAnnaType.help
-	@cp -f ${HELP}/d01ajfAnnaType.help ${HELP}/D01AJFA.help
-	@${TANGLE} -R"d01ajfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01ajfAnnaType.input
-	@echo "d01ajfAnnaType (D01AJFA)" >>${HELPFILE}
-
-${HELP}/d01akfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01akfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01akfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01akfAnnaType.help
-	@cp -f ${HELP}/d01akfAnnaType.help ${HELP}/D01AKFA.help
-	@${TANGLE} -R"d01akfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01akfAnnaType.input
-	@echo "d01akfAnnaType (D01AKFA)" >>${HELPFILE}
-
-${HELP}/d01alfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01alfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01alfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01alfAnnaType.help
-	@cp -f ${HELP}/d01alfAnnaType.help ${HELP}/D01ALFA.help
-	@${TANGLE} -R"d01alfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01alfAnnaType.input
-	@echo "d01alfAnnaType (D01ALFA)" >>${HELPFILE}
-
-${HELP}/d01amfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01amfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01amfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01amfAnnaType.help
-	@cp -f ${HELP}/d01amfAnnaType.help ${HELP}/D01AMFA.help
-	@${TANGLE} -R"d01amfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01amfAnnaType.input
-	@echo "d01amfAnnaType (D01AMFA)" >>${HELPFILE}
-
-${HELP}/d01anfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01anfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01anfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01anfAnnaType.help
-	@cp -f ${HELP}/d01anfAnnaType.help ${HELP}/D01ANFA.help
-	@${TANGLE} -R"d01anfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01anfAnnaType.input
-	@echo "d01anfAnnaType (D01ANFA)" >>${HELPFILE}
-
-${HELP}/d01apfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01apfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01apfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01apfAnnaType.help
-	@cp -f ${HELP}/d01apfAnnaType.help ${HELP}/D01APFA.help
-	@${TANGLE} -R"d01apfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01apfAnnaType.input
-	@echo "d01apfAnnaType (D01APFA)" >>${HELPFILE}
-
-${HELP}/d01aqfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01aqfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01aqfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01aqfAnnaType.help
-	@cp -f ${HELP}/d01aqfAnnaType.help ${HELP}/D01AQFA.help
-	@${TANGLE} -R"d01aqfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01aqfAnnaType.input
-	@echo "d01aqfAnnaType (D01AQFA)" >>${HELPFILE}
-
-${HELP}/d01asfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01asfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01asfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01asfAnnaType.help
-	@cp -f ${HELP}/d01asfAnnaType.help ${HELP}/D01ASFA.help
-	@${TANGLE} -R"d01asfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01asfAnnaType.input
-	@echo "d01asfAnnaType (D01ASFA)" >>${HELPFILE}
-
-${HELP}/d01fcfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01fcfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01fcfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01fcfAnnaType.help
-	@cp -f ${HELP}/d01fcfAnnaType.help ${HELP}/D01FCFA.help
-	@${TANGLE} -R"d01fcfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01fcfAnnaType.input
-	@echo "d01fcfAnnaType (D01FCFA)" >>${HELPFILE}
-
-${HELP}/d01gbfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01gbfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01gbfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01gbfAnnaType.help
-	@cp -f ${HELP}/d01gbfAnnaType.help ${HELP}/D01GBFA.help
-	@${TANGLE} -R"d01gbfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01gbfAnnaType.input
-	@echo "d01gbfAnnaType (D01GBFA)" >>${HELPFILE}
-
-${HELP}/d01TransformFunctionType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d01TransformFunctionType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d01TransformFunctionType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d01TransformFunctionType.help
-	@cp -f ${HELP}/d01TransformFunctionType.help ${HELP}/D01TRNS.help
-	@${TANGLE} -R"d01TransformFunctionType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d01TransformFunctionType.input
-	@echo "d01TransformFunctionType (D01TRNS)" >>${HELPFILE}
-
-${HELP}/d02bbfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d02bbfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d02bbfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d02bbfAnnaType.help
-	@cp -f ${HELP}/d02bbfAnnaType.help ${HELP}/D02BBFA.help
-	@${TANGLE} -R"d02bbfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d02bbfAnnaType.input
-	@echo "d02bbfAnnaType (D02BBFA)" >>${HELPFILE}
-
-${HELP}/d02bhfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d02bhfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d02bhfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d02bhfAnnaType.help
-	@cp -f ${HELP}/d02bhfAnnaType.help ${HELP}/D02BHFA.help
-	@${TANGLE} -R"d02bhfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d02bhfAnnaType.input
-	@echo "d02bhfAnnaType (D02BHFA)" >>${HELPFILE}
-
-${HELP}/d02cjfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d02cjfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d02cjfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d02cjfAnnaType.help
-	@cp -f ${HELP}/d02cjfAnnaType.help ${HELP}/D02CJFA.help
-	@${TANGLE} -R"d02cjfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d02cjfAnnaType.input
-	@echo "d02cjfAnnaType (D02CJFA)" >>${HELPFILE}
-
-${HELP}/d02ejfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d02ejfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d02ejfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d02ejfAnnaType.help
-	@cp -f ${HELP}/d02ejfAnnaType.help ${HELP}/D02EJFA.help
-	@${TANGLE} -R"d02ejfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d02ejfAnnaType.input
-	@echo "d02ejfAnnaType (D02EJFA)" >>${HELPFILE}
-
-${HELP}/d03eefAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d03eefAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d03eefAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d03eefAnnaType.help
-	@cp -f ${HELP}/d03eefAnnaType.help ${HELP}/D03EEFA.help
-	@${TANGLE} -R"d03eefAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d03eefAnnaType.input
-	@echo "d03eefAnnaType (D03EEFA)" >>${HELPFILE}
-
-${HELP}/d03fafAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create d03fafAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"d03fafAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/d03fafAnnaType.help
-	@cp -f ${HELP}/d03fafAnnaType.help ${HELP}/D03FAFA.help
-	@${TANGLE} -R"d03fafAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/d03fafAnnaType.input
-	@echo "d03fafAnnaType (D03FAFA)" >>${HELPFILE}
-
-${HELP}/ElementaryFunction.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7220 create ElementaryFunction.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"ElementaryFunction.help" ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/ElementaryFunction.help
-	@cp -f ${HELP}/ElementaryFunction.help ${HELP}/EF.help
-	@${TANGLE} -R"ElementaryFunction.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/ElementaryFunction.input
-	@echo "ElementaryFunction (EF)" >>${HELPFILE}
-
-${HELP}/ElementaryFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ElementaryFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ElementaryFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ElementaryFunctionCategory.help
-	@cp -f ${HELP}/ElementaryFunctionCategory.help ${HELP}/ELEMFUN.help
-	@${TANGLE} -R"ElementaryFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ElementaryFunctionCategory.input
-	@echo "ElementaryFunctionCategory (ELEMFUN)" >>${HELPFILE}
-
-${HELP}/Eltable.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Eltable.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Eltable.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Eltable.help
-	@cp -f ${HELP}/Eltable.help ${HELP}/ELTAB.help
-	@${TANGLE} -R"Eltable.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Eltable.input
-	@echo "Eltable (ELTAB)" >>${HELPFILE}
-
-${HELP}/EltableAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create EltableAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"EltableAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/EltableAggregate.help
-	@cp -f ${HELP}/EltableAggregate.help ${HELP}/ELTAGG.help
-	@${TANGLE} -R"EltableAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/EltableAggregate.input
-	@echo "EltableAggregate (ELTAGG)" >>${HELPFILE}
-
-${HELP}/EntireRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create EntireRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"EntireRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/EntireRing.help
-	@cp -f ${HELP}/EntireRing.help ${HELP}/ENTIRER.help
-	@${TANGLE} -R"EntireRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/EntireRing.input
-	@echo "EntireRing (ENTIRER)" >>${HELPFILE}
-
-${HELP}/EqTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7230 create EqTable.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"EqTable.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/EqTable.help
-	@cp -f ${HELP}/EqTable.help ${HELP}/EQTBL.help
-	@${TANGLE} -R"EqTable.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/EqTable.input
-	@echo "EqTable (EQTBL)" >>${HELPFILE}
-
-${HELP}/Equation.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7240 create Equation.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Equation.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Equation.help
-	@cp -f ${HELP}/Equation.help ${HELP}/EQ.help
-	@${TANGLE} -R"Equation.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Equation.input
-	@echo "Equation (EQ)" >>${HELPFILE}
-
-${HELP}/Export3D.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 5000 create Export3D.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"Export3D.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/Export3D.help
-	@cp -f ${HELP}/Export3D.help ${HELP}/EXP3D.help
-	@${TANGLE} -R"Export3D.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/Export3D.input
-	@echo "Export3D (EXP3D)" >>${HELPFILE}
-
-${HELP}/ExpressionSpace.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ExpressionSpace.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ExpressionSpace.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ExpressionSpace.help
-	@cp -f ${HELP}/ExpressionSpace.help ${HELP}/ES.help
-	@${TANGLE} -R"ExpressionSpace.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ExpressionSpace.input
-	@echo "ExpressionSpace (ES)" >>${HELPFILE}
-
-${HELP}/ExtensibleLinearAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ExtensibleLinearAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ExtensibleLinearAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ExtensibleLinearAggregate.help
-	@cp -f ${HELP}/ExtensibleLinearAggregate.help ${HELP}/ELAGG.help
-	@${TANGLE} -R"ExtensibleLinearAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ExtensibleLinearAggregate.input
-	@echo "ExtensibleLinearAggregate (ELAGG)" >>${HELPFILE}
-
-${HELP}/EuclideanGroebnerBasisPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7250 create EuclideanGroebnerBasisPackage.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"EuclideanGroebnerBasisPackage.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/EuclideanGroebnerBasisPackage.help
-	@cp -f ${HELP}/EuclideanGroebnerBasisPackage.help ${HELP}/GBEUCLID.help
-	@${TANGLE} -R"EuclideanGroebnerBasisPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/EuclideanGroebnerBasisPackage.input
-	@echo "EuclideanGroebnerBasisPackage (GBEUCLID)" >>${HELPFILE}
-
-${HELP}/EuclideanDomain.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create EuclideanDomain.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"EuclideanDomain.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/EuclideanDomain.help
-	@cp -f ${HELP}/EuclideanDomain.help ${HELP}/EUCDOM.help
-	@${TANGLE} -R"EuclideanDomain.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/EuclideanDomain.input
-	@echo "EuclideanDomain (EUCDOM)" >>${HELPFILE}
-
-${HELP}/EuclideanModularRing.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create EuclideanModularRing.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"EuclideanModularRing.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/EuclideanModularRing.help
-	@cp -f ${HELP}/EuclideanModularRing.help ${HELP}/EMR.help
-	@${TANGLE} -R"EuclideanModularRing.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/EuclideanModularRing.input
-	@echo "EuclideanModularRing (EMR)" >>${HELPFILE}
-
-${HELP}/Evalable.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Evalable.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Evalable.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Evalable.help
-	@cp -f ${HELP}/Evalable.help ${HELP}/EVALAB.help
-	@${TANGLE} -R"Evalable.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Evalable.input
-	@echo "Evalable (EVALAB)" >>${HELPFILE}
-
-${HELP}/Expression.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7260 create Expression.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Expression.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Expression.help
-	@cp -f ${HELP}/Expression.help ${HELP}/EXPR.help
-	@${TANGLE} -R"Expression.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Expression.input
-	@echo "Expression (EXPR)" >>${HELPFILE}
-
-${HELP}/ExponentialExpansion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ExponentialExpansion.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ExponentialExpansion.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ExponentialExpansion.help
-	@cp -f ${HELP}/ExponentialExpansion.help ${HELP}/EXPEXPAN.help
-	@${TANGLE} -R"ExponentialExpansion.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ExponentialExpansion.input
-	@echo "ExponentialExpansion (EXPEXPAN)" >>${HELPFILE}
-
-${HELP}/ExponentialOfUnivariatePuiseuxSeries.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ExponentialOfUnivariatePuiseuxSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ExponentialOfUnivariatePuiseuxSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ExponentialOfUnivariatePuiseuxSeries.help
-	@cp -f ${HELP}/ExponentialOfUnivariatePuiseuxSeries.help \
-           ${HELP}/EXPUPXS.help
-	@${TANGLE} -R"ExponentialOfUnivariatePuiseuxSeries.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/ExponentialOfUnivariatePuiseuxSeries.input
-	@echo "ExponentialOfUnivariatePuiseuxSeries (EXPUPXS)" >>${HELPFILE}
-
-${HELP}/ExtAlgBasis.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ExtAlgBasis.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ExtAlgBasis.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ExtAlgBasis.help
-	@cp -f ${HELP}/ExtAlgBasis.help ${HELP}/EAB.help
-	@${TANGLE} -R"ExtAlgBasis.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ExtAlgBasis.input
-	@echo "ExtAlgBasis (EAB)" >>${HELPFILE}
-
-${HELP}/ExtensionField.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ExtensionField.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ExtensionField.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ExtensionField.help
-	@cp -f ${HELP}/ExtensionField.help ${HELP}/XF.help
-	@${TANGLE} -R"ExtensionField.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ExtensionField.input
-	@echo "ExtensionField (XF)" >>${HELPFILE}
-
-${HELP}/e04dgfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create e04dgfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"e04dgfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/e04dgfAnnaType.help
-	@cp -f ${HELP}/e04dgfAnnaType.help ${HELP}/E04DGFA.help
-	@${TANGLE} -R"e04dgfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/e04dgfAnnaType.input
-	@echo "e04dgfAnnaType (E04DGFA)" >>${HELPFILE}
-
-${HELP}/e04fdfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create e04fdfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"e04fdfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/e04fdfAnnaType.help
-	@cp -f ${HELP}/e04fdfAnnaType.help ${HELP}/E04FDFA.help
-	@${TANGLE} -R"e04fdfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/e04fdfAnnaType.input
-	@echo "e04fdfAnnaType (E04FDFA)" >>${HELPFILE}
-
-${HELP}/e04gcfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create e04gcfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"e04gcfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/e04gcfAnnaType.help
-	@cp -f ${HELP}/e04gcfAnnaType.help ${HELP}/E04GCFA.help
-	@${TANGLE} -R"e04gcfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/e04gcfAnnaType.input
-	@echo "e04gcfAnnaType (E04GCFA)" >>${HELPFILE}
-
-${HELP}/e04jafAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create e04jafAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"e04jafAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/e04jafAnnaType.help
-	@cp -f ${HELP}/e04jafAnnaType.help ${HELP}/E04JAFA.help
-	@${TANGLE} -R"e04jafAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/e04jafAnnaType.input
-	@echo "e04jafAnnaType (E04JAFA)" >>${HELPFILE}
-
-${HELP}/e04mbfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create e04mbfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"e04mbfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/e04mbfAnnaType.help
-	@cp -f ${HELP}/e04mbfAnnaType.help ${HELP}/E04MBFA.help
-	@${TANGLE} -R"e04mbfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/e04mbfAnnaType.input
-	@echo "e04mbfAnnaType (E04MBFA)" >>${HELPFILE}
-
-${HELP}/e04nafAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create e04nafAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"e04nafAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/e04nafAnnaType.help
-	@cp -f ${HELP}/e04nafAnnaType.help ${HELP}/E04NAFA.help
-	@${TANGLE} -R"e04nafAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/e04nafAnnaType.input
-	@echo "e04nafAnnaType (E04NAFA)" >>${HELPFILE}
-
-${HELP}/e04ucfAnnaType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create e04ucfAnnaType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"e04ucfAnnaType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/e04ucfAnnaType.help
-	@cp -f ${HELP}/e04ucfAnnaType.help ${HELP}/E04UCFA.help
-	@${TANGLE} -R"e04ucfAnnaType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/e04ucfAnnaType.input
-	@echo "e04ucfAnnaType (E04UCFA)" >>${HELPFILE}
-
-${HELP}/Factored.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7270 create Factored.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Factored.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Factored.help
-	@cp -f ${HELP}/Factored.help ${HELP}/FR.help
-	@${TANGLE} -R"Factored.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Factored.input
-	@echo "Factored (FR)" >>${HELPFILE}
-
-${HELP}/FactoredFunctions2.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7280 create FactoredFunctions2.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"FactoredFunctions2.help" ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/FactoredFunctions2.help
-	@cp -f ${HELP}/FactoredFunctions2.help ${HELP}/FR2.help
-	@${TANGLE} -R"FactoredFunctions2.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/FactoredFunctions2.input
-	@echo "FactoredFunctions2 (FR2)" >>${HELPFILE}
-
-${HELP}/FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.help: \
-         ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7283 create \
-    FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} \
-    -R"FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-  >${HELP}/FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.help
-	@cp \
- ${HELP}/FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.help \
-         ${HELP}/FACTEXT.help
-	@${TANGLE} \
-    -R"FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.input" \
-         ${BOOKS}/bookvol10.4.pamphlet \
->${INPUT}/FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber.input
-	@echo \
- "FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber (FACTEXT)" \
-           >>${HELPFILE}
-
-${HELP}/FactorisationOverPseudoAlgebraicClosureOfRationalNumber.help: \
-         ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7285 create \
-            FactorisationOverPseudoAlgebraicClosureOfRationalNumber.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} \
-            -R"FactorisationOverPseudoAlgebraicClosureOfRationalNumber.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-          >${HELP}/FactorisationOverPseudoAlgebraicClosureOfRationalNumber.help
-	@cp -f \
-         ${HELP}/FactorisationOverPseudoAlgebraicClosureOfRationalNumber.help \
-         ${HELP}/FACTRN.help
-	@${TANGLE} \
-         -R"FactorisationOverPseudoAlgebraicClosureOfRationalNumber.input" \
-         ${BOOKS}/bookvol10.4.pamphlet \
-        >${INPUT}/FactorisationOverPseudoAlgebraicClosureOfRationalNumber.input
-	@echo \
-          "FactorisationOverPseudoAlgebraicClosureOfRationalNumber (FACTRN)" \
-           >>${HELPFILE}
-
-${HELP}/Field.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Field.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Field.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Field.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Field.help ${HELP}/FIELD.help ; \
-	 fi
-	@${TANGLE} -R"Field.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Field.input
-	@echo "Field (FIELD)" >>${HELPFILE}
-
-${HELP}/FieldOfPrimeCharacteristic.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FieldOfPrimeCharacteristic.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FieldOfPrimeCharacteristic.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FieldOfPrimeCharacteristic.help
-	@cp -f ${HELP}/FieldOfPrimeCharacteristic.help ${HELP}/FPC.help
-	@${TANGLE} -R"FieldOfPrimeCharacteristic.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FieldOfPrimeCharacteristic.input
-	@echo "FieldOfPrimeCharacteristic (FPC)" >>${HELPFILE}
-
-${HELP}/File.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7290 create File.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"File.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/File.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/File.help ${HELP}/FILE.help ; \
-	 fi
-	@${TANGLE} -R"File.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/File.input
-	@echo "File (FILE)" >>${HELPFILE}
-
-${HELP}/FileCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FileCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FileCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FileCategory.help
-	@cp -f ${HELP}/FileCategory.help ${HELP}/FILECAT.help
-	@${TANGLE} -R"FileCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FileCategory.input
-	@echo "FileCategory (FILECAT)" >>${HELPFILE}
-
-${HELP}/FileName.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7300 create FileName.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FileName.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FileName.help
-	@cp -f ${HELP}/FileName.help ${HELP}/FNAME.help
-	@${TANGLE} -R"FileName.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FileName.input
-	@echo "FileName (FNAME)" >>${HELPFILE}
-
-${HELP}/FileNameCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FileNameCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FileNameCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FileNameCategory.help
-	@cp -f ${HELP}/FileNameCategory.help ${HELP}/FNCAT.help
-	@${TANGLE} -R"FileNameCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FileNameCategory.input
-	@echo "FileNameCategory (FNCAT)" >>${HELPFILE}
-
-${HELP}/Finite.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Finite.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Finite.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Finite.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Finite.help ${HELP}/FINITE.help ; \
-	 fi
-	@${TANGLE} -R"Finite.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Finite.input
-	@echo "Finite (FINITE)" >>${HELPFILE}
-
-${HELP}/FiniteAbelianMonoidRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FiniteAbelianMonoidRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FiniteAbelianMonoidRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FiniteAbelianMonoidRing.help
-	@cp -f ${HELP}/FiniteAbelianMonoidRing.help ${HELP}/FAMR.help
-	@${TANGLE} -R"FiniteAbelianMonoidRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FiniteAbelianMonoidRing.input
-	@echo "FiniteAbelianMonoidRing (FAMR)" >>${HELPFILE}
-
-${HELP}/FiniteAlgebraicExtensionField.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FiniteAlgebraicExtensionField.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FiniteAlgebraicExtensionField.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FiniteAlgebraicExtensionField.help
-	@cp -f ${HELP}/FiniteAlgebraicExtensionField.help ${HELP}/FAXF.help
-	@${TANGLE} -R"FiniteAlgebraicExtensionField.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FiniteAlgebraicExtensionField.input
-	@echo "FiniteAlgebraicExtensionField (FAXF)" >>${HELPFILE}
-
-${HELP}/FiniteDivisor.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteDivisor.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteDivisor.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteDivisor.help
-	@cp -f ${HELP}/FiniteDivisor.help ${HELP}/FDIV.help
-	@${TANGLE} -R"FiniteDivisor.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FiniteDivisor.input
-	@echo "FiniteDivisor (FDIV)" >>${HELPFILE}
-
-${HELP}/FiniteDivisorCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FiniteDivisorCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FiniteDivisorCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FiniteDivisorCategory.help
-	@cp -f ${HELP}/FiniteDivisorCategory.help ${HELP}/FDIVCAT.help
-	@${TANGLE} -R"FiniteDivisorCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FiniteDivisorCategory.input
-	@echo "FiniteDivisorCategory (FDIVCAT)" >>${HELPFILE}
-
-${HELP}/FiniteField.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteField.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteField.help
-	@cp -f ${HELP}/FiniteField.help ${HELP}/FF.help
-	@${TANGLE} -R"FiniteField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FiniteField.input
-	@echo "FiniteField (FF)" >>${HELPFILE}
-
-${HELP}/FiniteFieldCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FiniteFieldCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FiniteFieldCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FiniteFieldCategory.help
-	@cp -f ${HELP}/FiniteFieldCategory.help ${HELP}/FFIELDC.help
-	@${TANGLE} -R"FiniteFieldCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FiniteFieldCategory.input
-	@echo "FiniteFieldCategory (FFIELDC)" >>${HELPFILE}
-
-${HELP}/FiniteFieldCyclicGroup.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteFieldCyclicGroup.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteFieldCyclicGroup.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteFieldCyclicGroup.help
-	@cp -f ${HELP}/FiniteFieldCyclicGroup.help ${HELP}/FFCG.help
-	@${TANGLE} -R"FiniteFieldCyclicGroup.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FiniteFieldCyclicGroup.input
-	@echo "FiniteFieldCyclicGroup (FFCG)" >>${HELPFILE}
-
-${HELP}/FiniteFieldCyclicGroupExtension.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteFieldCyclicGroupExtension.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteFieldCyclicGroupExtension.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteFieldCyclicGroupExtension.help
-	@cp -f ${HELP}/FiniteFieldCyclicGroupExtension.help ${HELP}/FFCGX.help
-	@${TANGLE} -R"FiniteFieldCyclicGroupExtension.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FiniteFieldCyclicGroupExtension.input
-	@echo "FiniteFieldCyclicGroupExtension (FFCGX)" >>${HELPFILE}
-
-${HELP}/FiniteFieldCyclicGroupExtensionByPolynomial.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteFieldCyclicGroupExtensionByPolynomial.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteFieldCyclicGroupExtensionByPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteFieldCyclicGroupExtensionByPolynomial.help
-	@cp -f ${HELP}/FiniteFieldCyclicGroupExtensionByPolynomial.help \
-           ${HELP}/FFCGP.help
-	@${TANGLE} -R"FiniteFieldCyclicGroupExtensionByPolynomial.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/FiniteFieldCyclicGroupExtensionByPolynomial.input
-	@echo "FiniteFieldCyclicGroupExtensionByPolynomial (FFCGP)" \
-           >>${HELPFILE}
-
-${HELP}/FiniteFieldExtension.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteFieldExtension.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteFieldExtension.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteFieldExtension.help
-	@cp -f ${HELP}/FiniteFieldExtension.help ${HELP}/FFX.help
-	@${TANGLE} -R"FiniteFieldExtension.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FiniteFieldExtension.input
-	@echo "FiniteFieldExtension (FFX)" >>${HELPFILE}
-
-${HELP}/FiniteFieldExtensionByPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteFieldExtensionByPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteFieldExtensionByPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteFieldExtensionByPolynomial.help
-	@cp -f ${HELP}/FiniteFieldExtensionByPolynomial.help ${HELP}/FFP.help
-	@${TANGLE} -R"FiniteFieldExtensionByPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FiniteFieldExtensionByPolynomial.input
-	@echo "FiniteFieldExtensionByPolynomial (FFP)" >>${HELPFILE}
-
-${HELP}/FiniteFieldFactorizationWithSizeParseBySideEffect.help: \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7303 create \
-           FiniteFieldFactorizationWithSizeParseBySideEffect.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"FiniteFieldFactorizationWithSizeParseBySideEffect.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/FiniteFieldFactorizationWithSizeParseBySideEffect.help
-	@cp -f ${HELP}/FiniteFieldFactorizationWithSizeParseBySideEffect.help \
-            ${HELP}/FFFACTSE.help
-	@${TANGLE} \
-            -R"FiniteFieldFactorizationWithSizeParseBySideEffect.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/FiniteFieldFactorizationWithSizeParseBySideEffect.input
-	@echo "FiniteFieldFactorizationWithSizeParseBySideEffect (FFFACTSE)"\
-            >>${HELPFILE}
-
-${HELP}/FiniteFieldNormalBasis.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteFieldNormalBasis.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteFieldNormalBasis.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteFieldNormalBasis.help
-	@cp -f ${HELP}/FiniteFieldNormalBasis.help ${HELP}/FFNB.help
-	@${TANGLE} -R"FiniteFieldNormalBasis.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FiniteFieldNormalBasis.input
-	@echo "FiniteFieldNormalBasis (FFNB)" >>${HELPFILE}
-
-${HELP}/FiniteFieldNormalBasisExtension.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteFieldNormalBasisExtension.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteFieldNormalBasisExtension.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteFieldNormalBasisExtension.help
-	@cp -f ${HELP}/FiniteFieldNormalBasisExtension.help ${HELP}/FFNBX.help
-	@${TANGLE} -R"FiniteFieldNormalBasisExtension.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FiniteFieldNormalBasisExtension.input
-	@echo "FiniteFieldNormalBasisExtension (FFNBX)" >>${HELPFILE}
-
-${HELP}/FiniteFieldNormalBasisExtensionByPolynomial.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FiniteFieldNormalBasisExtensionByPolynomial.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FiniteFieldNormalBasisExtensionByPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FiniteFieldNormalBasisExtensionByPolynomial.help
-	@cp -f ${HELP}/FiniteFieldNormalBasisExtensionByPolynomial.help \
-           ${HELP}/FFNBP.help
-	@${TANGLE} -R"FiniteFieldNormalBasisExtensionByPolynomial.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/FiniteFieldNormalBasisExtensionByPolynomial.input
-	@echo "FiniteFieldNormalBasisExtensionByPolynomial (FFNBP)" \
-          >>${HELPFILE}
-
-${HELP}/FiniteFieldSquareFreeDecomposition.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7305 create FiniteFieldSquareFreeDecomposition.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"FiniteFieldSquareFreeDecomposition.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/FiniteFieldSquareFreeDecomposition.help
-	@cp -f ${HELP}/FiniteFieldSquareFreeDecomposition.help \
-            ${HELP}/FFSQFR.help
-	@${TANGLE} -R"FiniteFieldSquareFreeDecomposition.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/FiniteFieldSquareFreeDecomposition.input
-	@echo "FiniteFieldSquareFreeDecomposition (FFSQFR)" >>${HELPFILE}
-
-${HELP}/FiniteLinearAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FiniteLinearAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FiniteLinearAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FiniteLinearAggregate.help
-	@cp -f ${HELP}/FiniteLinearAggregate.help ${HELP}/FLAGG.help
-	@${TANGLE} -R"FiniteLinearAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FiniteLinearAggregate.input
-	@echo "FiniteLinearAggregate (FLAGG)" >>${HELPFILE}
-
-${HELP}/FiniteRankAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FiniteRankAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FiniteRankAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FiniteRankAlgebra.help
-	@cp -f ${HELP}/FiniteRankAlgebra.help ${HELP}/FINRALG.help
-	@${TANGLE} -R"FiniteRankAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FiniteRankAlgebra.input
-	@echo "FiniteRankAlgebra (FINRALG)" >>${HELPFILE}
-
-${HELP}/FiniteRankNonAssociativeAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FiniteRankNonAssociativeAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FiniteRankNonAssociativeAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FiniteRankNonAssociativeAlgebra.help
-	@cp -f ${HELP}/FiniteRankNonAssociativeAlgebra.help \
-            ${HELP}/FINAALG.help
-	@${TANGLE} -R"FiniteRankNonAssociativeAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FiniteRankNonAssociativeAlgebra.input
-	@echo "FiniteRankNonAssociativeAlgebra (FINAALG)" >>${HELPFILE}
-
-${HELP}/FiniteSetAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FiniteSetAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FiniteSetAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FiniteSetAggregate.help
-	@cp -f ${HELP}/FiniteSetAggregate.help ${HELP}/FSAGG.help
-	@${TANGLE} -R"FiniteSetAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FiniteSetAggregate.input
-	@echo "FiniteSetAggregate (FSAGG)" >>${HELPFILE}
-
-${HELP}/FlexibleArray.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7310 create FlexibleArray.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FlexibleArray.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FlexibleArray.help
-	@cp -f ${HELP}/FlexibleArray.help ${HELP}/FARRAY.help
-	@${TANGLE} -R"FlexibleArray.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FlexibleArray.input
-	@echo "FlexibleArray (FARRAY)" >>${HELPFILE}
-
-${HELP}/Float.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7320 create Float.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Float.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Float.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Float.help ${HELP}/FLOAT.help ; \
-	 fi
-	@${TANGLE} -R"Float.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Float.input
-	@echo "Float (FLOAT)" >>${HELPFILE}
-
-${HELP}/FloatingPointSystem.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FloatingPointSystem.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FloatingPointSystem.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FloatingPointSystem.help
-	@cp -f ${HELP}/FloatingPointSystem.help ${HELP}/FPS.help
-	@${TANGLE} -R"FloatingPointSystem.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FloatingPointSystem.input
-	@echo "FloatingPointSystem (FPS)" >>${HELPFILE}
-
-${HELP}/FortranCode.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FortranCode.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FortranCode.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FortranCode.help
-	@cp -f ${HELP}/FortranCode.help ${HELP}/FC.help
-	@${TANGLE} -R"FortranCode.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FortranCode.input
-	@echo "FortranCode (FC)" >>${HELPFILE}
-
-${HELP}/FortranExpression.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FortranExpression.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FortranExpression.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FortranExpression.help
-	@cp -f ${HELP}/FortranExpression.help ${HELP}/FEXPR.help
-	@${TANGLE} -R"FortranExpression.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FortranExpression.input
-	@echo "FortranExpression (FEXPR)" >>${HELPFILE}
-
-${HELP}/FortranFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FortranFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FortranFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FortranFunctionCategory.help
-	@cp -f ${HELP}/FortranFunctionCategory.help ${HELP}/FORFN.help
-	@${TANGLE} -R"FortranFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FortranFunctionCategory.input
-	@echo "FortranFunctionCategory (FORFN)" >>${HELPFILE}
-
-${HELP}/FortranMachineTypeCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FortranMachineTypeCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FortranMachineTypeCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FortranMachineTypeCategory.help
-	@cp -f ${HELP}/FortranMachineTypeCategory.help ${HELP}/FMTC.help
-	@${TANGLE} -R"FortranMachineTypeCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FortranMachineTypeCategory.input
-	@echo "FortranMachineTypeCategory (FMTC)" >>${HELPFILE}
-
-${HELP}/FortranMatrixCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FortranMatrixCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FortranMatrixCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FortranMatrixCategory.help
-	@cp -f ${HELP}/FortranMatrixCategory.help ${HELP}/FMC.help
-	@${TANGLE} -R"FortranMatrixCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FortranMatrixCategory.input
-	@echo "FortranMatrixCategory (FMC)" >>${HELPFILE}
-
-${HELP}/FortranMatrixFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FortranMatrixFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FortranMatrixFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FortranMatrixFunctionCategory.help
-	@cp -f ${HELP}/FortranMatrixFunctionCategory.help ${HELP}/FMFUN.help
-	@${TANGLE} -R"FortranMatrixFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FortranMatrixFunctionCategory.input
-	@echo "FortranMatrixFunctionCategory (FMFUN)" >>${HELPFILE}
-
-${HELP}/FortranProgram.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FortranProgram.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FortranProgram.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FortranProgram.help
-	@cp -f ${HELP}/FortranProgram.help ${HELP}/FORTRAN.help
-	@${TANGLE} -R"FortranProgram.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FortranProgram.input
-	@echo "FortranProgram (FORTRAN)" >>${HELPFILE}
-
-${HELP}/FortranProgramCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FortranProgramCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FortranProgramCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FortranProgramCategory.help
-	@cp -f ${HELP}/FortranProgramCategory.help ${HELP}/FORTCAT.help
-	@${TANGLE} -R"FortranProgramCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FortranProgramCategory.input
-	@echo "FortranProgramCategory (FORTCAT)" >>${HELPFILE}
-
-${HELP}/FortranScalarType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FortranScalarType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FortranScalarType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FortranScalarType.help
-	@cp -f ${HELP}/FortranScalarType.help ${HELP}/FST.help
-	@${TANGLE} -R"FortranScalarType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FortranScalarType.input
-	@echo "FortranScalarType (FST)" >>${HELPFILE}
-
-${HELP}/FortranTemplate.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FortranTemplate.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FortranTemplate.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FortranTemplate.help
-	@cp -f ${HELP}/FortranTemplate.help ${HELP}/FTEM.help
-	@${TANGLE} -R"FortranTemplate.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FortranTemplate.input
-	@echo "FortranTemplate (FTEM)" >>${HELPFILE}
-
-${HELP}/FortranType.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FortranType.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FortranType.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FortranType.help
-	@cp -f ${HELP}/FortranType.help ${HELP}/FT.help
-	@${TANGLE} -R"FortranType.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FortranType.input
-	@echo "FortranType (FT)" >>${HELPFILE}
-
-${HELP}/FortranVectorCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FortranVectorCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FortranVectorCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FortranVectorCategory.help
-	@cp -f ${HELP}/FortranVectorCategory.help ${HELP}/FVC.help
-	@${TANGLE} -R"FortranVectorCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FortranVectorCategory.input
-	@echo "FortranVectorCategory (FVC)" >>${HELPFILE}
-
-${HELP}/FortranVectorFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FortranVectorFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FortranVectorFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FortranVectorFunctionCategory.help
-	@cp -f ${HELP}/FortranVectorFunctionCategory.help ${HELP}/FVFUN.help
-	@${TANGLE} -R"FortranVectorFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FortranVectorFunctionCategory.input
-	@echo "FortranVectorFunctionCategory (FVFUN)" >>${HELPFILE}
-
-${HELP}/FourierComponent.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FourierComponent.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FourierComponent.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FourierComponent.help
-	@cp -f ${HELP}/FourierComponent.help ${HELP}/FCOMP.help
-	@${TANGLE} -R"FourierComponent.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FourierComponent.input
-	@echo "FourierComponent (FCOMP)" >>${HELPFILE}
-
-${HELP}/FourierSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FourierSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FourierSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FourierSeries.help
-	@cp -f ${HELP}/FourierSeries.help ${HELP}/FSERIES.help
-	@${TANGLE} -R"FourierSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FourierSeries.input
-	@echo "FourierSeries (FSERIES)" >>${HELPFILE}
-
-${HELP}/Fraction.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7330 create Fraction.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Fraction.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Fraction.help
-	@cp -f ${HELP}/Fraction.help ${HELP}/FRAC.help
-	@${TANGLE} -R"Fraction.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Fraction.input
-	@echo "Fraction (FRAC)" >>${HELPFILE}
-
-${HELP}/FractionalIdeal.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FractionalIdeal.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FractionalIdeal.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FractionalIdeal.help
-	@cp -f ${HELP}/FractionalIdeal.help ${HELP}/FRIDEAL.help
-	@${TANGLE} -R"FractionalIdeal.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FractionalIdeal.input
-	@echo "FractionalIdeal (FRIDEAL)" >>${HELPFILE}
-
-${HELP}/FramedAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FramedAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FramedAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FramedAlgebra.help
-	@cp -f ${HELP}/FramedAlgebra.help ${HELP}/FRAMALG.help
-	@${TANGLE} -R"FramedAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FramedAlgebra.input
-	@echo "FramedAlgebra (FRAMALG)" >>${HELPFILE}
-
-${HELP}/FramedModule.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FramedModule.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FramedModule.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FramedModule.help
-	@cp -f ${HELP}/FramedModule.help ${HELP}/FRMOD.help
-	@${TANGLE} -R"FramedModule.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FramedModule.input
-	@echo "FramedModule (FRMOD)" >>${HELPFILE}
-
-${HELP}/FramedNonAssociativeAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FramedNonAssociativeAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FramedNonAssociativeAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FramedNonAssociativeAlgebra.help
-	@cp -f ${HELP}/FramedNonAssociativeAlgebra.help ${HELP}/FRNAALG.help
-	@${TANGLE} -R"FramedNonAssociativeAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FramedNonAssociativeAlgebra.input
-	@echo "FramedNonAssociativeAlgebra (FRNAALG)" >>${HELPFILE}
-
-${HELP}/FreeAbelianGroup.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FreeAbelianGroup.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FreeAbelianGroup.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FreeAbelianGroup.help
-	@cp -f ${HELP}/FreeAbelianGroup.help ${HELP}/FAGROUP.help
-	@${TANGLE} -R"FreeAbelianGroup.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FreeAbelianGroup.input
-	@echo "FreeAbelianGroup (FAGROUP)" >>${HELPFILE}
-
-${HELP}/FreeAbelianMonoid.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FreeAbelianMonoid.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FreeAbelianMonoid.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FreeAbelianMonoid.help
-	@cp -f ${HELP}/FreeAbelianMonoid.help ${HELP}/FAMONOID.help
-	@${TANGLE} -R"FreeAbelianMonoid.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FreeAbelianMonoid.input
-	@echo "FreeAbelianMonoid (FAMONOID)" >>${HELPFILE}
-
-${HELP}/FreeAbelianMonoidCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FreeAbelianMonoidCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FreeAbelianMonoidCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FreeAbelianMonoidCategory.help
-	@cp -f ${HELP}/FreeAbelianMonoidCategory.help ${HELP}/FAMONC.help
-	@${TANGLE} -R"FreeAbelianMonoidCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FreeAbelianMonoidCategory.input
-	@echo "FreeAbelianMonoidCategory (FAMONC)" >>${HELPFILE}
-
-${HELP}/FreeGroup.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FreeGroup.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FreeGroup.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FreeGroup.help
-	@cp -f ${HELP}/FreeGroup.help ${HELP}/FGROUP.help
-	@${TANGLE} -R"FreeGroup.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FreeGroup.input
-	@echo "FreeGroup (FGROUP)" >>${HELPFILE}
-
-${HELP}/FreeLieAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FreeLieAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FreeLieAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FreeLieAlgebra.help
-	@cp -f ${HELP}/FreeLieAlgebra.help ${HELP}/FLALG.help
-	@${TANGLE} -R"FreeLieAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FreeLieAlgebra.input
-	@echo "FreeLieAlgebra (FLALG)" >>${HELPFILE}
-
-${HELP}/FreeModuleCat.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FreeModuleCat.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FreeModuleCat.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FreeModuleCat.help
-	@cp -f ${HELP}/FreeModuleCat.help ${HELP}/FMCAT.help
-	@${TANGLE} -R"FreeModuleCat.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FreeModuleCat.input
-	@echo "FreeModuleCat (FMCAT)" >>${HELPFILE}
-
-${HELP}/FreeModule.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FreeModule.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FreeModule.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FreeModule.help
-	@cp -f ${HELP}/FreeModule.help ${HELP}/FM.help
-	@${TANGLE} -R"FreeModule.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FreeModule.input
-	@echo "FreeModule (FM)" >>${HELPFILE}
-
-${HELP}/FreeModule1.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FreeModule1.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FreeModule1.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FreeModule1.help
-	@cp -f ${HELP}/FreeModule1.help ${HELP}/FM1.help
-	@${TANGLE} -R"FreeModule1.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FreeModule1.input
-	@echo "FreeModule1 (FM1)" >>${HELPFILE}
-
-${HELP}/FreeMonoid.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FreeMonoid.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FreeMonoid.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FreeMonoid.help
-	@cp -f ${HELP}/FreeMonoid.help ${HELP}/FMONOID.help
-	@${TANGLE} -R"FreeMonoid.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FreeMonoid.input
-	@echo "FreeMonoid (FMONOID)" >>${HELPFILE}
-
-${HELP}/FreeNilpotentLie.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FreeNilpotentLie.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FreeNilpotentLie.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FreeNilpotentLie.help
-	@cp -f ${HELP}/FreeNilpotentLie.help ${HELP}/FNLA.help
-	@${TANGLE} -R"FreeNilpotentLie.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FreeNilpotentLie.input
-	@echo "FreeNilpotentLie (FNLA)" >>${HELPFILE}
-
-${HELP}/FullPartialFractionExpansion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7340 create FullPartialFractionExpansion.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FullPartialFractionExpansion.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/FullPartialFractionExpansion.help
-	@cp -f ${HELP}/FullPartialFractionExpansion.help ${HELP}/FPARFRAC.help
-	@${TANGLE} -R"FullPartialFractionExpansion.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FullPartialFractionExpansion.input
-	@echo "FullPartialFractionExpansion (FPARFRAC)" >>${HELPFILE}
-
-${HELP}/FullyEvalableOver.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FullyEvalableOver.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FullyEvalableOver.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FullyEvalableOver.help
-	@cp -f ${HELP}/FullyEvalableOver.help ${HELP}/FEVALAB.help
-	@${TANGLE} -R"FullyEvalableOver.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FullyEvalableOver.input
-	@echo "FullyEvalableOver (FEVALAB)" >>${HELPFILE}
-
-${HELP}/FullyLinearlyExplicitRingOver.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FullyLinearlyExplicitRingOver.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FullyLinearlyExplicitRingOver.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FullyLinearlyExplicitRingOver.help
-	@cp -f ${HELP}/FullyLinearlyExplicitRingOver.help ${HELP}/FLINEXP.help
-	@${TANGLE} -R"FullyLinearlyExplicitRingOver.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FullyLinearlyExplicitRingOver.input
-	@echo "FullyLinearlyExplicitRingOver (FLINEXP)" >>${HELPFILE}
-
-${HELP}/FullyPatternMatchable.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FullyPatternMatchable.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FullyPatternMatchable.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FullyPatternMatchable.help
-	@cp -f ${HELP}/FullyPatternMatchable.help ${HELP}/FPATMAB.help
-	@${TANGLE} -R"FullyPatternMatchable.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FullyPatternMatchable.input
-	@echo "FullyPatternMatchable (FPATMAB)" >>${HELPFILE}
-
-${HELP}/FullyRetractableTo.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FullyRetractableTo.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FullyRetractableTo.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FullyRetractableTo.help
-	@cp -f ${HELP}/FullyRetractableTo.help ${HELP}/FRETRCT.help
-	@${TANGLE} -R"FullyRetractableTo.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FullyRetractableTo.input
-	@echo "FullyRetractableTo (FRETRCT)" >>${HELPFILE}
-
-${HELP}/FunctionCalled.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create FunctionCalled.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"FunctionCalled.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/FunctionCalled.help
-	@cp -f ${HELP}/FunctionCalled.help ${HELP}/FUNCTION.help
-	@${TANGLE} -R"FunctionCalled.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/FunctionCalled.input
-	@echo "FunctionCalled (FUNCTION)" >>${HELPFILE}
-
-${HELP}/FunctionFieldCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FunctionFieldCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FunctionFieldCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FunctionFieldCategory.help
-	@cp -f ${HELP}/FunctionFieldCategory.help ${HELP}/FFCAT.help
-	@${TANGLE} -R"FunctionFieldCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FunctionFieldCategory.input
-	@echo "FunctionFieldCategory (FFCAT)" >>${HELPFILE}
-
-${HELP}/FunctionSpace.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create FunctionSpace.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"FunctionSpace.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/FunctionSpace.help
-	@cp -f ${HELP}/FunctionSpace.help ${HELP}/FS.help
-	@${TANGLE} -R"FunctionSpace.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/FunctionSpace.input
-	@echo "FunctionSpace (FS)" >>${HELPFILE}
-
-${HELP}/GcdDomain.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create GcdDomain.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"GcdDomain.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/GcdDomain.help
-	@cp -f ${HELP}/GcdDomain.help ${HELP}/GCDDOM.help
-	@${TANGLE} -R"GcdDomain.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/GcdDomain.input
-	@echo "GcdDomain (GCDDOM)" >>${HELPFILE}
-
-${HELP}/GeneralDistributedMultivariatePolynomial.help: \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7350 create GeneralDistributedMultivariatePolynomial.help \
-            from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GeneralDistributedMultivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/GeneralDistributedMultivariatePolynomial.help
-	@cp -f ${HELP}/GeneralDistributedMultivariatePolynomial.help \
-             ${HELP}/GDMP.help
-	@${TANGLE} -R"GeneralDistributedMultivariatePolynomial.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GeneralDistributedMultivariatePolynomial.input
-	@echo "GeneralDistributedMultivariatePolynomial (GDMP)" >>${HELPFILE}
-
-${HELP}/GeneralModulePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create GeneralModulePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GeneralModulePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/GeneralModulePolynomial.help
-	@cp -f ${HELP}/GeneralModulePolynomial.help ${HELP}/GMODPOL.help
-	@${TANGLE} -R"GeneralModulePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GeneralModulePolynomial.input
-	@echo "GeneralModulePolynomial (GMODPOL)" >>${HELPFILE}
-
-${HELP}/GeneralPackageForAlgebraicFunctionField.help: \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7355 create GeneralPackageForAlgebraicFunctionField.help \
-            from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"GeneralPackageForAlgebraicFunctionField.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/GeneralPackageForAlgebraicFunctionField.help
-	@cp -f ${HELP}/GeneralPackageForAlgebraicFunctionField.help \
-             ${HELP}/GPAFF.help
-	@${TANGLE} -R"GeneralPackageForAlgebraicFunctionField.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/GeneralPackageForAlgebraicFunctionField.input
-	@echo "GeneralPackageForAlgebraicFunctionField (GPAFF)" >>${HELPFILE}
-
-${HELP}/GeneralSparseTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7360 create GeneralSparseTable.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GeneralSparseTable.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/GeneralSparseTable.help
-	@cp -f ${HELP}/GeneralSparseTable.help ${HELP}/GSTBL.help
-	@${TANGLE} -R"GeneralSparseTable.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GeneralSparseTable.input
-	@echo "GeneralSparseTable (GSTBL)" >>${HELPFILE}
-
-${HELP}/GenericNonAssociativeAlgebra.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create GenericNonAssociativeAlgebra.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GenericNonAssociativeAlgebra.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/GenericNonAssociativeAlgebra.help
-	@cp -f ${HELP}/GenericNonAssociativeAlgebra.help ${HELP}/GCNAALG.help
-	@${TANGLE} -R"GenericNonAssociativeAlgebra.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GenericNonAssociativeAlgebra.input
-	@echo "GenericNonAssociativeAlgebra (GCNAALG)" >>${HELPFILE}
-
-${HELP}/GeneralPolynomialSet.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create GeneralPolynomialSet.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GeneralPolynomialSet.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/GeneralPolynomialSet.help
-	@cp -f ${HELP}/GeneralPolynomialSet.help ${HELP}/GPOLSET.help
-	@${TANGLE} -R"GeneralPolynomialSet.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GeneralPolynomialSet.input
-	@echo "GeneralPolynomialSet (GPOLSET)" >>${HELPFILE}
-
-${HELP}/GeneralTriangularSet.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create GeneralTriangularSet.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GeneralTriangularSet.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/GeneralTriangularSet.help
-	@cp -f ${HELP}/GeneralTriangularSet.help ${HELP}/GTSET.help
-	@${TANGLE} -R"GeneralTriangularSet.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GeneralTriangularSet.input
-	@echo "GeneralTriangularSet (GTSET)" >>${HELPFILE}
-
-${HELP}/GeneralUnivariatePowerSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create GeneralUnivariatePowerSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GeneralUnivariatePowerSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/GeneralUnivariatePowerSeries.help
-	@cp -f ${HELP}/GeneralUnivariatePowerSeries.help ${HELP}/GSERIES.help
-	@${TANGLE} -R"GeneralUnivariatePowerSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GeneralUnivariatePowerSeries.input
-	@echo "GeneralUnivariatePowerSeries (GSERIES)" >>${HELPFILE}
-
-${HELP}/GnuDraw.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 5000 create GnuDraw.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"GnuDraw.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/GnuDraw.help
-	@cp -f ${HELP}/GnuDraw.help ${HELP}/GDRAW.help
-	@${TANGLE} -R"GnuDraw.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/GnuDraw.input
-	@echo "GnuDraw (GDRAW)" >>${HELPFILE}
-
-${HELP}/GradedAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create GradedAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"GradedAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/GradedAlgebra.help
-	@cp -f ${HELP}/GradedAlgebra.help ${HELP}/GRALG.help
-	@${TANGLE} -R"GradedAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/GradedAlgebra.input
-	@echo "GradedAlgebra (GRALG)" >>${HELPFILE}
-
-${HELP}/GradedModule.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create GradedModule.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"GradedModule.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/GradedModule.help
-	@cp -f ${HELP}/GradedModule.help ${HELP}/GRMOD.help
-	@${TANGLE} -R"GradedModule.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/GradedModule.input
-	@echo "GradedModule (GRMOD)" >>${HELPFILE}
-
-${HELP}/GraphImage.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create GraphImage.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GraphImage.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/GraphImage.help
-	@cp -f ${HELP}/GraphImage.help ${HELP}/GRIMAGE.help
-	@${TANGLE} -R"GraphImage.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GraphImage.input
-	@echo "GraphImage (GRIMAGE)" >>${HELPFILE}
-
-${HELP}/GroebnerFactorizationPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7370 create GroebnerFactorizationPackage.help \
-            from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"GroebnerFactorizationPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/GroebnerFactorizationPackage.help
-	@cp -f ${HELP}/GroebnerFactorizationPackage.help ${HELP}/GBF.help
-	@${TANGLE} -R"GroebnerFactorizationPackage.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/GroebnerFactorizationPackage.input
-	@echo "GroebnerFactorizationPackage (GBF)" >>${HELPFILE}
-
-${HELP}/GroebnerPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7380 create GroebnerPackage.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"GroebnerPackage.help" ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/GroebnerPackage.help
-	@cp -f ${HELP}/GroebnerPackage.help ${HELP}/GB.help
-	@${TANGLE} -R"GroebnerPackage.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/GroebnerPackage.input
-	@echo "GroebnerPackage (GB)" >>${HELPFILE}
-
-${HELP}/Group.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Group.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Group.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Group.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Group.help ${HELP}/GROUP.help ; \
-	 fi
-	@${TANGLE} -R"Group.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Group.input
-	@echo "Group (GROUP)" >>${HELPFILE}
-
-${HELP}/GuessOption.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create GuessOption.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GuessOption.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/GuessOption.help
-	@cp -f ${HELP}/GuessOption.help ${HELP}/GOPT.help
-	@${TANGLE} -R"GuessOption.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GuessOption.input
-	@echo "GuessOption (GOPT)" >>${HELPFILE}
-
-${HELP}/GuessOptionFunctions0.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create GuessOptionFunctions0.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"GuessOptionFunctions0.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/GuessOptionFunctions0.help
-	@cp -f ${HELP}/GuessOptionFunctions0.help ${HELP}/GOPT0.help
-	@${TANGLE} -R"GuessOptionFunctions0.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/GuessOptionFunctions0.input
-	@echo "GuessOptionFunctions0 (GOPT0)" >>${HELPFILE}
-
-${HELP}/HashTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create HashTable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"HashTable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/HashTable.help
-	@cp -f ${HELP}/HashTable.help ${HELP}/HASHTBL.help
-	@${TANGLE} -R"HashTable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/HashTable.input
-	@echo "HashTable (HASHTBL)" >>${HELPFILE}
-
-${HELP}/Heap.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7390 create Heap.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Heap.help" ${BOOKS}/bookvol10.3.pamphlet \
-             >${HELP}/Heap.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Heap.help ${HELP}/HEAP.help ; \
-	 fi
-	@${TANGLE} -R"Heap.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Heap.input
-	@echo "Heap (HEAP)" >>${HELPFILE}
-
-${HELP}/HexadecimalExpansion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7400 create HexadecimalExpansion.help \
-            from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"HexadecimalExpansion.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/HexadecimalExpansion.help
-	@cp -f ${HELP}/HexadecimalExpansion.help  ${HELP}/HEXADEC.help
-	@${TANGLE} -R"HexadecimalExpansion.input" \
-           ${BOOKS}/bookvol10.3.pamphlet >${INPUT}/HexadecimalExpansion.input
-	@echo "HexadecimalExpansion (HEXADEC)" >>${HELPFILE}
-
-${HELP}/HTMLFormat.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create HTMLFormat.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"HTMLFormat.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/HTMLFormat.help
-	@cp -f ${HELP}/HTMLFormat.help ${HELP}/HTMLFORM.help
-	@${TANGLE} -R"HTMLFormat.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/HTMLFormat.input
-	@echo "HTMLFormat (HTMLFORM)" >>${HELPFILE}
-
-${HELP}/HomogeneousAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create HomogeneousAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"HomogeneousAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/HomogeneousAggregate.help
-	@cp -f ${HELP}/HomogeneousAggregate.help ${HELP}/HOAGG.help
-	@${TANGLE} -R"HomogeneousAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/HomogeneousAggregate.input
-	@echo "HomogeneousAggregate (HOAGG)" >>${HELPFILE}
-
-${HELP}/HomogeneousDirectProduct.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create HomogeneousDirectProduct.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"HomogeneousDirectProduct.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/HomogeneousDirectProduct.help
-	@cp -f ${HELP}/HomogeneousDirectProduct.help ${HELP}/HDP.help
-	@${TANGLE} -R"HomogeneousDirectProduct.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/HomogeneousDirectProduct.input
-	@echo "HomogeneousDirectProduct (HDP)" >>${HELPFILE}
-
-${HELP}/HomogeneousDistributedMultivariatePolynomial.help: \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7410 create HomogeneousDistributedMultivariatePolynomial.help \
-            from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"HomogeneousDistributedMultivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/HomogeneousDistributedMultivariatePolynomial.help
-	@cp -f ${HELP}/HomogeneousDistributedMultivariatePolynomial.help \
-             ${HELP}/HDMP.help
-	@${TANGLE} -R"HomogeneousDistributedMultivariatePolynomial.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/HomogeneousDistributedMultivariatePolynomial.input
-	@echo "HomogeneousDistributedMultivariatePolynomial (HDMP)" \
-            >>${HELPFILE}
-
-${HELP}/HyperbolicFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create HyperbolicFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"HyperbolicFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/HyperbolicFunctionCategory.help
-	@cp -f ${HELP}/HyperbolicFunctionCategory.help ${HELP}/HYPCAT.help
-	@${TANGLE} -R"HyperbolicFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/HyperbolicFunctionCategory.input
-	@echo "HyperbolicFunctionCategory (HYPCAT)" >>${HELPFILE}
-
-${HELP}/HyperellipticFiniteDivisor.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create HyperellipticFiniteDivisor.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"HyperellipticFiniteDivisor.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/HyperellipticFiniteDivisor.help
-	@cp -f ${HELP}/HyperellipticFiniteDivisor.help ${HELP}/HELLFDIV.help
-	@${TANGLE} -R"HyperellipticFiniteDivisor.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/HyperellipticFiniteDivisor.input
-	@echo "HyperellipticFiniteDivisor (HELLFDIV)" >>${HELPFILE}
-
-${HELP}/IndexCard.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexCard.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexCard.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexCard.help
-	@cp -f ${HELP}/IndexCard.help ${HELP}/ICARD.help
-	@${TANGLE} -R"IndexCard.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexCard.input
-	@echo "IndexCard (ICARD)" >>${HELPFILE}
-
-${HELP}/IndexedAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create IndexedAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"IndexedAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/IndexedAggregate.help
-	@cp -f ${HELP}/IndexedAggregate.help ${HELP}/IXAGG.help
-	@${TANGLE} -R"IndexedAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/IndexedAggregate.input
-	@echo "IndexedAggregate (IXAGG)" >>${HELPFILE}
-
-${HELP}/IndexedBits.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7415 create IndexedBits.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedBits.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedBits.help
-	@cp -f ${HELP}/IndexedBits.help ${HELP}/IBITS.help
-	@${TANGLE} -R"IndexedBits.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedBits.input
-	@echo "IndexedBits (IBITS)" >>${HELPFILE}
-
-${HELP}/IndexedDirectProductAbelianGroup.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedDirectProductAbelianGroup.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedDirectProductAbelianGroup.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedDirectProductAbelianGroup.help
-	@cp -f ${HELP}/IndexedDirectProductAbelianGroup.help ${HELP}/IDPAG.help
-	@${TANGLE} -R"IndexedDirectProductAbelianGroup.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedDirectProductAbelianGroup.input
-	@echo "IndexedDirectProductAbelianGroup (IDPAG)" >>${HELPFILE}
-
-${HELP}/IndexedDirectProductAbelianMonoid.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedDirectProductAbelianMonoid.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedDirectProductAbelianMonoid.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedDirectProductAbelianMonoid.help
-	@cp -f ${HELP}/IndexedDirectProductAbelianMonoid.help \
-            ${HELP}/IDPAM.help
-	@${TANGLE} -R"IndexedDirectProductAbelianMonoid.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedDirectProductAbelianMonoid.input
-	@echo "IndexedDirectProductAbelianMonoid (IDPAM)" >>${HELPFILE}
-
-${HELP}/IndexedDirectProductCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create IndexedDirectProductCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"IndexedDirectProductCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/IndexedDirectProductCategory.help
-	@cp -f ${HELP}/IndexedDirectProductCategory.help ${HELP}/IDPC.help
-	@${TANGLE} -R"IndexedDirectProductCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/IndexedDirectProductCategory.input
-	@echo "IndexedDirectProductCategory (IDPC)" >>${HELPFILE}
-
-${HELP}/IndexedDirectProductObject.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedDirectProductObject.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedDirectProductObject.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedDirectProductObject.help
-	@cp -f ${HELP}/IndexedDirectProductObject.help ${HELP}/IDPO.help
-	@${TANGLE} -R"IndexedDirectProductObject.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedDirectProductObject.input
-	@echo "IndexedDirectProductObject (IDPO)" >>${HELPFILE}
-
-${HELP}/IndexedDirectProductOrderedAbelianMonoid.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedDirectProductOrderedAbelianMonoid.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedDirectProductOrderedAbelianMonoid.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedDirectProductOrderedAbelianMonoid.help
-	@cp -f ${HELP}/IndexedDirectProductOrderedAbelianMonoid.help \
-           ${HELP}/IDPOAM.help
-	@${TANGLE} -R"IndexedDirectProductOrderedAbelianMonoid.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/IndexedDirectProductOrderedAbelianMonoid.input
-	@echo "IndexedDirectProductOrderedAbelianMonoid (IDPOAM)" >>${HELPFILE}
-
-${HELP}/IndexedDirectProductOrderedAbelianMonoidSup.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedDirectProductOrderedAbelianMonoidSup.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedDirectProductOrderedAbelianMonoidSup.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedDirectProductOrderedAbelianMonoidSup.help
-	@cp -f ${HELP}/IndexedDirectProductOrderedAbelianMonoidSup.help \
-           ${HELP}/IDPOAMS.help
-	@${TANGLE} -R"IndexedDirectProductOrderedAbelianMonoidSup.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/IndexedDirectProductOrderedAbelianMonoidSup.input
-	@echo "IndexedDirectProductOrderedAbelianMonoidSup (IDPOAMS)"\
-           >>${HELPFILE}
-
-${HELP}/IndexedExponents.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedExponents.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedExponents.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedExponents.help
-	@cp -f ${HELP}/IndexedExponents.help ${HELP}/INDE.help
-	@${TANGLE} -R"IndexedExponents.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedExponents.input
-	@echo "IndexedExponents (INDE)" >>${HELPFILE}
-
-${HELP}/IndexedFlexibleArray.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedFlexibleArray.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedFlexibleArray.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedFlexibleArray.help
-	@cp -f ${HELP}/IndexedFlexibleArray.help ${HELP}/IFARRAY.help
-	@${TANGLE} -R"IndexedFlexibleArray.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedFlexibleArray.input
-	@echo "IndexedFlexibleArray (IFARRAY)" >>${HELPFILE}
-
-${HELP}/IndexedList.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedList.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedList.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedList.help
-	@cp -f ${HELP}/IndexedList.help ${HELP}/ILIST.help
-	@${TANGLE} -R"IndexedList.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedList.input
-	@echo "IndexedList (ILIST)" >>${HELPFILE}
-
-${HELP}/IndexedMatrix.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedMatrix.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedMatrix.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedMatrix.help
-	@cp -f ${HELP}/IndexedMatrix.help ${HELP}/IMATRIX.help
-	@${TANGLE} -R"IndexedMatrix.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedMatrix.input
-	@echo "IndexedMatrix (IMATRIX)" >>${HELPFILE}
-
-${HELP}/IndexedOneDimensionalArray.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedOneDimensionalArray.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedOneDimensionalArray.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedOneDimensionalArray.help
-	@cp -f ${HELP}/IndexedOneDimensionalArray.help ${HELP}/IARRAY1.help
-	@${TANGLE} -R"IndexedOneDimensionalArray.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedOneDimensionalArray.input
-	@echo "IndexedOneDimensionalArray (IARRAY1)" >>${HELPFILE}
-
-${HELP}/IndexedString.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedString.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedString.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedString.help
-	@cp -f ${HELP}/IndexedString.help ${HELP}/ISTRING.help
-	@${TANGLE} -R"IndexedString.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedString.input
-	@echo "IndexedString (ISTRING)" >>${HELPFILE}
-
-${HELP}/IndexedTwoDimensionalArray.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedTwoDimensionalArray.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedTwoDimensionalArray.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedTwoDimensionalArray.help
-	@cp -f ${HELP}/IndexedTwoDimensionalArray.help ${HELP}/IARRAY2.help
-	@${TANGLE} -R"IndexedTwoDimensionalArray.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedTwoDimensionalArray.input
-	@echo "IndexedTwoDimensionalArray (IARRAY2)" >>${HELPFILE}
-
-${HELP}/IndexedVector.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IndexedVector.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IndexedVector.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IndexedVector.help
-	@cp -f ${HELP}/IndexedVector.help ${HELP}/IVECTOR.help
-	@${TANGLE} -R"IndexedVector.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IndexedVector.input
-	@echo "IndexedVector (IVECTOR)" >>${HELPFILE}
-
-${HELP}/InfClsPt.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7417 create InfClsPt.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InfClsPt.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InfClsPt.help
-	@cp -f ${HELP}/InfClsPt.help ${HELP}/ICP.help
-	@${TANGLE} -R"InfClsPt.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/InfClsPt.input
-	@echo "InfClsPt (ICP)" >>${HELPFILE}
-
-${HELP}/InfiniteTuple.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InfiniteTuple.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InfiniteTuple.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InfiniteTuple.help
-	@cp -f ${HELP}/InfiniteTuple.help ${HELP}/ITUPLE.help
-	@${TANGLE} -R"InfiniteTuple.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InfiniteTuple.input
-	@echo "InfiniteTuple (ITUPLE)" >>${HELPFILE}
-
-${HELP}/InfinitlyClosePoint.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7418 create InfinitlyClosePoint.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InfinitlyClosePoint.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InfinitlyClosePoint.help
-	@cp -f ${HELP}/InfinitlyClosePoint.help ${HELP}/INFCLSPT.help
-	@${TANGLE} -R"InfinitlyClosePoint.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/InfinitlyClosePoint.input
-	@echo "InfinitlyClosePoint (INFCLSPT)" >>${HELPFILE}
-
-${HELP}/InfinitlyClosePointCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7419 create InfinitlyClosePointCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"InfinitlyClosePointCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/InfinitlyClosePointCategory.help
-	@cp -f ${HELP}/InfinitlyClosePointCategory.help ${HELP}/INFCLCT.help
-	@${TANGLE} -R"InfinitlyClosePointCategory.input" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${INPUT}/InfinitlyClosePointCategory.input
-	@echo "InfinitlyClosePointCategory (INFCLCT)" >>${HELPFILE}
-
-${HELP}/InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7420 create \
-           InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} \
-      -R"InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.help" \
-      ${BOOKS}/bookvol10.3.pamphlet \
-       >${HELP}/InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.help
-	@cp -f \
-      ${HELP}/InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.help \
-      ${HELP}/INFCLSPS.help
-	@${TANGLE} \
-      -R"InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.input" \
-      ${BOOKS}/bookvol10.3.pamphlet \
-     >${INPUT}/InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField.input
-	@echo \
-      "InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField (INFCLSPS)" \
-      >>${HELPFILE}
-
-${HELP}/InnerAlgebraicNumber.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerAlgebraicNumber.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerAlgebraicNumber.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerAlgebraicNumber.help
-	@cp -f ${HELP}/InnerAlgebraicNumber.help ${HELP}/IAN.help
-	@${TANGLE} -R"InnerAlgebraicNumber.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerAlgebraicNumber.input
-	@echo "InnerAlgebraicNumber (IAN)" >>${HELPFILE}
-
-${HELP}/InnerEvalable.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create InnerEvalable.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"InnerEvalable.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/InnerEvalable.help
-	@cp -f ${HELP}/InnerEvalable.help ${HELP}/IEVALAB.help
-	@${TANGLE} -R"InnerEvalable.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/InnerEvalable.input
-	@echo "InnerEvalable (IEVALAB)" >>${HELPFILE}
-
-${HELP}/InnerFiniteField.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerFiniteField.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerFiniteField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerFiniteField.help
-	@cp -f ${HELP}/InnerFiniteField.help ${HELP}/IFF.help
-	@${TANGLE} -R"InnerFiniteField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerFiniteField.input
-	@echo "InnerFiniteField (IFF)" >>${HELPFILE}
-
-${HELP}/InnerFreeAbelianMonoid.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerFreeAbelianMonoid.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerFreeAbelianMonoid.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerFreeAbelianMonoid.help
-	@cp -f ${HELP}/InnerFreeAbelianMonoid.help ${HELP}/IFAMON.help
-	@${TANGLE} -R"InnerFreeAbelianMonoid.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerFreeAbelianMonoid.input
-	@echo "InnerFreeAbelianMonoid (IFAMON)" >>${HELPFILE}
-
-${HELP}/InnerIndexedTwoDimensionalArray.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerIndexedTwoDimensionalArray.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerIndexedTwoDimensionalArray.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerIndexedTwoDimensionalArray.help
-	@cp -f ${HELP}/InnerIndexedTwoDimensionalArray.help \
-            ${HELP}/IIARRAY2.help
-	@${TANGLE} -R"InnerIndexedTwoDimensionalArray.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerIndexedTwoDimensionalArray.input
-	@echo "InnerIndexedTwoDimensionalArray (IIARRAY2)" >>${HELPFILE}
-
-${HELP}/InnerPAdicInteger.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerPAdicInteger.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerPAdicInteger.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerPAdicInteger.help
-	@cp -f ${HELP}/InnerPAdicInteger.help ${HELP}/IPADIC.help
-	@${TANGLE} -R"InnerPAdicInteger.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerPAdicInteger.input
-	@echo "InnerPAdicInteger (IPADIC)" >>${HELPFILE}
-
-${HELP}/InnerPrimeField.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerPrimeField.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerPrimeField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerPrimeField.help
-	@cp -f ${HELP}/InnerPrimeField.help ${HELP}/IPF.help
-	@${TANGLE} -R"InnerPrimeField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerPrimeField.input
-	@echo "InnerPrimeField (IPF)" >>${HELPFILE}
-
-${HELP}/InnerSparseUnivariatePowerSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerSparseUnivariatePowerSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerSparseUnivariatePowerSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerSparseUnivariatePowerSeries.help
-	@cp -f ${HELP}/InnerSparseUnivariatePowerSeries.help ${HELP}/ISUPS.help
-	@${TANGLE} -R"InnerSparseUnivariatePowerSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerSparseUnivariatePowerSeries.input
-	@echo "InnerSparseUnivariatePowerSeries (ISUPS)" >>${HELPFILE}
-
-${HELP}/InnerTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerTable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerTable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerTable.help
-	@cp -f ${HELP}/InnerTable.help ${HELP}/INTABL.help
-	@${TANGLE} -R"InnerTable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerTable.input
-	@echo "InnerTable (INTABL)" >>${HELPFILE}
-
-${HELP}/InnerTaylorSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InnerTaylorSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InnerTaylorSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InnerTaylorSeries.help
-	@cp -f ${HELP}/InnerTaylorSeries.help ${HELP}/ITAYLOR.help
-	@${TANGLE} -R"InnerTaylorSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InnerTaylorSeries.input
-	@echo "InnerTaylorSeries (ITAYLOR)" >>${HELPFILE}
-
-${HELP}/InputForm.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create InputForm.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"InputForm.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/InputForm.help
-	@cp -f ${HELP}/InputForm.help ${HELP}/INFORM.help
-	@${TANGLE} -R"InputForm.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/InputForm.input
-	@echo "InputForm (INFORM)" >>${HELPFILE}
-
-${HELP}/Integer.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7425 create Integer.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Integer.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Integer.help
-	@cp -f ${HELP}/Integer.help ${HELP}/INT.help
-	@${TANGLE} -R"Integer.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Integer.input
-	@echo "Integer (INT)" >>${HELPFILE}
-
-${HELP}/IntegerCombinatoricFunctions.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7430 create IntegerCombinatoricFunctions.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"IntegerCombinatoricFunctions.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/IntegerCombinatoricFunctions.help
-	@cp -f ${HELP}/IntegerCombinatoricFunctions.help ${HELP}/COMBINAT.help
-	@${TANGLE} -R"IntegerCombinatoricFunctions.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/IntegerCombinatoricFunctions.input
-	@echo "IntegerCombinatoricFunctions (COMBINAT)" >>${HELPFILE}
-
-${HELP}/IntegerLinearDependence.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7440 create IntegerLinearDependence.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"IntegerLinearDependence.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/IntegerLinearDependence.help
-	@cp -f ${HELP}/IntegerLinearDependence.help ${HELP}/ZLINDEP.help
-	@${TANGLE} -R"IntegerLinearDependence.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/IntegerLinearDependence.input
-	@echo "IntegerLinearDependence (ZLINDEP)" >>${HELPFILE}
-
-${HELP}/IntegerMod.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IntegerMod.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IntegerMod.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IntegerMod.help
-	@cp -f ${HELP}/IntegerMod.help ${HELP}/ZMOD.help
-	@${TANGLE} -R"IntegerMod.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IntegerMod.input
-	@echo "IntegerMod (ZMOD)" >>${HELPFILE}
-
-${HELP}/IntegerNumberSystem.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create IntegerNumberSystem.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"IntegerNumberSystem.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/IntegerNumberSystem.help
-	@cp -f ${HELP}/IntegerNumberSystem.help ${HELP}/INS.help
-	@${TANGLE} -R"IntegerNumberSystem.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/IntegerNumberSystem.input
-	@echo "IntegerNumberSystem (INS)" >>${HELPFILE}
-
-${HELP}/IntegerNumberTheoryFunctions.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7450 create IntegerNumberTheoryFunctions.help \
-            from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"IntegerNumberTheoryFunctions.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/IntegerNumberTheoryFunctions.help
-	@cp -f ${HELP}/IntegerNumberTheoryFunctions.help \
-             ${HELP}/INTHEORY.help
-	@${TANGLE} -R"IntegerNumberTheoryFunctions.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/IntegerNumberTheoryFunctions.input
-	@echo "IntegerNumberTheoryFunctions (INTHEORY)" >>${HELPFILE}
-
-${HELP}/IntegralDomain.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create IntegralDomain.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"IntegralDomain.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/IntegralDomain.help
-	@cp -f ${HELP}/IntegralDomain.help ${HELP}/INTDOM.help
-	@${TANGLE} -R"IntegralDomain.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/IntegralDomain.input
-	@echo "IntegralDomain (INTDOM)" >>${HELPFILE}
-
-${HELP}/IntegrationFunctionsTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IntegrationFunctionsTable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IntegrationFunctionsTable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IntegrationFunctionsTable.help
-	@cp -f ${HELP}/IntegrationFunctionsTable.help ${HELP}/INTFTBL.help
-	@${TANGLE} -R"IntegrationFunctionsTable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IntegrationFunctionsTable.input
-	@echo "IntegrationFunctionsTable (INTFTBL)" >>${HELPFILE}
-
-${HELP}/IntegrationResult.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create IntegrationResult.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"IntegrationResult.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/IntegrationResult.help
-	@cp -f ${HELP}/IntegrationResult.help ${HELP}/IR.help
-	@${TANGLE} -R"IntegrationResult.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/IntegrationResult.input
-	@echo "IntegrationResult (IR)" >>${HELPFILE}
-
-${HELP}/InterfaceGroebnerPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7455 create InterfaceGroebnerPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"InterfaceGroebnerPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/InterfaceGroebnerPackage.help
-	@cp -f ${HELP}/InterfaceGroebnerPackage.help ${HELP}/INTERGB.help
-	@${TANGLE} -R"InterfaceGroebnerPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/InterfaceGroebnerPackage.input
-	@echo "InterfaceGroebnerPackage (INTERGB)" >>${HELPFILE}
-
-${HELP}/InterpolateFormsPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7455 create InterpolateFormsPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"InterpolateFormsPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/InterpolateFormsPackage.help
-	@cp -f ${HELP}/InterpolateFormsPackage.help ${HELP}/INTFRSP.help
-	@${TANGLE} -R"InterpolateFormsPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/InterpolateFormsPackage.input
-	@echo "InterpolateFormsPackage (INTFRSP)" >>${HELPFILE}
-
-${HELP}/IntersectionDivisorPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7456 create IntersectionDivisorPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"IntersectionDivisorPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/IntersectionDivisorPackage.help
-	@cp -f ${HELP}/IntersectionDivisorPackage.help ${HELP}/INTDIVP.help
-	@${TANGLE} -R"IntersectionDivisorPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/IntersectionDivisorPackage.input
-	@echo "IntersectionDivisorPackage (INTDIVP)" >>${HELPFILE}
-
-${HELP}/Interval.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7457 create Interval.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Interval.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Interval.help
-	@cp -f ${HELP}/Interval.help ${HELP}/INTRVL.help
-	@${TANGLE} -R"Interval.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Interval.input
-	@echo "Interval (INTRVL)" >>${HELPFILE}
-
-${HELP}/IntervalCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create IntervalCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"IntervalCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/IntervalCategory.help
-	@cp -f ${HELP}/IntervalCategory.help ${HELP}/INTCAT.help
-	@${TANGLE} -R"IntervalCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/IntervalCategory.input
-	@echo "IntervalCategory (INTCAT)" >>${HELPFILE}
-
-${HELP}/Kernel.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7460 create Kernel.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Kernel.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Kernel.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Kernel.help ${HELP}/KERNEL.help ; \
-	 fi
-	@${TANGLE} -R"Kernel.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Kernel.input
-	@echo "Kernel (KERNEL)" >>${HELPFILE}
-
-${HELP}/KeyedAccessFile.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7470 create KeyedAccessFile.help from \
-              ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"KeyedAccessFile.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/KeyedAccessFile.help
-	@cp -f ${HELP}/KeyedAccessFile.help ${HELP}/KAFILE.help
-	@${TANGLE} -R"KeyedAccessFile.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/KeyedAccessFile.input
-	@echo "KeyedAccessFile (KAFILE)" >>${HELPFILE}
-
-${HELP}/KeyedDictionary.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create KeyedDictionary.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"KeyedDictionary.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/KeyedDictionary.help
-	@cp -f ${HELP}/KeyedDictionary.help ${HELP}/KDAGG.help
-	@${TANGLE} -R"KeyedDictionary.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/KeyedDictionary.input
-	@echo "KeyedDictionary (KDAGG)" >>${HELPFILE}
-
-${HELP}/LaurentPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create LaurentPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LaurentPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/LaurentPolynomial.help
-	@cp -f ${HELP}/LaurentPolynomial.help ${HELP}/LAUPOL.help
-	@${TANGLE} -R"LaurentPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LaurentPolynomial.input
-	@echo "LaurentPolynomial (LAUPOL)" >>${HELPFILE}
-
-${HELP}/LazyStreamAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create LazyStreamAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LazyStreamAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/LazyStreamAggregate.help
-	@cp -f ${HELP}/LazyStreamAggregate.help ${HELP}/LZSTAGG.help
-	@${TANGLE} -R"LazyStreamAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/LazyStreamAggregate.input
-	@echo "LazyStreamAggregate (LZSTAGG)" >>${HELPFILE}
-
-${HELP}/LazardSetSolvingPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7480 create LazardSetSolvingPackage.help from \
-              ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"LazardSetSolvingPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/LazardSetSolvingPackage.help
-	@cp -f ${HELP}/LazardSetSolvingPackage.help ${HELP}/LAZM3PK.help
-	@${TANGLE} -R"LazardSetSolvingPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/LazardSetSolvingPackage.input
-	@echo "LazardSetSolvingPackage (LAZM3PK)" >>${HELPFILE}
-
-${HELP}/LeftAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create LeftAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LeftAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/LeftAlgebra.help
-	@cp -f ${HELP}/LeftAlgebra.help ${HELP}/LALG.help
-	@${TANGLE} -R"LeftAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/LeftAlgebra.input
-	@echo "LeftAlgebra (LALG)" >>${HELPFILE}
-
-${HELP}/LeftModule.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create LeftModule.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LeftModule.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/LeftModule.help
-	@cp -f ${HELP}/LeftModule.help ${HELP}/LMODULE.help
-	@${TANGLE} -R"LeftModule.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/LeftModule.input
-	@echo "LeftModule (LMODULE)" >>${HELPFILE}
-
-${HELP}/LexTriangularPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7490 create LexTriangularPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"LexTriangularPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/LexTriangularPackage.help
-	@cp -f ${HELP}/LexTriangularPackage.help ${HELP}/LEXTRIPK.help
-	@${TANGLE} -R"LexTriangularPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/LexTriangularPackage.input
-	@echo "LexTriangularPackage (LEXTRIPK)" >>${HELPFILE}
-
-${HELP}/Library.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7500 create Library.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Library.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Library.help
-	@cp -f ${HELP}/Library.help ${HELP}/LIB.help
-	@${TANGLE} -R"Library.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Library.input
-	@echo "Library (LIB)" >>${HELPFILE}
-
-${HELP}/LieAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create LieAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LieAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/LieAlgebra.help
-	@cp -f ${HELP}/LieAlgebra.help ${HELP}/LIECAT.help
-	@${TANGLE} -R"LieAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/LieAlgebra.input
-	@echo "LieAlgebra (LIECAT)" >>${HELPFILE}
-
-${HELP}/LieExponentials.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7510 create LieExponentials.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LieExponentials.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/LieExponentials.help
-	@cp -f ${HELP}/LieExponentials.help ${HELP}/LEXP.help
-	@${TANGLE} -R"LieExponentials.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LieExponentials.input
-	@echo "LieExponentials (LEXP)" >>${HELPFILE}
-
-${HELP}/LiePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7520 create LiePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LiePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/LiePolynomial.help
-	@cp -f ${HELP}/LiePolynomial.help ${HELP}/LPOLY.help
-	@${TANGLE} -R"LiePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LiePolynomial.input
-	@echo "LiePolynomial (LPOLY)" >>${HELPFILE}
-
-${HELP}/LieSquareMatrix.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create LieSquareMatrix.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LieSquareMatrix.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/LieSquareMatrix.help
-	@cp -f ${HELP}/LieSquareMatrix.help ${HELP}/LSQM.help
-	@${TANGLE} -R"LieSquareMatrix.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LieSquareMatrix.input
-	@echo "LieSquareMatrix (LSQM)" >>${HELPFILE}
-
-${HELP}/LinearlyExplicitRingOver.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create LinearlyExplicitRingOver.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LinearlyExplicitRingOver.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/LinearlyExplicitRingOver.help
-	@cp -f ${HELP}/LinearlyExplicitRingOver.help ${HELP}/LINEXP.help
-	@${TANGLE} -R"LinearlyExplicitRingOver.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/LinearlyExplicitRingOver.input
-	@echo "LinearlyExplicitRingOver (LINEXP)" >>${HELPFILE}
-
-${HELP}/LinearAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create LinearAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LinearAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/LinearAggregate.help
-	@cp -f ${HELP}/LinearAggregate.help ${HELP}/LNAGG.help
-	@${TANGLE} -R"LinearAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/LinearAggregate.input
-	@echo "LinearAggregate (LNAGG)" >>${HELPFILE}
-
-${HELP}/LinearOrdinaryDifferentialOperator.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7530 create LinearOrdinaryDifferentialOperator.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LinearOrdinaryDifferentialOperator.help" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/LinearOrdinaryDifferentialOperator.help
-	@cp -f ${HELP}/LinearOrdinaryDifferentialOperator.help \
-           ${HELP}/LODO.help
-	@${TANGLE} -R"LinearOrdinaryDifferentialOperator.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LinearOrdinaryDifferentialOperator.input
-	@echo "LinearOrdinaryDifferentialOperator (LODO)" >>${HELPFILE}
-
-${HELP}/LinearOrdinaryDifferentialOperator1.help: \
-      ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7540 create LinearOrdinaryDifferentialOperator1.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LinearOrdinaryDifferentialOperator1.help" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/LinearOrdinaryDifferentialOperator1.help
-	@cp -f ${HELP}/LinearOrdinaryDifferentialOperator1.help \
-           ${HELP}/LODO1.help
-	@${TANGLE} -R"LinearOrdinaryDifferentialOperator1.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LinearOrdinaryDifferentialOperator1.input
-	@echo "LinearOrdinaryDifferentialOperator1 (LODO1)" >>${HELPFILE}
-
-${HELP}/LinearOrdinaryDifferentialOperator2.help: \
-     ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7550 create LinearOrdinaryDifferentialOperator2.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LinearOrdinaryDifferentialOperator2.help" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/LinearOrdinaryDifferentialOperator2.help
-	@cp -f ${HELP}/LinearOrdinaryDifferentialOperator2.help \
-           ${HELP}/LODO2.help
-	@${TANGLE} -R"LinearOrdinaryDifferentialOperator2.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LinearOrdinaryDifferentialOperator2.input
-	@echo "LinearOrdinaryDifferentialOperator2 (LODO2)" >>${HELPFILE}
-
-${HELP}/LinearOrdinaryDifferentialOperatorCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create LinearOrdinaryDifferentialOperatorCategory.help \
-           from ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LinearOrdinaryDifferentialOperatorCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/LinearOrdinaryDifferentialOperatorCategory.help
-	@cp -f ${HELP}/LinearOrdinaryDifferentialOperatorCategory.help \
-           ${HELP}/LODOCAT.help
-	@${TANGLE} -R"LinearOrdinaryDifferentialOperatorCategory.input" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${INPUT}/LinearOrdinaryDifferentialOperatorCategory.input
-	@echo "LinearOrdinaryDifferentialOperatorCategory (LODOCAT)" \
-           >>${HELPFILE}
-
-${HELP}/LinearSystemFromPowerSeriesPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7555 create LinearSystemFromPowerSeriesPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"LinearSystemFromPowerSeriesPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/LinearSystemFromPowerSeriesPackage.help
-	@cp -f ${HELP}/LinearSystemFromPowerSeriesPackage.help \
-           ${HELP}/LISYSER.help
-	@${TANGLE} -R"LinearSystemFromPowerSeriesPackage.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${INPUT}/LinearSystemFromPowerSeriesPackage.input
-	@echo "LinearSystemFromPowerSeriesPackage (LISYSER)" >>${HELPFILE}
-
-${HELP}/ListAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ListAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ListAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ListAggregate.help
-	@cp -f ${HELP}/ListAggregate.help ${HELP}/LSAGG.help
-	@${TANGLE} -R"ListAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ListAggregate.input
-	@echo "ListAggregate (LSAGG)" >>${HELPFILE}
-
-${HELP}/ListMonoidOps.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ListMonoidOps.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ListMonoidOps.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ListMonoidOps.help
-	@cp -f ${HELP}/ListMonoidOps.help ${HELP}/LMOPS.help
-	@${TANGLE} -R"ListMonoidOps.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ListMonoidOps.input
-	@echo "ListMonoidOps (LMOPS)" >>${HELPFILE}
-
-${HELP}/ListMultiDictionary.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ListMultiDictionary.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ListMultiDictionary.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ListMultiDictionary.help
-	@cp -f ${HELP}/ListMultiDictionary.help ${HELP}/LMDICT.help
-	@${TANGLE} -R"ListMultiDictionary.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ListMultiDictionary.input
-	@echo "ListMultiDictionary (LMDICT)" >>${HELPFILE}
-
-${HELP}/LiouvillianFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create LiouvillianFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LiouvillianFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/LiouvillianFunctionCategory.help
-	@cp -f ${HELP}/LiouvillianFunctionCategory.help ${HELP}/LFCAT.help
-	@${TANGLE} -R"LiouvillianFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/LiouvillianFunctionCategory.input
-	@echo "LiouvillianFunctionCategory (LFCAT)" >>${HELPFILE}
-
-${HELP}/List.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7560 create List.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"List.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/List.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/List.help ${HELP}/LIST.help ; \
-	 fi
-	@${TANGLE} -R"List.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/List.input
-	@echo "List (LIST)" >>${HELPFILE}
-
-${HELP}/LinesOpPack.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7565 create LinesOpPack.help from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"LinesOpPack.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/LinesOpPack.help
-	@cp -f ${HELP}/LinesOpPack.help ${HELP}/LOP.help
-	@${TANGLE} -R"LinesOpPack.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/LinesOpPack.input
-	@echo "LinesOpPack (LOP)" >>${HELPFILE}
-
-${HELP}/LocalAlgebra.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create LocalAlgebra.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LocalAlgebra.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/LocalAlgebra.help
-	@cp -f ${HELP}/LocalAlgebra.help ${HELP}/LA.help
-	@${TANGLE} -R"LocalAlgebra.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LocalAlgebra.input
-	@echo "LocalAlgebra (LA)" >>${HELPFILE}
-
-${HELP}/Localize.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Localize.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Localize.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Localize.help
-	@cp -f ${HELP}/Localize.help ${HELP}/LO.help
-	@${TANGLE} -R"Localize.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Localize.input
-	@echo "Localize (LO)" >>${HELPFILE}
-
-${HELP}/LocalParametrizationOfSimplePointPackage.help: \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7577 create LocalParametrizationOfSimplePointPackage.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"LocalParametrizationOfSimplePointPackage.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/LocalParametrizationOfSimplePointPackage.help
-	@cp -f ${HELP}/LocalParametrizationOfSimplePointPackage.help \
-            ${HELP}/LPARSPT.help
-	@${TANGLE} -R"LocalParametrizationOfSimplePointPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/LocalParametrizationOfSimplePointPackage.input
-	@echo "LocalParametrizationOfSimplePointPackage (LPARSPT)" \
-           >>${HELPFILE}
-
-${HELP}/LocalPowerSeriesCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7578 create LocalPowerSeriesCategory.help from \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"LocalPowerSeriesCategory.help" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${HELP}/LocalPowerSeriesCategory.help
-	@cp -f ${HELP}/LocalPowerSeriesCategory.help ${HELP}/LOCPOWC.help
-	@${TANGLE} -R"LocalPowerSeriesCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/LocalPowerSeriesCategory.input
-	@echo "LocalPowerSeriesCategory (LOCPOWC)" >>${HELPFILE}
-
-${HELP}/Logic.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Logic.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Logic.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Logic.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Logic.help ${HELP}/LOGIC.help ; \
-	 fi
-	@${TANGLE} -R"Logic.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Logic.input
-	@echo "Logic (LOGIC)" >>${HELPFILE}
-
-${HELP}/LyndonWord.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7570 create LyndonWord.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"LyndonWord.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/LyndonWord.help
-	@cp -f ${HELP}/LyndonWord.help ${HELP}/LWORD.help
-	@${TANGLE} -R"LyndonWord.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/LyndonWord.input
-	@echo "LyndonWord (LWORD)" >>${HELPFILE}
-
-${HELP}/MachineComplex.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MachineComplex.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MachineComplex.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MachineComplex.help
-	@cp -f ${HELP}/MachineComplex.help ${HELP}/MCMPLX.help
-	@${TANGLE} -R"MachineComplex.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MachineComplex.input
-	@echo "MachineComplex (MCMPLX)" >>${HELPFILE}
-
-${HELP}/MachineFloat.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MachineFloat.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MachineFloat.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MachineFloat.help
-	@cp -f ${HELP}/MachineFloat.help ${HELP}/MFLOAT.help
-	@${TANGLE} -R"MachineFloat.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MachineFloat.input
-	@echo "MachineFloat (MFLOAT)" >>${HELPFILE}
-
-${HELP}/MachineInteger.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MachineInteger.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MachineInteger.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MachineInteger.help
-	@cp -f ${HELP}/MachineInteger.help ${HELP}/MINT.help
-	@${TANGLE} -R"MachineInteger.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MachineInteger.input
-	@echo "MachineInteger (MINT)" >>${HELPFILE}
-
-${HELP}/Magma.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7580 create Magma.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Magma.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Magma.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Magma.help ${HELP}/MAGMA.help ; \
-	 fi
-	@${TANGLE} -R"Magma.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Magma.input
-	@echo "Magma (MAGMA)" >>${HELPFILE}
-
-${HELP}/MakeCachableSet.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MakeCachableSet.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MakeCachableSet.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MakeCachableSet.help
-	@cp -f ${HELP}/MakeCachableSet.help ${HELP}/MKCHSET.help
-	@${TANGLE} -R"MakeCachableSet.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MakeCachableSet.input
-	@echo "MakeCachableSet (MKCHSET)" >>${HELPFILE}
-
-${HELP}/MakeFunction.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7590 create MakeFunction.help from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"MakeFunction.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/MakeFunction.help
-	@cp -f ${HELP}/MakeFunction.help ${HELP}/MKFUNC.help
-	@${TANGLE} -R"MakeFunction.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/MakeFunction.input
-	@echo "MakeFunction (MKFUNC)" >>${HELPFILE}
-
-${HELP}/MappingPackage1.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7600 create MappingPackage1.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"MappingPackage1.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/MappingPackage1.help
-	@cp -f ${HELP}/MappingPackage1.help ${HELP}/MAPPKG1.help
-	@${TANGLE} -R"MappingPackage1.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/MappingPackage1.input
-	@echo "MappingPackage1 (MAPPKG1)" >>${HELPFILE}
-
-${HELP}/MappingPackage2.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7610 create MappingPackage2.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"MappingPackage2.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/MappingPackage2.help
-	@cp -f ${HELP}/MappingPackage2.help ${HELP}/MAPPKG2.help
-	@${TANGLE} -R"MappingPackage2.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/MappingPackage2.input
-	@echo "MappingPackage2 (MAPPKG2)" >>${HELPFILE}
-
-${HELP}/MappingPackage3.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7620 create MappingPackage3.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"MappingPackage3.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/MappingPackage3.help
-	@cp -f ${HELP}/MappingPackage3.help ${HELP}/MAPPKG3.help
-	@${TANGLE} -R"MappingPackage3.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/MappingPackage3.input
-	@echo "MappingPackage3 (MAPPKG3)" >>${HELPFILE}
-
-${HELP}/MathMLFormat.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MathMLFormat.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MathMLFormat.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MathMLFormat.help
-	@cp -f ${HELP}/MathMLFormat.help ${HELP}/MMLFORM.help
-	@${TANGLE} -R"MathMLFormat.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MathMLFormat.input
-	@echo "MathMLFormat (MMLFORM)" >>${HELPFILE}
-
-${HELP}/Matrix.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7630 create Matrix.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Matrix.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Matrix.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Matrix.help ${HELP}/MATRIX.help ; \
-	 fi
-	@${TANGLE} -R"Matrix.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Matrix.input
-	@echo "Matrix (MATRIX)" >>${HELPFILE}
-
-${HELP}/MatrixCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7640 create MatrixCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"MatrixCategory.help" ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/MatrixCategory.help
-	@cp -f ${HELP}/MatrixCategory.help ${HELP}/MATCAT.help
-	@${TANGLE} -R"MatrixCategory.input" ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/MatrixCategory.input
-	@echo "MatrixCategory (MATCAT)" >>${HELPFILE}
-
-${HELP}/ModMonic.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ModMonic.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ModMonic.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ModMonic.help
-	@cp -f ${HELP}/ModMonic.help ${HELP}/MODMON.help
-	@${TANGLE} -R"ModMonic.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ModMonic.input
-	@echo "ModMonic (MODMON)" >>${HELPFILE}
-
-${HELP}/ModularField.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ModularField.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ModularField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ModularField.help
-	@cp -f ${HELP}/ModularField.help ${HELP}/MODFIELD.help
-	@${TANGLE} -R"ModularField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ModularField.input
-	@echo "ModularField (MODFIELD)" >>${HELPFILE}
-
-${HELP}/ModularRing.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ModularRing.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ModularRing.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ModularRing.help
-	@cp -f ${HELP}/ModularRing.help ${HELP}/MODRING.help
-	@${TANGLE} -R"ModularRing.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ModularRing.input
-	@echo "ModularRing (MODRING)" >>${HELPFILE}
-
-${HELP}/Module.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Module.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Module.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Module.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Module.help ${HELP}/MODULE.help ; \
-	 fi
-	@${TANGLE} -R"Module.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Module.input
-	@echo "Module (MODULE)" >>${HELPFILE}
-
-${HELP}/ModuleMonomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ModuleMonomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ModuleMonomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ModuleMonomial.help
-	@cp -f ${HELP}/ModuleMonomial.help ${HELP}/MODMONOM.help
-	@${TANGLE} -R"ModuleMonomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ModuleMonomial.input
-	@echo "ModuleMonomial (MODMONOM)" >>${HELPFILE}
-
-${HELP}/ModuleOperator.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ModuleOperator.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ModuleOperator.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ModuleOperator.help
-	@cp -f ${HELP}/ModuleOperator.help ${HELP}/MODOP.help
-	@${TANGLE} -R"ModuleOperator.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ModuleOperator.input
-	@echo "ModuleOperator (MODOP)" >>${HELPFILE}
-
-${HELP}/MoebiusTransform.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MoebiusTransform.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MoebiusTransform.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MoebiusTransform.help
-	@cp -f ${HELP}/MoebiusTransform.help ${HELP}/MOEBIUS.help
-	@${TANGLE} -R"MoebiusTransform.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MoebiusTransform.input
-	@echo "MoebiusTransform (MOEBIUS)" >>${HELPFILE}
-
-${HELP}/Monad.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Monad.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Monad.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Monad.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Monad.help ${HELP}/MONAD.help ; \
-	 fi
-	@${TANGLE} -R"Monad.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Monad.input
-	@echo "Monad (MONAD)" >>${HELPFILE}
-
-${HELP}/MonadWithUnit.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create MonadWithUnit.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"MonadWithUnit.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/MonadWithUnit.help
-	@cp -f ${HELP}/MonadWithUnit.help ${HELP}/MONADWU.help
-	@${TANGLE} -R"MonadWithUnit.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/MonadWithUnit.input
-	@echo "MonadWithUnit (MONADWU)" >>${HELPFILE}
-
-${HELP}/MonogenicAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create MonogenicAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"MonogenicAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/MonogenicAlgebra.help
-	@cp -f ${HELP}/MonogenicAlgebra.help ${HELP}/MONOGEN.help
-	@${TANGLE} -R"MonogenicAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/MonogenicAlgebra.input
-	@echo "MonogenicAlgebra (MONOGEN)" >>${HELPFILE}
-
-${HELP}/MonogenicLinearOperator.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create MonogenicLinearOperator.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"MonogenicLinearOperator.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/MonogenicLinearOperator.help
-	@cp -f ${HELP}/MonogenicLinearOperator.help ${HELP}/MLO.help
-	@${TANGLE} -R"MonogenicLinearOperator.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/MonogenicLinearOperator.input
-	@echo "MonogenicLinearOperator (MLO)" >>${HELPFILE}
-
-${HELP}/MonoidRing.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MonoidRing.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MonoidRing.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MonoidRing.help
-	@cp -f ${HELP}/MonoidRing.help ${HELP}/MRING.help
-	@${TANGLE} -R"MonoidRing.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MonoidRing.input
-	@echo "MonoidRing (MRING)" >>${HELPFILE}
-
-${HELP}/Monoid.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Monoid.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Monoid.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Monoid.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Monoid.help ${HELP}/MONOID.help ; \
-	 fi
-	@${TANGLE} -R"Monoid.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Monoid.input
-	@echo "Monoid (MONOID)" >>${HELPFILE}
-
-${HELP}/MultiDictionary.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create MultiDictionary.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"MultiDictionary.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/MultiDictionary.help
-	@cp -f ${HELP}/MultiDictionary.help ${HELP}/MDAGG.help
-	@${TANGLE} -R"MultiDictionary.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/MultiDictionary.input
-	@echo "MultiDictionary (MDAGG)" >>${HELPFILE}
-
-${HELP}/Multiset.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7650 create Multiset.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Multiset.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Multiset.help
-	@cp -f ${HELP}/Multiset.help ${HELP}/MSET.help
-	@${TANGLE} -R"Multiset.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Multiset.input
-	@echo "Multiset (MSET)" >>${HELPFILE}
-
-${HELP}/MultisetAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create MultisetAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"MultisetAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/MultisetAggregate.help
-	@cp -f ${HELP}/MultisetAggregate.help ${HELP}/MSETAGG.help
-	@${TANGLE} -R"MultisetAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/MultisetAggregate.input
-	@echo "MultisetAggregate (MSETAGG)" >>${HELPFILE}
-
-${HELP}/MultivariatePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7660 create MultivariatePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MultivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MultivariatePolynomial.help
-	@cp -f ${HELP}/MultivariatePolynomial.help ${HELP}/MPOLY.help
-	@${TANGLE} -R"MultivariatePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MultivariatePolynomial.input
-	@echo "MultivariatePolynomial (MPOLY)" >>${HELPFILE}
-
-${HELP}/MultivariateTaylorSeriesCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create MultivariateTaylorSeriesCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"MultivariateTaylorSeriesCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/MultivariateTaylorSeriesCategory.help
-	@cp -f ${HELP}/MultivariateTaylorSeriesCategory.help \
-            ${HELP}/MTSCAT.help
-	@${TANGLE} -R"MultivariateTaylorSeriesCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/MultivariateTaylorSeriesCategory.input
-	@echo "MultivariateTaylorSeriesCategory (MTSCAT)" >>${HELPFILE}
-
-${HELP}/MyExpression.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MyExpression.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MyExpression.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MyExpression.help
-	@cp -f ${HELP}/MyExpression.help ${HELP}/MYEXPR.help
-	@${TANGLE} -R"MyExpression.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MyExpression.input
-	@echo "MyExpression (MYEXPR)" >>${HELPFILE}
-
-${HELP}/MyUnivariatePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create MyUnivariatePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"MyUnivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/MyUnivariatePolynomial.help
-	@cp -f ${HELP}/MyUnivariatePolynomial.help ${HELP}/MYUP.help
-	@${TANGLE} -R"MyUnivariatePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/MyUnivariatePolynomial.input
-	@echo "MyUnivariatePolynomial (MYUP)" >>${HELPFILE}
-
-${HELP}/NewSparseMultivariatePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create NewSparseMultivariatePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NewSparseMultivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/NewSparseMultivariatePolynomial.help
-	@cp -f ${HELP}/NewSparseMultivariatePolynomial.help ${HELP}/NSMP.help
-	@${TANGLE} -R"NewSparseMultivariatePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NewSparseMultivariatePolynomial.input
-	@echo "NewSparseMultivariatePolynomial (NSMP)" >>${HELPFILE}
-
-${HELP}/NewSparseUnivariatePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create NewSparseUnivariatePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NewSparseUnivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/NewSparseUnivariatePolynomial.help
-	@cp -f ${HELP}/NewSparseUnivariatePolynomial.help ${HELP}/NSUP.help
-	@${TANGLE} -R"NewSparseUnivariatePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NewSparseUnivariatePolynomial.input
-	@echo "NewSparseUnivariatePolynomial (NSUP)" >>${HELPFILE}
-
-${HELP}/NagEigenPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7670 create NagEigenPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagEigenPackage.help" ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagEigenPackage.help
-	@cp -f ${HELP}/NagEigenPackage.help ${HELP}/NAGF02.help
-	@echo "NagEigenPackage (NAGF02)" >>${HELPFILE}
-
-${HELP}/NagFittingPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7680 create NagFittingPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagFittingPackage.help" ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagFittingPackage.help
-	@cp -f ${HELP}/NagFittingPackage.help ${HELP}/NAGE02.help
-	@echo "NagFittingPackage (NAGE02)" >>${HELPFILE}
-
-${HELP}/NagLinearEquationSolvingPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7690 create NagLinearEquationSolvingPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagLinearEquationSolvingPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagLinearEquationSolvingPackage.help
-	@cp -f ${HELP}/NagLinearEquationSolvingPackage.help ${HELP}/NAGF04.help
-	@echo "NagLinearEquationSolvingPackage (NAGF04)" >>${HELPFILE}
-
-${HELP}/NagIntegrationPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7700 create NagIntegrationPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagIntegrationPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagIntegrationPackage.help
-	@cp -f ${HELP}/NagIntegrationPackage.help ${HELP}/NAGD01.help
-	@echo "NagIntegrationPackage (NAGD01)" >>${HELPFILE}
-
-${HELP}/NagInterpolationPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7710 create NagInterpolationPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagInterpolationPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagInterpolationPackage.help
-	@cp -f ${HELP}/NagInterpolationPackage.help ${HELP}/NAGE01.help
-	@echo "NagInterpolationPackage (NAGE01)" >>${HELPFILE}
-
-${HELP}/NagLapack.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7720 create NagLapack.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagLapack.help" ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagLapack.help
-	@cp -f ${HELP}/NagLapack.help ${HELP}/NAGF07.help
-	@echo "NagLapack (NAGF07)" >>${HELPFILE}
-
-${HELP}/NagMatrixOperationsPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7730 create NagMatrixOperationsPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagMatrixOperationsPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagMatrixOperationsPackage.help
-	@cp -f ${HELP}/NagMatrixOperationsPackage.help ${HELP}/NAGF01.help
-	@echo "NagMatrixOperationsPackage (NAGF01)" >>${HELPFILE}
-
-${HELP}/NagOptimisationPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7740 create NagOptimisationPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagOptimisationPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagOptimisationPackage.help
-	@cp -f ${HELP}/NagOptimisationPackage.help ${HELP}/NAGE04.help
-	@echo "NagOptimisationPackage (NAGE04)" >>${HELPFILE}
-
-${HELP}/NagOrdinaryDifferentialEquationsPackage.help: \
-  ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7750 create NagOrdinaryDifferentialEquationsPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagOrdinaryDifferentialEquationsPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagOrdinaryDifferentialEquationsPackage.help
-	@cp -f ${HELP}/NagOrdinaryDifferentialEquationsPackage.help \
-             ${HELP}/NAGD02.help
-	@echo "NagOrdinaryDifferentialEquationsPackage (NAGD02)" >>${HELPFILE}
-
-${HELP}/NagPartialDifferentialEquationsPackage.help: \
-  ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7760 create NagPartialDifferentialEquationsPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagPartialDifferentialEquationsPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagPartialDifferentialEquationsPackage.help
-	@cp -f ${HELP}/NagPartialDifferentialEquationsPackage.help \
-             ${HELP}/NAGD03.help
-	@echo "NagPartialDifferentialEquationsPackage (NAGD03)" >>${HELPFILE}
-
-${HELP}/NagPolynomialRootsPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7770 create NagPolynomialRootsPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagPolynomialRootsPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagPolynomialRootsPackage.help
-	@cp -f ${HELP}/NagPolynomialRootsPackage.help ${HELP}/NAGC02.help
-	@echo "NagPolynomialRootsPackage (NAGC02)" >>${HELPFILE}
-
-${HELP}/NagRootFindingPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7780 create NagRootFindingPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagRootFindingPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagRootFindingPackage.help
-	@cp -f ${HELP}/NagRootFindingPackage.help ${HELP}/NAGC05.help
-	@echo "NagRootFindingPackage (NAGC05)" >>${HELPFILE}
-
-${HELP}/NagSeriesSummationPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7790 create NagSeriesSummationPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagSeriesSummationPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagSeriesSummationPackage.help
-	@cp -f ${HELP}/NagSeriesSummationPackage.help ${HELP}/NAGC06.help
-	@echo "NagSeriesSummationPackage (NAGC06)" >>${HELPFILE}
-
-${HELP}/NagSpecialFunctionsPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7800 create NagSpecialFunctionsPackage.help from \
-             ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NagSpecialFunctionsPackage.help" \
-             ${BOOKS}/bookvol10.4.pamphlet \
-             >${HELP}/NagSpecialFunctionsPackage.help
-	@cp -f ${HELP}/NagSpecialFunctionsPackage.help ${HELP}/NAGS.help
-	@echo "NagSpecialFunctionsPackage (NAGS)" >>${HELPFILE}
-
-${HELP}/NeitherSparseOrDensePowerSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7805 create NeitherSparseOrDensePowerSeries.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NeitherSparseOrDensePowerSeries.help" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/NeitherSparseOrDensePowerSeries.help
-	@cp -f ${HELP}/NeitherSparseOrDensePowerSeries.help ${HELP}/NSDPS.help
-	@${TANGLE} -R"NeitherSparseOrDensePowerSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NeitherSparseOrDensePowerSeries.input
-	@echo "NeitherSparseOrDensePowerSeries (NSDPS)" >>${HELPFILE}
-
-${HELP}/NewtonPolygon.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7807 create NewtonPolygon.help from \
-            ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"NewtonPolygon.help" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${HELP}/NewtonPolygon.help
-	@cp -f ${HELP}/NewtonPolygon.help ${HELP}/NPOLYGON.help
-	@${TANGLE} -R"NewtonPolygon.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/NewtonPolygon.input
-	@echo "NewtonPolygon (NPOLYGON)" >>${HELPFILE}
-
-${HELP}/NonAssociativeAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create NonAssociativeAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"NonAssociativeAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/NonAssociativeAlgebra.help
-	@cp -f ${HELP}/NonAssociativeAlgebra.help ${HELP}/NAALG.help
-	@${TANGLE} -R"NonAssociativeAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/NonAssociativeAlgebra.input
-	@echo "NonAssociativeAlgebra (NAALG)" >>${HELPFILE}
-
-${HELP}/NonAssociativeRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create NonAssociativeRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"NonAssociativeRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/NonAssociativeRing.help
-	@cp -f ${HELP}/NonAssociativeRing.help ${HELP}/NASRING.help
-	@${TANGLE} -R"NonAssociativeRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/NonAssociativeRing.input
-	@echo "NonAssociativeRing (NASRING)" >>${HELPFILE}
-
-${HELP}/NonAssociativeRng.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create NonAssociativeRng.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"NonAssociativeRng.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/NonAssociativeRng.help
-	@cp -f ${HELP}/NonAssociativeRng.help ${HELP}/NARNG.help
-	@${TANGLE} -R"NonAssociativeRng.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/NonAssociativeRng.input
-	@echo "NonAssociativeRng (NARNG)" >>${HELPFILE}
-
-${HELP}/None.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7810 create None.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"None.help" ${BOOKS}/bookvol10.3.pamphlet \
-             >${HELP}/None.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/None.help ${HELP}/NONE.help ; \
-	 fi
-	@${TANGLE} -R"None.input" ${BOOKS}/bookvol10.3.pamphlet \
-             >${INPUT}/None.input
-	@echo "None (NONE)" >>${HELPFILE}
-
-${HELP}/NonNegativeInteger.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create NonNegativeInteger.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NonNegativeInteger.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/NonNegativeInteger.help
-	@cp -f ${HELP}/NonNegativeInteger.help ${HELP}/NNI.help
-	@${TANGLE} -R"NonNegativeInteger.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NonNegativeInteger.input
-	@echo "NonNegativeInteger (NNI)" >>${HELPFILE}
-
-${HELP}/NormalizedTriangularSetCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create NormalizedTriangularSetCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"NormalizedTriangularSetCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/NormalizedTriangularSetCategory.help
-	@cp -f ${HELP}/NormalizedTriangularSetCategory.help ${HELP}/NTSCAT.help
-	@${TANGLE} -R"NormalizedTriangularSetCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/NormalizedTriangularSetCategory.input
-	@echo "NormalizedTriangularSetCategory (NTSCAT)" >>${HELPFILE}
-
-${HELP}/NottinghamGroup.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7820 create NottinghamGroup.help from \
-             ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NottinghamGroup.help" ${BOOKS}/bookvol10.3.pamphlet \
-             >${HELP}/NottinghamGroup.help
-	@cp -f ${HELP}/NottinghamGroup.help ${HELP}/NOTTING.help
-	@${TANGLE} -R"NottinghamGroup.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NottinghamGroup.input
-	@echo "NottinghamGroup (NOTTING)" >>${HELPFILE}
-
-${HELP}/NumericalIntegrationCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create NumericalIntegrationCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"NumericalIntegrationCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/NumericalIntegrationCategory.help
-	@cp -f ${HELP}/NumericalIntegrationCategory.help ${HELP}/NUMINT.help
-	@${TANGLE} -R"NumericalIntegrationCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/NumericalIntegrationCategory.input
-	@echo "NumericalIntegrationCategory (NUMINT)" >>${HELPFILE}
-
-${HELP}/NumericalIntegrationProblem.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create NumericalIntegrationProblem.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NumericalIntegrationProblem.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/NumericalIntegrationProblem.help
-	@cp -f ${HELP}/NumericalIntegrationProblem.help ${HELP}/NIPROB.help
-	@${TANGLE} -R"NumericalIntegrationProblem.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NumericalIntegrationProblem.input
-	@echo "NumericalIntegrationProblem (NIPROB)" >>${HELPFILE}
-
-${HELP}/NumericalODEProblem.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create NumericalODEProblem.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NumericalODEProblem.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/NumericalODEProblem.help
-	@cp -f ${HELP}/NumericalODEProblem.help ${HELP}/ODEPROB.help
-	@${TANGLE} -R"NumericalODEProblem.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NumericalODEProblem.input
-	@echo "NumericalODEProblem (ODEPROB)" >>${HELPFILE}
-
-${HELP}/NumericalOptimizationCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create NumericalOptimizationCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"NumericalOptimizationCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/NumericalOptimizationCategory.help
-	@cp -f ${HELP}/NumericalOptimizationCategory.help ${HELP}/OPTCAT.help
-	@${TANGLE} -R"NumericalOptimizationCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/NumericalOptimizationCategory.input
-	@echo "NumericalOptimizationCategory (OPTCAT)" >>${HELPFILE}
-
-${HELP}/NumericalOptimizationProblem.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create NumericalOptimizationProblem.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NumericalOptimizationProblem.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/NumericalOptimizationProblem.help
-	@cp -f ${HELP}/NumericalOptimizationProblem.help ${HELP}/OPTPROB.help
-	@${TANGLE} -R"NumericalOptimizationProblem.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NumericalOptimizationProblem.input
-	@echo "NumericalOptimizationProblem (OPTPROB)" >>${HELPFILE}
-
-${HELP}/NumericalPDEProblem.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create NumericalPDEProblem.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"NumericalPDEProblem.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/NumericalPDEProblem.help
-	@cp -f ${HELP}/NumericalPDEProblem.help ${HELP}/PDEPROB.help
-	@${TANGLE} -R"NumericalPDEProblem.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/NumericalPDEProblem.input
-	@echo "NumericalPDEProblem (PDEPROB)" >>${HELPFILE}
-
-${HELP}/Octonion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7830 create Octonion.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Octonion.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Octonion.help
-	@cp -f ${HELP}/Octonion.help ${HELP}/OCT.help
-	@${TANGLE} -R"Octonion.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Octonion.input
-	@echo "Octonion (OCT)" >>${HELPFILE}
-
-${HELP}/OctonionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OctonionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OctonionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OctonionCategory.help
-	@cp -f ${HELP}/OctonionCategory.help ${HELP}/OC.help
-	@${TANGLE} -R"OctonionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OctonionCategory.input
-	@echo "OctonionCategory (OC)" >>${HELPFILE}
-
-${HELP}/ODEIntensityFunctionsTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ODEIntensityFunctionsTable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ODEIntensityFunctionsTable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ODEIntensityFunctionsTable.help
-	@cp -f ${HELP}/ODEIntensityFunctionsTable.help ${HELP}/ODEIFTBL.help
-	@${TANGLE} -R"ODEIntensityFunctionsTable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ODEIntensityFunctionsTable.input
-	@echo "ODEIntensityFunctionsTable (ODEIFTBL)" >>${HELPFILE}
-
-${HELP}/OneDimensionalArray.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7840 create OneDimensionalArray.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OneDimensionalArray.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OneDimensionalArray.help
-	@cp -f ${HELP}/OneDimensionalArray.help ${HELP}/ARRAY1.help
-	@${TANGLE} -R"OneDimensionalArray.input"  \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OneDimensionalArray.input
-	@echo "OneDimensionalArray (ARRAY1)" >>${HELPFILE}
-
-${HELP}/OneDimensionalArrayAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OneDimensionalArrayAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OneDimensionalArrayAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OneDimensionalArrayAggregate.help
-	@cp -f ${HELP}/OneDimensionalArrayAggregate.help ${HELP}/A1AGG.help
-	@${TANGLE} -R"OneDimensionalArrayAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OneDimensionalArrayAggregate.input
-	@echo "OneDimensionalArrayAggregate (A1AGG)" >>${HELPFILE}
-
-${HELP}/OnePointCompletion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OnePointCompletion.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OnePointCompletion.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OnePointCompletion.help
-	@cp -f ${HELP}/OnePointCompletion.help ${HELP}/ONECOMP.help
-	@${TANGLE} -R"OnePointCompletion.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OnePointCompletion.input
-	@echo "OnePointCompletion (ONECOMP)" >>${HELPFILE}
-
-${HELP}/OpenMath.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OpenMath.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OpenMath.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OpenMath.help
-	@cp -f ${HELP}/OpenMath.help ${HELP}/OM.help
-	@${TANGLE} -R"OpenMath.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OpenMath.input
-	@echo "OpenMath (OM)" >>${HELPFILE}
-
-${HELP}/OpenMathConnection.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OpenMathConnection.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OpenMathConnection.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OpenMathConnection.help
-	@cp -f ${HELP}/OpenMathConnection.help ${HELP}/OMCONN.help
-	@${TANGLE} -R"OpenMathConnection.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OpenMathConnection.input
-	@echo "OpenMathConnection (OMCONN)" >>${HELPFILE}
-
-${HELP}/OpenMathDevice.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OpenMathDevice.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OpenMathDevice.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OpenMathDevice.help
-	@cp -f ${HELP}/OpenMathDevice.help ${HELP}/OMDEV.help
-	@${TANGLE} -R"OpenMathDevice.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OpenMathDevice.input
-	@echo "OpenMathDevice (OMDEV)" >>${HELPFILE}
-
-${HELP}/OpenMathEncoding.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OpenMathEncoding.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OpenMathEncoding.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OpenMathEncoding.help
-	@cp -f ${HELP}/OpenMathEncoding.help ${HELP}/OMENC.help
-	@${TANGLE} -R"OpenMathEncoding.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OpenMathEncoding.input
-	@echo "OpenMathEncoding (OMENC)" >>${HELPFILE}
-
-${HELP}/OpenMathError.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OpenMathError.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OpenMathError.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OpenMathError.help
-	@cp -f ${HELP}/OpenMathError.help ${HELP}/OMERR.help
-	@${TANGLE} -R"OpenMathError.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OpenMathError.input
-	@echo "OpenMathError (OMERR)" >>${HELPFILE}
-
-${HELP}/OpenMathErrorKind.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OpenMathErrorKind.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OpenMathErrorKind.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OpenMathErrorKind.help
-	@cp -f ${HELP}/OpenMathErrorKind.help ${HELP}/OMERRK.help
-	@${TANGLE} -R"OpenMathErrorKind.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OpenMathErrorKind.input
-	@echo "OpenMathErrorKind (OMERRK)" >>${HELPFILE}
-
-${HELP}/Operator.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7850 create Operator.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Operator.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Operator.help
-	@cp -f ${HELP}/Operator.help ${HELP}/OP.help
-	@${TANGLE} -R"Operator.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Operator.input
-	@echo "Operator (OP)" >>${HELPFILE}
-
-${HELP}/OppositeMonogenicLinearOperator.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OppositeMonogenicLinearOperator.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OppositeMonogenicLinearOperator.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OppositeMonogenicLinearOperator.help
-	@cp -f ${HELP}/OppositeMonogenicLinearOperator.help ${HELP}/OMLO.help
-	@${TANGLE} -R"OppositeMonogenicLinearOperator.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OppositeMonogenicLinearOperator.input
-	@echo "OppositeMonogenicLinearOperator (OMLO)" >>${HELPFILE}
-
-${HELP}/OrderedAbelianGroup.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedAbelianGroup.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedAbelianGroup.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedAbelianGroup.help
-	@cp -f ${HELP}/OrderedAbelianGroup.help ${HELP}/OAGROUP.help
-	@${TANGLE} -R"OrderedAbelianGroup.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedAbelianGroup.input
-	@echo "OrderedAbelianGroup (OAGROUP)" >>${HELPFILE}
-
-${HELP}/OrderedAbelianMonoid.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedAbelianMonoid.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedAbelianMonoid.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedAbelianMonoid.help
-	@cp -f ${HELP}/OrderedAbelianMonoid.help ${HELP}/OAMON.help
-	@${TANGLE} -R"OrderedAbelianMonoid.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedAbelianMonoid.input
-	@echo "OrderedAbelianMonoid (OAMON)" >>${HELPFILE}
-
-${HELP}/OrderedAbelianMonoidSup.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedAbelianMonoidSup.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedAbelianMonoidSup.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedAbelianMonoidSup.help
-	@cp -f ${HELP}/OrderedAbelianMonoidSup.help ${HELP}/OAMONS.help
-	@${TANGLE} -R"OrderedAbelianMonoidSup.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedAbelianMonoidSup.input
-	@echo "OrderedAbelianMonoidSup (OAMONS)" >>${HELPFILE}
-
-${HELP}/OrderedAbelianSemiGroup.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedAbelianSemiGroup.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedAbelianSemiGroup.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedAbelianSemiGroup.help
-	@cp -f ${HELP}/OrderedAbelianSemiGroup.help ${HELP}/OASGP.help
-	@${TANGLE} -R"OrderedAbelianSemiGroup.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedAbelianSemiGroup.input
-	@echo "OrderedAbelianSemiGroup (OASGP)" >>${HELPFILE}
-
-${HELP}/OrderedCancellationAbelianMonoid.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedCancellationAbelianMonoid.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedCancellationAbelianMonoid.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedCancellationAbelianMonoid.help
-	@cp -f ${HELP}/OrderedCancellationAbelianMonoid.help \
-            ${HELP}/OCAMON.help
-	@${TANGLE} -R"OrderedCancellationAbelianMonoid.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedCancellationAbelianMonoid.input
-	@echo "OrderedCancellationAbelianMonoid (OCAMON)" >>${HELPFILE}
-
-${HELP}/OrderedCompletion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OrderedCompletion.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrderedCompletion.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrderedCompletion.help
-	@cp -f ${HELP}/OrderedCompletion.help ${HELP}/ORDCOMP.help
-	@${TANGLE} -R"OrderedCompletion.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrderedCompletion.input
-	@echo "OrderedCompletion (ORDCOMP)" >>${HELPFILE}
-
-${HELP}/OrderedDirectProduct.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OrderedDirectProduct.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrderedDirectProduct.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrderedDirectProduct.help
-	@cp -f ${HELP}/OrderedDirectProduct.help ${HELP}/ODP.help
-	@${TANGLE} -R"OrderedDirectProduct.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrderedDirectProduct.input
-	@echo "OrderedDirectProduct (ODP)" >>${HELPFILE}
-
-${HELP}/OrderedFinite.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedFinite.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedFinite.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedFinite.help
-	@cp -f ${HELP}/OrderedFinite.help ${HELP}/ORDFIN.help
-	@${TANGLE} -R"OrderedFinite.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedFinite.input
-	@echo "OrderedFinite (ORDFIN)" >>${HELPFILE}
-
-${HELP}/OrderedFreeMonoid.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7855 create OrderedFreeMonoid.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrderedFreeMonoid.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrderedFreeMonoid.help
-	@cp -f ${HELP}/OrderedFreeMonoid.help ${HELP}/OFMONOID.help
-	@${TANGLE} -R"OrderedFreeMonoid.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrderedFreeMonoid.input
-	@echo "OrderedFreeMonoid (OFMONOID)" >>${HELPFILE}
-
-${HELP}/OrderedIntegralDomain.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedIntegralDomain.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedIntegralDomain.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedIntegralDomain.help
-	@cp -f ${HELP}/OrderedIntegralDomain.help ${HELP}/OINTDOM.help
-	@${TANGLE} -R"OrderedIntegralDomain.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedIntegralDomain.input
-	@echo "OrderedIntegralDomain (OINTDOM)" >>${HELPFILE}
-
-${HELP}/OrderedMonoid.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedMonoid.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedMonoid.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedMonoid.help
-	@cp -f ${HELP}/OrderedMonoid.help ${HELP}/ORDMON.help
-	@${TANGLE} -R"OrderedMonoid.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedMonoid.input
-	@echo "OrderedMonoid (ORDMON)" >>${HELPFILE}
-
-${HELP}/OrderedMultisetAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedMultisetAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedMultisetAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedMultisetAggregate.help
-	@cp -f ${HELP}/OrderedMultisetAggregate.help ${HELP}/OMSAGG.help
-	@${TANGLE} -R"OrderedMultisetAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedMultisetAggregate.input
-	@echo "OrderedMultisetAggregate (OMSAGG)" >>${HELPFILE}
-
-${HELP}/OrderedRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedRing.help
-	@cp -f ${HELP}/OrderedRing.help ${HELP}/ORDRING.help
-	@${TANGLE} -R"OrderedRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedRing.input
-	@echo "OrderedRing (ORDRING)" >>${HELPFILE}
-
-${HELP}/OrderedSet.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create OrderedSet.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrderedSet.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrderedSet.help
-	@cp -f ${HELP}/OrderedSet.help ${HELP}/ORDSET.help
-	@${TANGLE} -R"OrderedSet.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrderedSet.input
-	@echo "OrderedSet (ORDSET)" >>${HELPFILE}
-
-${HELP}/OrderedVariableList.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7860 create OrderedVariableList.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrderedVariableList.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrderedVariableList.help
-	@cp -f ${HELP}/OrderedVariableList.help ${HELP}/OVAR.help
-	@${TANGLE} -R"OrderedVariableList.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrderedVariableList.input
-	@echo "OrderedVariableList (OVAR)" >>${HELPFILE}
-
-${HELP}/OrderlyDifferentialPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7870 create OrderlyDifferentialPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrderlyDifferentialPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrderlyDifferentialPolynomial.help
-	@cp -f ${HELP}/OrderlyDifferentialPolynomial.help ${HELP}/ODPOL.help
-	@${TANGLE} -R"OrderlyDifferentialPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrderlyDifferentialPolynomial.input
-	@echo "OrderlyDifferentialPolynomial (ODPOL)" >>${HELPFILE}
-
-${HELP}/OrderlyDifferentialVariable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OrderlyDifferentialVariable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrderlyDifferentialVariable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrderlyDifferentialVariable.help
-	@cp -f ${HELP}/OrderlyDifferentialVariable.help ${HELP}/ODVAR.help
-	@${TANGLE} -R"OrderlyDifferentialVariable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrderlyDifferentialVariable.input
-	@echo "OrderlyDifferentialVariable (ODVAR)" >>${HELPFILE}
-
-${HELP}/OrdinaryDifferentialEquationsSolverCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create \
-           OrdinaryDifferentialEquationsSolverCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"OrdinaryDifferentialEquationsSolverCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/OrdinaryDifferentialEquationsSolverCategory.help
-	@cp -f ${HELP}/OrdinaryDifferentialEquationsSolverCategory.help \
-            ${HELP}/ODECAT.help
-	@${TANGLE} -R"OrdinaryDifferentialEquationsSolverCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/OrdinaryDifferentialEquationsSolverCategory.input
-	@echo "OrdinaryDifferentialEquationsSolverCategory (ODECAT)" \
-           >>${HELPFILE}
-
-${HELP}/OrdinaryDifferentialRing.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OrdinaryDifferentialRing.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrdinaryDifferentialRing.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrdinaryDifferentialRing.help
-	@cp -f ${HELP}/OrdinaryDifferentialRing.help ${HELP}/ODR.help
-	@${TANGLE} -R"OrdinaryDifferentialRing.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrdinaryDifferentialRing.input
-	@echo "OrdinaryDifferentialRing (ODR)" >>${HELPFILE}
-
-${HELP}/OrdinaryWeightedPolynomials.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OrdinaryWeightedPolynomials.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrdinaryWeightedPolynomials.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrdinaryWeightedPolynomials.help
-	@cp -f ${HELP}/OrdinaryWeightedPolynomials.help ${HELP}/OWP.help
-	@${TANGLE} -R"OrdinaryWeightedPolynomials.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrdinaryWeightedPolynomials.input
-	@echo "OrdinaryWeightedPolynomials (OWP)" >>${HELPFILE}
-
-${HELP}/OrdSetInts.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OrdSetInts.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OrdSetInts.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OrdSetInts.help
-	@cp -f ${HELP}/OrdSetInts.help ${HELP}/OSI.help
-	@${TANGLE} -R"OrdSetInts.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OrdSetInts.input
-	@echo "OrdSetInts (OSI)" >>${HELPFILE}
-
-${HELP}/OutputForm.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create OutputForm.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"OutputForm.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/OutputForm.help
-	@cp -f ${HELP}/OutputForm.help ${HELP}/OUTFORM.help
-	@${TANGLE} -R"OutputForm.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/OutputForm.input
-	@echo "OutputForm (OUTFORM)" >>${HELPFILE}
-
-${HELP}/PackageForAlgebraicFunctionField.help: \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7875 make PackageForAlgebraicFunctionField.help \
-           from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"PackageForAlgebraicFunctionField.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/PackageForAlgebraicFunctionField.help
-	@cp -f ${HELP}/PackageForAlgebraicFunctionField.help \
-           ${HELP}/PAFF.help
-	@${TANGLE} -R"PackageForAlgebraicFunctionField.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${INPUT}/PackageForAlgebraicFunctionField.input
-	@echo "PackageForAlgebraicFunctionField (PAFF)" \
-           >>${HELPFILE}
-
-${HELP}/PackageForAlgebraicFunctionFieldOverFiniteField.help: \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7875 make PackageForAlgebraicFunctionFieldOverFiniteField.help \
-           from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"PackageForAlgebraicFunctionFieldOverFiniteField.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/PackageForAlgebraicFunctionFieldOverFiniteField.help
-	@cp -f ${HELP}/PackageForAlgebraicFunctionFieldOverFiniteField.help \
-           ${HELP}/PAFFFF.help
-	@${TANGLE} -R"PackageForAlgebraicFunctionFieldOverFiniteField.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${INPUT}/PackageForAlgebraicFunctionFieldOverFiniteField.input
-	@echo "PackageForAlgebraicFunctionFieldOverFiniteField (PAFFFF)" \
-           >>${HELPFILE}
-
-${HELP}/PackageForPoly.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7880 create PackageForPoly.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"PackageForPoly.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/PackageForPoly.help
-	@cp -f ${HELP}/PackageForPoly.help ${HELP}/PFORP.help
-	@${TANGLE} -R"PackageForPoly.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/PackageForPoly.input
-	@echo "PackageForPoly (PFORP)" >>${HELPFILE}
-
-${HELP}/PAdicInteger.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PAdicInteger.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PAdicInteger.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PAdicInteger.help
-	@cp -f ${HELP}/PAdicInteger.help ${HELP}/PADIC.help
-	@${TANGLE} -R"PAdicInteger.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PAdicInteger.input
-	@echo "PAdicInteger (PADIC)" >>${HELPFILE}
-
-${HELP}/PAdicIntegerCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PAdicIntegerCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PAdicIntegerCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PAdicIntegerCategory.help
-	@cp -f ${HELP}/PAdicIntegerCategory.help ${HELP}/PADICCT.help
-	@${TANGLE} -R"PAdicIntegerCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PAdicIntegerCategory.input
-	@echo "PAdicIntegerCategory (PADICCT)" >>${HELPFILE}
-
-${HELP}/PAdicRational.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PAdicRational.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PAdicRational.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PAdicRational.help
-	@cp -f ${HELP}/PAdicRational.help ${HELP}/PADICRAT.help
-	@${TANGLE} -R"PAdicRational.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PAdicRational.input
-	@echo "PAdicRational (PADICRAT)" >>${HELPFILE}
-
-${HELP}/PAdicRationalConstructor.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PAdicRationalConstructor.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PAdicRationalConstructor.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PAdicRationalConstructor.help
-	@cp -f ${HELP}/PAdicRationalConstructor.help ${HELP}/PADICRC.help
-	@${TANGLE} -R"PAdicRationalConstructor.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PAdicRationalConstructor.input
-	@echo "PAdicRationalConstructor (PADICRC)" >>${HELPFILE}
-
-${HELP}/Palette.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Palette.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Palette.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Palette.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Palette.help ${HELP}/PALETTE.help ; \
-	 fi
-	@${TANGLE} -R"Palette.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Palette.input
-	@echo "Palette (PALETTE)" >>${HELPFILE}
-
-${HELP}/ParametricPlaneCurve.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ParametricPlaneCurve.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ParametricPlaneCurve.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ParametricPlaneCurve.help
-	@cp -f ${HELP}/ParametricPlaneCurve.help ${HELP}/PARPCURV.help
-	@${TANGLE} -R"ParametricPlaneCurve.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ParametricPlaneCurve.input
-	@echo "ParametricPlaneCurve (PARPCURV)" >>${HELPFILE}
-
-${HELP}/ParametricSpaceCurve.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ParametricSpaceCurve.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ParametricSpaceCurve.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ParametricSpaceCurve.help
-	@cp -f ${HELP}/ParametricSpaceCurve.help ${HELP}/PARSCURV.help
-	@${TANGLE} -R"ParametricSpaceCurve.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ParametricSpaceCurve.input
-	@echo "ParametricSpaceCurve (PARSCURV)" >>${HELPFILE}
-
-${HELP}/ParametricSurface.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ParametricSurface.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ParametricSurface.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ParametricSurface.help
-	@cp -f ${HELP}/ParametricSurface.help ${HELP}/PARSURF.help
-	@${TANGLE} -R"ParametricSurface.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ParametricSurface.input
-	@echo "ParametricSurface (PARSURF)" >>${HELPFILE}
-
-${HELP}/ParametrizationPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7882 create ParametrizationPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"ParametrizationPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/ParametrizationPackage.help
-	@cp -f ${HELP}/ParametrizationPackage.help ${HELP}/PARAMP.help
-	@${TANGLE} -R"ParametrizationPackage.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${INPUT}/ParametrizationPackage.input
-	@echo "ParametrizationPackage (PARAMP)" >>${HELPFILE}
-
-${HELP}/PartialDifferentialEquationsSolverCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create \
-           PartialDifferentialEquationsSolverCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PartialDifferentialEquationsSolverCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PartialDifferentialEquationsSolverCategory.help
-	@cp -f ${HELP}/PartialDifferentialEquationsSolverCategory.help \
-           ${HELP}/PDECAT.help
-	@${TANGLE} -R"PartialDifferentialEquationsSolverCategory.input" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${INPUT}/PartialDifferentialEquationsSolverCategory.input
-	@echo "PartialDifferentialEquationsSolverCategory (PDECAT)" \
-           >>${HELPFILE}
-
-${HELP}/PartialDifferentialRing.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PartialDifferentialRing.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PartialDifferentialRing.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PartialDifferentialRing.help
-	@cp -f ${HELP}/PartialDifferentialRing.help ${HELP}/PDRING.help
-	@${TANGLE} -R"PartialDifferentialRing.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PartialDifferentialRing.input
-	@echo "PartialDifferentialRing (PDRING)" >>${HELPFILE}
-
-${HELP}/PartialFraction.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7884 create PartialFraction.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PartialFraction.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PartialFraction.help
-	@cp -f ${HELP}/PartialFraction.help ${HELP}/PFR.help
-	@${TANGLE} -R"PartialFraction.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PartialFraction.input
-	@echo "PartialFraction (PFR)" >>${HELPFILE}
-
-${HELP}/PartialFractionPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7885 create PartialFractionPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"PartialFractionPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/PartialFractionPackage.help
-	@cp -f ${HELP}/PartialFractionPackage.help ${HELP}/PFRPAC.help
-	@${TANGLE} -R"PartialFractionPackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/PartialFractionPackage.input
-	@echo "PartialFractionPackage (PFRPAC)" >>${HELPFILE}
-
-${HELP}/PartialTranscendentalFunctions.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PartialTranscendentalFunctions.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PartialTranscendentalFunctions.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PartialTranscendentalFunctions.help
-	@cp -f ${HELP}/PartialTranscendentalFunctions.help ${HELP}/PTRANFN.help
-	@${TANGLE} -R"PartialTranscendentalFunctions.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PartialTranscendentalFunctions.input
-	@echo "PartialTranscendentalFunctions (PTRANFN)" >>${HELPFILE}
-
-${HELP}/Partition.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Partition.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Partition.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Partition.help
-	@cp -f ${HELP}/Partition.help ${HELP}/PRTITION.help
-	@${TANGLE} -R"Partition.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Partition.input
-	@echo "Partition (PRTITION)" >>${HELPFILE}
-
-${HELP}/Pattern.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Pattern.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Pattern.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Pattern.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Pattern.help ${HELP}/PATTERN.help ; \
-	 fi
-	@${TANGLE} -R"Pattern.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Pattern.input
-	@echo "Pattern (PATTERN)" >>${HELPFILE}
-
-${HELP}/Patternable.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Patternable.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Patternable.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Patternable.help
-	@cp -f ${HELP}/Patternable.help ${HELP}/PATAB.help
-	@${TANGLE} -R"Patternable.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Patternable.input
-	@echo "Patternable (PATAB)" >>${HELPFILE}
-
-${HELP}/PatternMatchable.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PatternMatchable.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PatternMatchable.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PatternMatchable.help
-	@cp -f ${HELP}/PatternMatchable.help ${HELP}/PATMAB.help
-	@${TANGLE} -R"PatternMatchable.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PatternMatchable.input
-	@echo "PatternMatchable (PATMAB)" >>${HELPFILE}
-
-${HELP}/PatternMatchListResult.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PatternMatchListResult.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PatternMatchListResult.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PatternMatchListResult.help
-	@cp -f ${HELP}/PatternMatchListResult.help ${HELP}/PATLRES.help
-	@${TANGLE} -R"PatternMatchListResult.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PatternMatchListResult.input
-	@echo "PatternMatchListResult (PATLRES)" >>${HELPFILE}
-
-${HELP}/PatternMatchResult.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PatternMatchResult.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PatternMatchResult.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PatternMatchResult.help
-	@cp -f ${HELP}/PatternMatchResult.help ${HELP}/PATRES.help
-	@${TANGLE} -R"PatternMatchResult.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PatternMatchResult.input
-	@echo "PatternMatchResult (PATRES)" >>${HELPFILE}
-
-${HELP}/PendantTree.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PendantTree.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PendantTree.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PendantTree.help
-	@cp -f ${HELP}/PendantTree.help ${HELP}/PENDTREE.help
-	@${TANGLE} -R"PendantTree.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PendantTree.input
-	@echo "PendantTree (PENDTREE)" >>${HELPFILE}
-
-${HELP}/Permanent.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7890 create Permanent.help from ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"Permanent.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/Permanent.help
-	@cp -f ${HELP}/Permanent.help ${HELP}/PERMAN.help
-	@${TANGLE} -R"Permanent.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/Permanent.input
-	@echo "Permanent (PERMAN)" >>${HELPFILE}
-
-${HELP}/Permutation.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7900 create Permutation.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Permutation.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Permutation.help
-	@cp -f ${HELP}/Permutation.help ${HELP}/PERM.help
-	@${TANGLE} -R"Permutation.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Permutation.input
-	@echo "Permutation (PERM)" >>${HELPFILE}
-
-${HELP}/PermutationCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PermutationCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PermutationCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PermutationCategory.help
-	@cp -f ${HELP}/PermutationCategory.help ${HELP}/PERMCAT.help
-	@${TANGLE} -R"PermutationCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PermutationCategory.input
-	@echo "PermutationCategory (PERMCAT)" >>${HELPFILE}
-
-${HELP}/PermutationGroup.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PermutationGroup.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PermutationGroup.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PermutationGroup.help
-	@cp -f ${HELP}/PermutationGroup.help ${HELP}/PERMGRP.help
-	@${TANGLE} -R"PermutationGroup.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PermutationGroup.input
-	@echo "PermutationGroup (PERMGRP)" >>${HELPFILE}
-
-${HELP}/Pi.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Pi.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Pi.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Pi.help
-	@cp -f ${HELP}/Pi.help ${HELP}/HACKPI.help
-	@${TANGLE} -R"Pi.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Pi.input
-	@echo "Pi (HACKPI)" >>${HELPFILE}
-
-${HELP}/Places.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7905 create Places.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Places.help" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Places.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Places.help ${HELP}/PLACES.help ; \
-	 fi
-	@${TANGLE} -R"Places.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Places.input
-	@echo "Places (PLACES)" >>${HELPFILE}
-
-${HELP}/PlacesCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7907 create PlacesCategory.help from \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PlacesCategory.help" \
-          ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PlacesCategory.help
-	@cp -f ${HELP}/PlacesCategory.help ${HELP}/PLACESC.help
-	@${TANGLE} -R"PlacesCategory.input" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PlacesCategory.input
-	@echo "PlacesCategory (PLACESC)" >>${HELPFILE}
-
-${HELP}/PlacesOverPseudoAlgebraicClosureOfFiniteField.help: \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7908 create \
-            PlacesOverPseudoAlgebraicClosureOfFiniteField.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PlacesOverPseudoAlgebraicClosureOfFiniteField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PlacesOverPseudoAlgebraicClosureOfFiniteField.help
-	@cp -f ${HELP}/PlacesOverPseudoAlgebraicClosureOfFiniteField.help \
-          ${HELP}/PLACESPS.help
-	@${TANGLE} -R"PlacesOverPseudoAlgebraicClosureOfFiniteField.input" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-          >${INPUT}/PlacesOverPseudoAlgebraicClosureOfFiniteField.input
-	@echo "PlacesOverPseudoAlgebraicClosureOfFiniteField (PLACESPS)" \
-          >>${HELPFILE}
-
-${HELP}/PlaneAlgebraicCurvePlot.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7910 create PlaneAlgebraicCurvePlot.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PlaneAlgebraicCurvePlot.help" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PlaneAlgebraicCurvePlot.help
-	@cp -f ${HELP}/PlaneAlgebraicCurvePlot.help ${HELP}/ACPLOT.help
-	@${TANGLE} -R"PlaneAlgebraicCurvePlot.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PlaneAlgebraicCurvePlot.input
-	@echo "PlaneAlgebraicCurvePlot (ACPLOT)" >>${HELPFILE}
-
-${HELP}/Plcs.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7915 create Plcs.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Plcs.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Plcs.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Plcs.help ${HELP}/PLCS.help ; \
-	 fi
-	@${TANGLE} -R"Plcs.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Plcs.input
-	@echo "Plcs (PLCS)" >>${HELPFILE}
-
-${HELP}/Plot.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7920 create Plot.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Plot.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Plot.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Plot.help ${HELP}/PLOT.help ; \
-	 fi
-	@${TANGLE} -R"Plot.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Plot.input
-	@echo "Plot (PLOT)" >>${HELPFILE}
-
-${HELP}/Plot3D.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Plot3D.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Plot3D.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Plot3D.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Plot3D.help ${HELP}/PLOT3D.help ; \
-	 fi
-	@${TANGLE} -R"Plot3D.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Plot3D.input
-	@echo "Plot3D (PLOT3D)" >>${HELPFILE}
-
-${HELP}/PlottablePlaneCurveCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PlottablePlaneCurveCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PlottablePlaneCurveCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PlottablePlaneCurveCategory.help
-	@cp -f ${HELP}/PlottablePlaneCurveCategory.help ${HELP}/PPCURVE.help
-	@${TANGLE} -R"PlottablePlaneCurveCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PlottablePlaneCurveCategory.input
-	@echo "PlottablePlaneCurveCategory (PPCURVE)" >>${HELPFILE}
-
-${HELP}/PlottableSpaceCurveCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PlottableSpaceCurveCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PlottableSpaceCurveCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PlottableSpaceCurveCategory.help
-	@cp -f ${HELP}/PlottableSpaceCurveCategory.help ${HELP}/PSCURVE.help
-	@${TANGLE} -R"PlottableSpaceCurveCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PlottableSpaceCurveCategory.input
-	@echo "PlottableSpaceCurveCategory (PSCURVE)" >>${HELPFILE}
-
-${HELP}/PoincareBirkhoffWittLyndonBasis.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PoincareBirkhoffWittLyndonBasis.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PoincareBirkhoffWittLyndonBasis.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PoincareBirkhoffWittLyndonBasis.help
-	@cp -f ${HELP}/PoincareBirkhoffWittLyndonBasis.help ${HELP}/PBWLB.help
-	@${TANGLE} -R"PoincareBirkhoffWittLyndonBasis.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PoincareBirkhoffWittLyndonBasis.input
-	@echo "PoincareBirkhoffWittLyndonBasis (PBWLB)" >>${HELPFILE}
-
-${HELP}/Point.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Point.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Point.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Point.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Point.help ${HELP}/POINT.help ; \
-	 fi
-	@${TANGLE} -R"Point.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Point.input
-	@echo "Point (POINT)" >>${HELPFILE}
-
-${HELP}/PointCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PointCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PointCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PointCategory.help
-	@cp -f ${HELP}/PointCategory.help ${HELP}/PTCAT.help
-	@${TANGLE} -R"PointCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PointCategory.input
-	@echo "PointCategory (PTCAT)" >>${HELPFILE}
-
-${HELP}/Polynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7930 create Polynomial.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Polynomial.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Polynomial.help
-	@cp -f ${HELP}/Polynomial.help ${HELP}/POLY.help
-	@${TANGLE} -R"Polynomial.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Polynomial.input
-	@echo "Polynomial (POLY)" >>${HELPFILE}
-
-${HELP}/PolynomialCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PolynomialCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PolynomialCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PolynomialCategory.help
-	@cp -f ${HELP}/PolynomialCategory.help ${HELP}/POLYCAT.help
-	@${TANGLE} -R"PolynomialCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PolynomialCategory.input
-	@echo "PolynomialCategory (POLYCAT)" >>${HELPFILE}
-
-${HELP}/PolynomialIdeals.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PolynomialIdeals.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PolynomialIdeals.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PolynomialIdeals.help
-	@cp -f ${HELP}/PolynomialIdeals.help ${HELP}/IDEAL.help
-	@${TANGLE} -R"PolynomialIdeals.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PolynomialIdeals.input
-	@echo "PolynomialIdeals (IDEAL)" >>${HELPFILE}
-
-${HELP}/PolynomialFactorizationExplicit.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PolynomialFactorizationExplicit.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PolynomialFactorizationExplicit.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PolynomialFactorizationExplicit.help
-	@cp -f ${HELP}/PolynomialFactorizationExplicit.help ${HELP}/PFECAT.help
-	@${TANGLE} -R"PolynomialFactorizationExplicit.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PolynomialFactorizationExplicit.input
-	@echo "PolynomialFactorizationExplicit (PFECAT)" >>${HELPFILE}
-
-${HELP}/PolynomialPackageForCurve.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7933 create PolynomialPackageForCurve.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"PolynomialPackageForCurve.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/PolynomialPackageForCurve.help
-	@cp -f ${HELP}/PolynomialPackageForCurve.help ${HELP}/PLPKCRV.help
-	@${TANGLE} -R"PolynomialPackageForCurve.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${INPUT}/PolynomialPackageForCurve.input
-	@echo "PolynomialPackageForCurve (PLPKCRV)" >>${HELPFILE}
-
-${HELP}/PolynomialRing.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PolynomialRing.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PolynomialRing.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PolynomialRing.help
-	@cp -f ${HELP}/PolynomialRing.help ${HELP}/PR.help
-	@${TANGLE} -R"PolynomialRing.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PolynomialRing.input
-	@echo "PolynomialRing (PR)" >>${HELPFILE}
-
-${HELP}/PolynomialSetCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PolynomialSetCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PolynomialSetCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PolynomialSetCategory.help
-	@cp -f ${HELP}/PolynomialSetCategory.help ${HELP}/PSETCAT.help
-	@${TANGLE} -R"PolynomialSetCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PolynomialSetCategory.input
-	@echo "PolynomialSetCategory (PSETCAT)" >>${HELPFILE}
-
-${HELP}/PositiveInteger.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PositiveInteger.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PositiveInteger.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PositiveInteger.help
-	@cp -f ${HELP}/PositiveInteger.help ${HELP}/PI.help
-	@${TANGLE} -R"PositiveInteger.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PositiveInteger.input
-	@echo "PositiveInteger (PI)" >>${HELPFILE}
-
-${HELP}/PowerSeriesCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PowerSeriesCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PowerSeriesCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PowerSeriesCategory.help
-	@cp -f ${HELP}/PowerSeriesCategory.help ${HELP}/PSCAT.help
-	@${TANGLE} -R"PowerSeriesCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PowerSeriesCategory.input
-	@echo "PowerSeriesCategory (PSCAT)" >>${HELPFILE}
-
-${HELP}/PrimeField.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PrimeField.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PrimeField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PrimeField.help
-	@cp -f ${HELP}/PrimeField.help ${HELP}/PF.help
-	@${TANGLE} -R"PrimeField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PrimeField.input
-	@echo "PrimeField (PF)" >>${HELPFILE}
-
-${HELP}/PrimitiveArray.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create PrimitiveArray.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PrimitiveArray.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PrimitiveArray.help
-	@cp -f ${HELP}/PrimitiveArray.help ${HELP}/PRIMARR.help
-	@${TANGLE} -R"PrimitiveArray.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PrimitiveArray.input
-	@echo "PrimitiveArray (PRIMARR)" >>${HELPFILE}
-
-${HELP}/PrimitiveFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PrimitiveFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PrimitiveFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PrimitiveFunctionCategory.help
-	@cp -f ${HELP}/PrimitiveFunctionCategory.help ${HELP}/PRIMCAT.help
-	@${TANGLE} -R"PrimitiveFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PrimitiveFunctionCategory.input
-	@echo "PrimitiveFunctionCategory (PRIMCAT)" >>${HELPFILE}
-
-${HELP}/PrincipalIdealDomain.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PrincipalIdealDomain.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PrincipalIdealDomain.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PrincipalIdealDomain.help
-	@cp -f ${HELP}/PrincipalIdealDomain.help ${HELP}/PID.help
-	@${TANGLE} -R"PrincipalIdealDomain.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PrincipalIdealDomain.input
-	@echo "PrincipalIdealDomain (PID)" >>${HELPFILE}
-
-${HELP}/PriorityQueueAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create PriorityQueueAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PriorityQueueAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PriorityQueueAggregate.help
-	@cp -f ${HELP}/PriorityQueueAggregate.help ${HELP}/PRQAGG.help
-	@${TANGLE} -R"PriorityQueueAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PriorityQueueAggregate.input
-	@echo "PriorityQueueAggregate (PRQAGG)" >>${HELPFILE}
-
-${HELP}/Product.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7935 create Product.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Product.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Product.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Product.help ${HELP}/PRODUCT.help ; \
-	 fi
-	@${TANGLE} -R"Product.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Product.input
-	@echo "Product (PRODUCT)" >>${HELPFILE}
-
-${HELP}/ProjectiveAlgebraicSetPackage.help: \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7936 create \
-           ProjectiveAlgebraicSetPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} \
-           -R"ProjectiveAlgebraicSetPackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/ProjectiveAlgebraicSetPackage.help
-	@cp -f \
-          ${HELP}/ProjectiveAlgebraicSetPackage.help \
-          ${HELP}/PRJALGPK.help
-	@${TANGLE} \
-          -R"ProjectiveAlgebraicSetPackage.input" \
-          ${BOOKS}/bookvol10.4.pamphlet \
-         >${INPUT}/ProjectiveAlgebraicSetPackage.input
-	@echo \
-         "ProjectiveAlgebraicSetPackage (PRJALGPK)" \
-          >>${HELPFILE}
-
-${HELP}/ProjectivePlane.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7937 create ProjectivePlane.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ProjectivePlane.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ProjectivePlane.help
-	@cp -f ${HELP}/ProjectivePlane.help ${HELP}/PROJPL.help
-	@${TANGLE} -R"ProjectivePlane.input" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-          >${INPUT}/ProjectivePlane.input
-	@echo "ProjectivePlane (PROJPL)" >>${HELPFILE}
-
-${HELP}/ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7938 create \
-           ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} \
-           -R"ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.help
-	@cp \
-          ${HELP}/ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.help \
-          ${HELP}/PROJPLPS.help
-	@${TANGLE} \
-          -R"ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.input" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-         >${INPUT}/ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField.input
-	@echo \
-         "ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField (PROJPLPS)" \
-          >>${HELPFILE}
-
-${HELP}/ProjectiveSpace.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7939 create ProjectiveSpace.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ProjectiveSpace.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ProjectiveSpace.help
-	@cp -f ${HELP}/ProjectiveSpace.help ${HELP}/PROJSP.help
-	@${TANGLE} -R"ProjectiveSpace.input" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-          >${INPUT}/ProjectiveSpace.input
-	@echo "ProjectiveSpace (PROJSP)" >>${HELPFILE}
-
-${HELP}/ProjectiveSpaceCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7940 create ProjectiveSpaceCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ProjectiveSpaceCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ProjectiveSpaceCategory.help
-	@cp -f ${HELP}/ProjectiveSpaceCategory.help ${HELP}/PRSPCAT.help
-	@${TANGLE} -R"ProjectiveSpaceCategory.input" \
-          ${BOOKS}/bookvol10.2.pamphlet \
-          >${INPUT}/ProjectiveSpaceCategory.input
-	@echo "ProjectiveSpaceCategory (PRSPCAT)" >>${HELPFILE}
-
-${HELP}/PseudoAlgebraicClosureOfAlgExtOfRationalNumber.help: \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7941 create \
-            PseudoAlgebraicClosureOfAlgExtOfRationalNumber.help from \
-            ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} \
-           -R"PseudoAlgebraicClosureOfAlgExtOfRationalNumber.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PseudoAlgebraicClosureOfAlgExtOfRationalNumber.help
-	@cp \
-          ${HELP}/PseudoAlgebraicClosureOfAlgExtOfRationalNumber.help \
-           ${HELP}/PACEXT.help
-	@${TANGLE} \
-         -R"PseudoAlgebraicClosureOfAlgExtOfRationalNumber.input" \
-         ${BOOKS}/bookvol10.3.pamphlet \
-         >${INPUT}/PseudoAlgebraicClosureOfAlgExtOfRationalNumber.input
-	@echo \
-           "PseudoAlgebraicClosureOfAlgExtOfRationalNumber (PACEXT)" \
-           >>${HELPFILE}
-
-${HELP}/PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.help: \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7942 create \
-            PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.help from \
-            ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} \
-           -R"PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.help
-	@cp \
-          ${HELP}/PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.help \
-           ${HELP}/PACEXTC.help
-	@${TANGLE} \
-         -R"PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.input" \
-         ${BOOKS}/bookvol10.2.pamphlet \
-         >${INPUT}/PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory.input
-	@echo \
-           "PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory (PACEXTC)" \
-           >>${HELPFILE}
-
-${HELP}/PseudoAlgebraicClosureOfFiniteFieldCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7943 create PseudoAlgebraicClosureOfFiniteFieldCategory.help \
-           from ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PseudoAlgebraicClosureOfFiniteFieldCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PseudoAlgebraicClosureOfFiniteFieldCategory.help
-	@cp -f ${HELP}/PseudoAlgebraicClosureOfFiniteFieldCategory.help \
-           ${HELP}/PACFFC.help
-	@${TANGLE} -R"PseudoAlgebraicClosureOfFiniteFieldCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PseudoAlgebraicClosureOfFiniteFieldCategory.input
-	@echo "PseudoAlgebraicClosureOfFiniteFieldCategory (PACFFC)" \
-           >>${HELPFILE}
-
-${HELP}/PseudoAlgebraicClosureOfPerfectFieldCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7944 create PseudoAlgebraicClosureOfPerfectFieldCategory.help \
-           from ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PseudoAlgebraicClosureOfPerfectFieldCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PseudoAlgebraicClosureOfPerfectFieldCategory.help
-	@cp -f ${HELP}/PseudoAlgebraicClosureOfPerfectFieldCategory.help \
-           ${HELP}/PACPERC.help
-	@${TANGLE} -R"PseudoAlgebraicClosureOfPerfectFieldCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PseudoAlgebraicClosureOfPerfectFieldCategory.input
-	@echo "PseudoAlgebraicClosureOfPerfectFieldCategory (PACPERC)" \
-           >>${HELPFILE}
-
-${HELP}/PseudoAlgebraicClosureOfFiniteField.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7945 create PseudoAlgebraicClosureOfFiniteField.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PseudoAlgebraicClosureOfFiniteField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PseudoAlgebraicClosureOfFiniteField.help
-	@cp -f ${HELP}/PseudoAlgebraicClosureOfFiniteField.help \
-           ${HELP}/PACOFF.help
-	@${TANGLE} -R"PseudoAlgebraicClosureOfFiniteField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PseudoAlgebraicClosureOfFiniteField.input
-	@echo "PseudoAlgebraicClosureOfFiniteField (PACOFF)" \
-           >>${HELPFILE}
-
-${HELP}/PseudoAlgebraicClosureOfRationalNumber.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7946 create PseudoAlgebraicClosureOfRationalNumber.help \
-           from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"PseudoAlgebraicClosureOfRationalNumber.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/PseudoAlgebraicClosureOfRationalNumber.help
-	@cp -f ${HELP}/PseudoAlgebraicClosureOfRationalNumber.help \
-           ${HELP}/PACRAT.help
-	@${TANGLE} -R"PseudoAlgebraicClosureOfRationalNumber.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/PseudoAlgebraicClosureOfRationalNumber.input
-	@echo "PseudoAlgebraicClosureOfRationalNumber (PACRAT)" \
-           >>${HELPFILE}
-
-${HELP}/PseudoAlgebraicClosureOfRationalNumberCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 7947 create PseudoAlgebraicClosureOfRationalNumberCategory.help \
-           from ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"PseudoAlgebraicClosureOfRationalNumberCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/PseudoAlgebraicClosureOfRationalNumberCategory.help
-	@cp -f ${HELP}/PseudoAlgebraicClosureOfRationalNumberCategory.help \
-           ${HELP}/PACRATC.help
-	@${TANGLE} -R"PseudoAlgebraicClosureOfRationalNumberCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/PseudoAlgebraicClosureOfRationalNumberCategory.input
-	@echo "PseudoAlgebraicClosureOfRationalNumberCategory (PACRATC)" \
-           >>${HELPFILE}
-
-${HELP}/QuadraticForm.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create QuadraticForm.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"QuadraticForm.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/QuadraticForm.help
-	@cp -f ${HELP}/QuadraticForm.help ${HELP}/QFORM.help
-	@${TANGLE} -R"QuadraticForm.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/QuadraticForm.input
-	@echo "QuadraticForm (QFORM)" >>${HELPFILE}
-
-${HELP}/QuasiAlgebraicSet.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create QuasiAlgebraicSet.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"QuasiAlgebraicSet.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/QuasiAlgebraicSet.help
-	@cp -f ${HELP}/QuasiAlgebraicSet.help ${HELP}/QALGSET.help
-	@${TANGLE} -R"QuasiAlgebraicSet.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/QuasiAlgebraicSet.input
-	@echo "QuasiAlgebraicSet (QALGSET)" >>${HELPFILE}
-
-${HELP}/Quaternion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7948 create Quaternion.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Quaternion.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Quaternion.help
-	@cp -f ${HELP}/Quaternion.help ${HELP}/QUAT.help
-	@${TANGLE} -R"Quaternion.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Quaternion.input
-	@echo "Quaternion (QUAT)" >>${HELPFILE}
-
-${HELP}/QuaternionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create QuaternionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"QuaternionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/QuaternionCategory.help
-	@cp -f ${HELP}/QuaternionCategory.help ${HELP}/QUATCAT.help
-	@${TANGLE} -R"QuaternionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/QuaternionCategory.input
-	@echo "QuaternionCategory (QUATCAT)" >>${HELPFILE}
-
-${HELP}/QuaternionCategoryFunctions2.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7949 create QuaternionCategoryFunctions2.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"QuaternionCategoryFunctions2.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/QuaternionCategoryFunctions2.help
-	@cp -f ${HELP}/QuaternionCategoryFunctions2.help ${HELP}/QUATCT2.help
-	@${TANGLE} -R"QuaternionCategoryFunctions2.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/QuaternionCategoryFunctions2.input
-	@echo "QuaternionCategoryFunctions2 (QUATCT2)" >>${HELPFILE}
-
-${HELP}/QueryEquation.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create QueryEquation.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"QueryEquation.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/QueryEquation.help
-	@cp -f ${HELP}/QueryEquation.help ${HELP}/QEQUAT.help
-	@${TANGLE} -R"QueryEquation.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/QueryEquation.input
-	@echo "QueryEquation (QEQUAT)" >>${HELPFILE}
-
-${HELP}/Queue.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7950 create Queue.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Queue.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Queue.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Queue.help ${HELP}/QUEUE.help ; \
-	 fi
-	@${TANGLE} -R"Queue.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Queue.input
-	@echo "Queue (QUEUE)" >>${HELPFILE}
-
-${HELP}/QueueAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create QueueAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"QueueAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/QueueAggregate.help
-	@cp -f ${HELP}/QueueAggregate.help ${HELP}/QUAGG.help
-	@${TANGLE} -R"QueueAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/QueueAggregate.input
-	@echo "QueueAggregate (QUAGG)" >>${HELPFILE}
-
-${HELP}/QuotientFieldCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create QuotientFieldCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"QuotientFieldCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/QuotientFieldCategory.help
-	@cp -f ${HELP}/QuotientFieldCategory.help ${HELP}/QFCAT.help
-	@${TANGLE} -R"QuotientFieldCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/QuotientFieldCategory.input
-	@echo "QuotientFieldCategory (QFCAT)" >>${HELPFILE}
-
-${HELP}/RadicalCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RadicalCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RadicalCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RadicalCategory.help
-	@cp -f ${HELP}/RadicalCategory.help ${HELP}/RADCAT.help
-	@${TANGLE} -R"RadicalCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RadicalCategory.input
-	@echo "RadicalCategory (RADCAT)" >>${HELPFILE}
-
-${HELP}/RadicalFunctionField.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create RadicalFunctionField.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RadicalFunctionField.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RadicalFunctionField.help
-	@cp -f ${HELP}/RadicalFunctionField.help ${HELP}/RADFF.help
-	@${TANGLE} -R"RadicalFunctionField.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RadicalFunctionField.input
-	@echo "RadicalFunctionField (RADFF)" >>${HELPFILE}
-
-${HELP}/RadicalSolvePackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7955 create RadicalSolvePackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"RadicalSolvePackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/RadicalSolvePackage.help
-	@cp -f ${HELP}/RadicalSolvePackage.help ${HELP}/SOLVERAD.help
-	@${TANGLE} -R"RadicalSolvePackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/RadicalSolvePackage.input
-	@echo "RadicalSolvePackage (SOLVERAD)" >>${HELPFILE}
-
-${HELP}/RadixExpansion.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7960 create RadixExpansion.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RadixExpansion.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RadixExpansion.help
-	@cp -f ${HELP}/RadixExpansion.help ${HELP}/RADIX.help
-	@${TANGLE} -R"RadixExpansion.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RadixExpansion.input
-	@echo "RadixExpansion (RADIX)" >>${HELPFILE}
-
-${HELP}/RationalFunctionSum.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 7965 create RationalFunctionSum.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"RationalFunctionSum.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/RationalFunctionSum.help
-	@cp -f ${HELP}/RationalFunctionSum.help ${HELP}/SUMRF.help
-	@${TANGLE} -R"RationalFunctionSum.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/RationalFunctionSum.input
-	@echo "RationalFunctionSum (SUMRF)" >>${HELPFILE}
-
-${HELP}/RealClosedField.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RealClosedField.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RealClosedField.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RealClosedField.help
-	@cp -f ${HELP}/RealClosedField.help ${HELP}/RCFIELD.help
-	@${TANGLE} -R"RealClosedField.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RealClosedField.input
-	@echo "RealClosedField (RCFIELD)" >>${HELPFILE}
-
-${HELP}/RealClosure.help: ${BOOKS}/bookvol10.3.pamphlet 
-	@echo 7970 create RealClosure.help from ${BOOKS}/bookvol10.3.pamphlet 
-	@${TANGLE} -R"RealClosure.help" ${BOOKS}/bookvol10.3.pamphlet  \
-           >${HELP}/RealClosure.help
-	@cp -f ${HELP}/RealClosure.help ${HELP}/RECLOS.help
-	@${TANGLE} -R"RealClosure.input" ${BOOKS}/bookvol10.3.pamphlet  \
-            >${INPUT}/RealClosure.input
-	@echo "RealClosure (RECLOS)" >>${HELPFILE}
-
-${HELP}/RealConstant.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RealConstant.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RealConstant.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RealConstant.help
-	@cp -f ${HELP}/RealConstant.help ${HELP}/REAL.help
-	@${TANGLE} -R"RealConstant.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RealConstant.input
-	@echo "RealConstant (REAL)" >>${HELPFILE}
-
-${HELP}/RealNumberSystem.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RealNumberSystem.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RealNumberSystem.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RealNumberSystem.help
-	@cp -f ${HELP}/RealNumberSystem.help ${HELP}/RNS.help
-	@${TANGLE} -R"RealNumberSystem.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RealNumberSystem.input
-	@echo "RealNumberSystem (RNS)" >>${HELPFILE}
-
-${HELP}/RealRootCharacterizationCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RealRootCharacterizationCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RealRootCharacterizationCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RealRootCharacterizationCategory.help
-	@cp -f ${HELP}/RealRootCharacterizationCategory.help ${HELP}/RRCC.help
-	@${TANGLE} -R"RealRootCharacterizationCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RealRootCharacterizationCategory.input
-	@echo "RealRootCharacterizationCategory (RRCC)" >>${HELPFILE}
-
-${HELP}/RealSolvePackage.help: ${BOOKS}/bookvol10.4.pamphlet 
-	@echo 7980 create RealSolvePackage.help from \
-          ${BOOKS}/bookvol10.4.pamphlet 
-	@${TANGLE} -R"RealSolvePackage.help" ${BOOKS}/bookvol10.4.pamphlet  \
-           >${HELP}/RealSolvePackage.help
-	@cp -f ${HELP}/RealSolvePackage.help ${HELP}/REALSOLV.help
-	@${TANGLE} -R"RealSolvePackage.input" ${BOOKS}/bookvol10.4.pamphlet  \
-            >${INPUT}/RealSolvePackage.input
-	@echo "RealSolvePackage (REALSOLV)" >>${HELPFILE}
-
-${HELP}/RectangularMatrix.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create RectangularMatrix.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RectangularMatrix.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RectangularMatrix.help
-	@cp -f ${HELP}/RectangularMatrix.help ${HELP}/RMATRIX.help
-	@${TANGLE} -R"RectangularMatrix.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RectangularMatrix.input
-	@echo "RectangularMatrix (RMATRIX)" >>${HELPFILE}
-
-${HELP}/RectangularMatrixCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RectangularMatrixCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RectangularMatrixCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RectangularMatrixCategory.help
-	@cp -f ${HELP}/RectangularMatrixCategory.help ${HELP}/RMATCAT.help
-	@${TANGLE} -R"RectangularMatrixCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RectangularMatrixCategory.input
-	@echo "RectangularMatrixCategory (RMATCAT)" >>${HELPFILE}
-
-${HELP}/RecursivePolynomialCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RecursivePolynomialCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RecursivePolynomialCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RecursivePolynomialCategory.help
-	@cp -f ${HELP}/RecursivePolynomialCategory.help ${HELP}/RPOLCAT.help
-	@${TANGLE} -R"RecursivePolynomialCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RecursivePolynomialCategory.input
-	@echo "RecursivePolynomialCategory (RPOLCAT)" >>${HELPFILE}
-
-${HELP}/RecursiveAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RecursiveAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RecursiveAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RecursiveAggregate.help
-	@cp -f ${HELP}/RecursiveAggregate.help ${HELP}/RCAGG.help
-	@${TANGLE} -R"RecursiveAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RecursiveAggregate.input
-	@echo "RecursiveAggregate (RCAGG)" >>${HELPFILE}
-
-${HELP}/Reference.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Reference.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Reference.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Reference.help
-	@cp -f ${HELP}/Reference.help ${HELP}/REF.help
-	@${TANGLE} -R"Reference.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Reference.input
-	@echo "Reference (REF)" >>${HELPFILE}
-
-${HELP}/RegularChain.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create RegularChain.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RegularChain.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RegularChain.help
-	@cp -f ${HELP}/RegularChain.help ${HELP}/RGCHAIN.help
-	@${TANGLE} -R"RegularChain.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RegularChain.input
-	@echo "RegularChain (RGCHAIN)" >>${HELPFILE}
-
-${HELP}/RegularTriangularSet.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 7990 create RegularTriangularSet.help from \
-          ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RegularTriangularSet.help" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RegularTriangularSet.help
-	@cp -f ${HELP}/RegularTriangularSet.help ${HELP}/REGSET.help
-	@${TANGLE} -R"RegularTriangularSet.input" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RegularTriangularSet.input
-	@echo "RegularTriangularSet (REGSET)" >>${HELPFILE}
-
-${HELP}/RegularTriangularSetCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RegularTriangularSetCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RegularTriangularSetCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RegularTriangularSetCategory.help
-	@cp -f ${HELP}/RegularTriangularSetCategory.help ${HELP}/RSETCAT.help
-	@${TANGLE} -R"RegularTriangularSetCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RegularTriangularSetCategory.input
-	@echo "RegularTriangularSetCategory (RSETCAT)" >>${HELPFILE}
-
-${HELP}/ResidueRing.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ResidueRing.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ResidueRing.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ResidueRing.help
-	@cp -f ${HELP}/ResidueRing.help ${HELP}/RESRING.help
-	@${TANGLE} -R"ResidueRing.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ResidueRing.input
-	@echo "ResidueRing (RESRING)" >>${HELPFILE}
-
-${HELP}/Result.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Result.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Result.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Result.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Result.help ${HELP}/RESULT.help ; \
-	 fi
-	@${TANGLE} -R"Result.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Result.input
-	@echo "Result (RESULT)" >>${HELPFILE}
-
-${HELP}/RetractableTo.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RetractableTo.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RetractableTo.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RetractableTo.help
-	@cp -f ${HELP}/RetractableTo.help ${HELP}/RETRACT.help
-	@${TANGLE} -R"RetractableTo.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RetractableTo.input
-	@echo "RetractableTo (RETRACT)" >>${HELPFILE}
-
-${HELP}/RewriteRule.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create RewriteRule.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RewriteRule.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RewriteRule.help
-	@cp -f ${HELP}/RewriteRule.help ${HELP}/RULE.help
-	@${TANGLE} -R"RewriteRule.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RewriteRule.input
-	@echo "RewriteRule (RULE)" >>${HELPFILE}
-
-${HELP}/RightModule.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create RightModule.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"RightModule.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/RightModule.help
-	@cp -f ${HELP}/RightModule.help ${HELP}/RMODULE.help
-	@${TANGLE} -R"RightModule.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/RightModule.input
-	@echo "RightModule (RMODULE)" >>${HELPFILE}
-
-${HELP}/RightOpenIntervalRootCharacterization.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create RightOpenIntervalRootCharacterization.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RightOpenIntervalRootCharacterization.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RightOpenIntervalRootCharacterization.help
-	@cp -f ${HELP}/RightOpenIntervalRootCharacterization.help \
-           ${HELP}/ROIRC.help
-	@${TANGLE} -R"RightOpenIntervalRootCharacterization.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/RightOpenIntervalRootCharacterization.input
-	@echo "RightOpenIntervalRootCharacterization (ROIRC)" >>${HELPFILE}
-
-${HELP}/Ring.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Ring.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Ring.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Ring.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Ring.help ${HELP}/RING.help ; \
-	 fi
-	@${TANGLE} -R"Ring.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Ring.input
-	@echo "Ring (RING)" >>${HELPFILE}
-
-${HELP}/Rng.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create Rng.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"Rng.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/Rng.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Rng.help ${HELP}/RNG.help ; \
-	 fi
-	@${TANGLE} -R"Rng.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/Rng.input
-	@echo "Rng (RNG)" >>${HELPFILE}
-
-${HELP}/RomanNumeral.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8000 create RomanNumeral.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RomanNumeral.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RomanNumeral.help
-	@cp -f ${HELP}/RomanNumeral.help ${HELP}/ROMAN.help
-	@${TANGLE} -R"RomanNumeral.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RomanNumeral.input
-	@echo "RomanNumeral (ROMAN)" >>${HELPFILE}
-
-${HELP}/RootsFindingPackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 8005 create RootsFindingPackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"RootsFindingPackage.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/RootsFindingPackage.help
-	@cp -f ${HELP}/RootsFindingPackage.help ${HELP}/RFP.help
-	@${TANGLE} -R"RootsFindingPackage.input" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${INPUT}/RootsFindingPackage.input
-	@echo "RootsFindingPackage (RFP)" >>${HELPFILE}
-
-${HELP}/RoutinesTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create RoutinesTable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RoutinesTable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RoutinesTable.help
-	@cp -f ${HELP}/RoutinesTable.help ${HELP}/ROUTINE.help
-	@${TANGLE} -R"RoutinesTable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RoutinesTable.input
-	@echo "RoutinesTable (ROUTINE)" >>${HELPFILE}
-
-${HELP}/RuleCalled.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create RuleCalled.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"RuleCalled.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/RuleCalled.help
-	@cp -f ${HELP}/RuleCalled.help ${HELP}/RULECOLD.help
-	@${TANGLE} -R"RuleCalled.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/RuleCalled.input
-	@echo "RuleCalled (RULECOLD)" >>${HELPFILE}
-
-${HELP}/Ruleset.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Ruleset.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Ruleset.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Ruleset.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Ruleset.help ${HELP}/RULESET.help ; \
-	 fi
-	@${TANGLE} -R"Ruleset.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Ruleset.input
-	@echo "Ruleset (RULESET)" >>${HELPFILE}
-
-${HELP}/ScriptFormulaFormat.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ScriptFormulaFormat.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ScriptFormulaFormat.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ScriptFormulaFormat.help
-	@cp -f ${HELP}/ScriptFormulaFormat.help ${HELP}/FORMULA.help
-	@${TANGLE} -R"ScriptFormulaFormat.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ScriptFormulaFormat.input
-	@echo "ScriptFormulaFormat (FORMULA)" >>${HELPFILE}
-
-${HELP}/Segment.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8010 create Segment.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Segment.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Segment.help
-	@cp -f ${HELP}/Segment.help ${HELP}/SEG.help
-	@${TANGLE} -R"Segment.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Segment.input
-	@echo "Segment (SEG)" >>${HELPFILE}
-
-${HELP}/SegmentBinding.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8020 create SegmentBinding.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SegmentBinding.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SegmentBinding.help
-	@cp -f ${HELP}/SegmentBinding.help ${HELP}/SEGBIND.help
-	@${TANGLE} -R"SegmentBinding.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SegmentBinding.input
-	@echo "SegmentBinding (SEGBIND)" >>${HELPFILE}
-
-${HELP}/SegmentCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SegmentCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SegmentCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SegmentCategory.help
-	@cp -f ${HELP}/SegmentCategory.help ${HELP}/SEGCAT.help
-	@${TANGLE} -R"SegmentCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/SegmentCategory.input
-	@echo "SegmentCategory (SEGCAT)" >>${HELPFILE}
-
-${HELP}/SegmentExpansionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SegmentExpansionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SegmentExpansionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SegmentExpansionCategory.help
-	@cp -f ${HELP}/SegmentExpansionCategory.help ${HELP}/SEGXCAT.help
-	@${TANGLE} -R"SegmentExpansionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/SegmentExpansionCategory.input
-	@echo "SegmentExpansionCategory (SEGXCAT)" >>${HELPFILE}
-
-${HELP}/SemiGroup.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SemiGroup.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SemiGroup.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SemiGroup.help
-	@cp -f ${HELP}/SemiGroup.help ${HELP}/SGROUP.help
-	@${TANGLE} -R"SemiGroup.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/SemiGroup.input
-	@echo "SemiGroup (SGROUP)" >>${HELPFILE}
-
-${HELP}/Set.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8030 create Set.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Set.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Set.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Set.help ${HELP}/SET.help ; \
-	 fi
-	@${TANGLE} -R"Set.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Set.input
-	@echo "Set (SET)" >>${HELPFILE}
-
-${HELP}/SetAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SetAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SetAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SetAggregate.help
-	@cp -f ${HELP}/SetAggregate.help ${HELP}/SETAGG.help
-	@${TANGLE} -R"SetAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/SetAggregate.input
-	@echo "SetAggregate (SETAGG)" >>${HELPFILE}
-
-${HELP}/SetCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SetCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SetCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SetCategory.help
-	@cp -f ${HELP}/SetCategory.help ${HELP}/SETCAT.help
-	@${TANGLE} -R"SetCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/SetCategory.input
-	@echo "SetCategory (SETCAT)" >>${HELPFILE}
-
-${HELP}/SetCategoryWithDegree.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 8035 create SetCategoryWithDegree.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SetCategoryWithDegree.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SetCategoryWithDegree.help
-	@cp -f ${HELP}/SetCategoryWithDegree.help ${HELP}/SETCATD.help
-	@${TANGLE} -R"SetCategoryWithDegree.input" \
-          ${BOOKS}/bookvol10.2.pamphlet \
-          >${INPUT}/SetCategoryWithDegree.input
-	@echo "SetCategoryWithDegree (SETCATD)" >>${HELPFILE}
-
-${HELP}/SetOfMIntegersInOneToN.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SetOfMIntegersInOneToN.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SetOfMIntegersInOneToN.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SetOfMIntegersInOneToN.help
-	@cp -f ${HELP}/SetOfMIntegersInOneToN.help ${HELP}/SETMN.help
-	@${TANGLE} -R"SetOfMIntegersInOneToN.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SetOfMIntegersInOneToN.input
-	@echo "SetOfMIntegersInOneToN (SETMN)" >>${HELPFILE}
-
-${HELP}/SequentialDifferentialPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SequentialDifferentialPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SequentialDifferentialPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SequentialDifferentialPolynomial.help
-	@cp -f ${HELP}/SequentialDifferentialPolynomial.help ${HELP}/SDPOL.help
-	@${TANGLE} -R"SequentialDifferentialPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SequentialDifferentialPolynomial.input
-	@echo "SequentialDifferentialPolynomial (SDPOL)" >>${HELPFILE}
-
-${HELP}/SequentialDifferentialVariable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SequentialDifferentialVariable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SequentialDifferentialVariable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SequentialDifferentialVariable.help
-	@cp -f ${HELP}/SequentialDifferentialVariable.help ${HELP}/SDVAR.help
-	@${TANGLE} -R"SequentialDifferentialVariable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SequentialDifferentialVariable.input
-	@echo "SequentialDifferentialVariable (SDVAR)" >>${HELPFILE}
-
-${HELP}/SExpression.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SExpression.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SExpression.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SExpression.help
-	@cp -f ${HELP}/SExpression.help ${HELP}/SEX.help
-	@${TANGLE} -R"SExpression.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SExpression.input
-	@echo "SExpression (SEX)" >>${HELPFILE}
-
-${HELP}/SExpressionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SExpressionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SExpressionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SExpressionCategory.help
-	@cp -f ${HELP}/SExpressionCategory.help ${HELP}/SEXCAT.help
-	@${TANGLE} -R"SExpressionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/SExpressionCategory.input
-	@echo "SExpressionCategory (SEXCAT)" >>${HELPFILE}
-
-${HELP}/SExpressionOf.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SExpressionOf.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SExpressionOf.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SExpressionOf.help
-	@cp -f ${HELP}/SExpressionOf.help ${HELP}/SEXOF.help
-	@${TANGLE} -R"SExpressionOf.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SExpressionOf.input
-	@echo "SExpressionOf (SEXOF)" >>${HELPFILE}
-
-${HELP}/SimpleAlgebraicExtension.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SimpleAlgebraicExtension.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SimpleAlgebraicExtension.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SimpleAlgebraicExtension.help
-	@cp -f ${HELP}/SimpleAlgebraicExtension.help ${HELP}/SAE.help
-	@${TANGLE} -R"SimpleAlgebraicExtension.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SimpleAlgebraicExtension.input
-	@echo "SimpleAlgebraicExtension (SAE)" >>${HELPFILE}
-
-${HELP}/SimpleFortranProgram.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SimpleFortranProgram.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SimpleFortranProgram.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SimpleFortranProgram.help
-	@cp -f ${HELP}/SimpleFortranProgram.help ${HELP}/SFORT.help
-	@${TANGLE} -R"SimpleFortranProgram.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SimpleFortranProgram.input
-	@echo "SimpleFortranProgram (SFORT)" >>${HELPFILE}
-
-${HELP}/SingleInteger.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8040 create SingleInteger.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SingleInteger.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SingleInteger.help
-	@cp -f ${HELP}/SingleInteger.help ${HELP}/SINT.help
-	@${TANGLE} -R"SingleInteger.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SingleInteger.input
-	@echo "SingleInteger (SINT)" >>${HELPFILE}
-
-${HELP}/SingletonAsOrderedSet.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SingletonAsOrderedSet.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SingletonAsOrderedSet.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SingletonAsOrderedSet.help
-	@cp -f ${HELP}/SingletonAsOrderedSet.help ${HELP}/SAOS.help
-	@${TANGLE} -R"SingletonAsOrderedSet.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SingletonAsOrderedSet.input
-	@echo "SingletonAsOrderedSet (SAOS)" >>${HELPFILE}
-
-${HELP}/SparseTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8050 create SparseTable.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseTable.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseTable.help
-	@cp -f ${HELP}/SparseTable.help ${HELP}/STBL.help
-	@${TANGLE} -R"SparseTable.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SparseTable.input
-	@echo "SparseTable (STBL)" >>${HELPFILE}
-
-${HELP}/SparseMultivariatePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SparseMultivariatePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseMultivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseMultivariatePolynomial.help
-	@cp -f ${HELP}/SparseMultivariatePolynomial.help ${HELP}/SMP.help
-	@${TANGLE} -R"SparseMultivariatePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SparseMultivariatePolynomial.input
-	@echo "SparseMultivariatePolynomial (SMP)" >>${HELPFILE}
-
-${HELP}/SparseMultivariateTaylorSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8060 create SparseMultivariateTaylorSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseMultivariateTaylorSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseMultivariateTaylorSeries.help
-	@cp -f ${HELP}/SparseMultivariateTaylorSeries.help ${HELP}/SMTS.help
-	@${TANGLE} -R"SparseMultivariateTaylorSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SparseMultivariateTaylorSeries.input
-	@echo "SparseMultivariateTaylorSeries (SMTS)" >>${HELPFILE}
-
-${HELP}/SparseUnivariateLaurentSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SparseUnivariateLaurentSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseUnivariateLaurentSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseUnivariateLaurentSeries.help
-	@cp -f ${HELP}/SparseUnivariateLaurentSeries.help ${HELP}/SULS.help
-	@${TANGLE} -R"SparseUnivariateLaurentSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SparseUnivariateLaurentSeries.input
-	@echo "SparseUnivariateLaurentSeries (SULS)" >>${HELPFILE}
-
-${HELP}/SparseUnivariatePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SparseUnivariatePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseUnivariatePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseUnivariatePolynomial.help
-	@cp -f ${HELP}/SparseUnivariatePolynomial.help ${HELP}/SUP.help
-	@${TANGLE} -R"SparseUnivariatePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SparseUnivariatePolynomial.input
-	@echo "SparseUnivariatePolynomial (SUP)" >>${HELPFILE}
-
-${HELP}/SparseUnivariatePolynomialExpressions.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SparseUnivariatePolynomialExpressions.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseUnivariatePolynomialExpressions.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseUnivariatePolynomialExpressions.help
-	@cp -f ${HELP}/SparseUnivariatePolynomialExpressions.help \
-           ${HELP}/SUPEXPR.help
-	@${TANGLE} -R"SparseUnivariatePolynomialExpressions.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/SparseUnivariatePolynomialExpressions.input
-	@echo "SparseUnivariatePolynomialExpressions (SUPEXPR)" >>${HELPFILE}
-
-${HELP}/SparseUnivariatePuiseuxSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SparseUnivariatePuiseuxSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseUnivariatePuiseuxSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseUnivariatePuiseuxSeries.help
-	@cp -f ${HELP}/SparseUnivariatePuiseuxSeries.help ${HELP}/SUPXS.help
-	@${TANGLE} -R"SparseUnivariatePuiseuxSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SparseUnivariatePuiseuxSeries.input
-	@echo "SparseUnivariatePuiseuxSeries (SUPXS)" >>${HELPFILE}
-
-${HELP}/SparseUnivariateSkewPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SparseUnivariateSkewPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseUnivariateSkewPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseUnivariateSkewPolynomial.help
-	@cp -f ${HELP}/SparseUnivariateSkewPolynomial.help ${HELP}/ORESUP.help
-	@${TANGLE} -R"SparseUnivariateSkewPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SparseUnivariateSkewPolynomial.input
-	@echo "SparseUnivariateSkewPolynomial (ORESUP)" >>${HELPFILE}
-
-${HELP}/SparseUnivariateTaylorSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SparseUnivariateTaylorSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SparseUnivariateTaylorSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SparseUnivariateTaylorSeries.help
-	@cp -f ${HELP}/SparseUnivariateTaylorSeries.help ${HELP}/SUTS.help
-	@${TANGLE} -R"SparseUnivariateTaylorSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SparseUnivariateTaylorSeries.input
-	@echo "SparseUnivariateTaylorSeries (SUTS)" >>${HELPFILE}
-
-${HELP}/SpecialFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SpecialFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SpecialFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SpecialFunctionCategory.help
-	@cp -f ${HELP}/SpecialFunctionCategory.help ${HELP}/SPFCAT.help
-	@${TANGLE} -R"SpecialFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/SpecialFunctionCategory.input
-	@echo "SpecialFunctionCategory (SPFCAT)" >>${HELPFILE}
-
-${HELP}/SplitHomogeneousDirectProduct.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SplitHomogeneousDirectProduct.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SplitHomogeneousDirectProduct.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SplitHomogeneousDirectProduct.help
-	@cp -f ${HELP}/SplitHomogeneousDirectProduct.help ${HELP}/SHDP.help
-	@${TANGLE} -R"SplitHomogeneousDirectProduct.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SplitHomogeneousDirectProduct.input
-	@echo "SplitHomogeneousDirectProduct (SHDP)" >>${HELPFILE}
-
-${HELP}/SplittingNode.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SplittingNode.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SplittingNode.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SplittingNode.help
-	@cp -f ${HELP}/SplittingNode.help ${HELP}/SPLNODE.help
-	@${TANGLE} -R"SplittingNode.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SplittingNode.input
-	@echo "SplittingNode (SPLNODE)" >>${HELPFILE}
-
-${HELP}/SplittingTree.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SplittingTree.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SplittingTree.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SplittingTree.help
-	@cp -f ${HELP}/SplittingTree.help ${HELP}/SPLTREE.help
-	@${TANGLE} -R"SplittingTree.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SplittingTree.input
-	@echo "SplittingTree (SPLTREE)" >>${HELPFILE}
-
-${HELP}/SquareMatrix.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8070 create SquareMatrix.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SquareMatrix.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SquareMatrix.help
-	@cp -f ${HELP}/SquareMatrix.help ${HELP}/SQMATRIX.help
-	@${TANGLE} -R"SquareMatrix.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SquareMatrix.input
-	@echo "SquareMatrix (SQMATRIX)" >>${HELPFILE}
-
-${HELP}/SquareFreeNormalizedTriangularSetCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SquareFreeNormalizedTriangularSetCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SquareFreeNormalizedTriangularSetCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SquareFreeNormalizedTriangularSetCategory.help
-	@cp -f ${HELP}/SquareFreeNormalizedTriangularSetCategory.help \
-           ${HELP}/SNTSCAT.help
-	@${TANGLE} -R"SquareFreeNormalizedTriangularSetCategory.input" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${INPUT}/SquareFreeNormalizedTriangularSetCategory.input
-	@echo "SquareFreeNormalizedTriangularSetCategory (SNTSCAT)" \
-           >>${HELPFILE}
-
-${HELP}/SquareFreeRegularTriangularSet.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8080 create SquareFreeRegularTriangularSet.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SquareFreeRegularTriangularSet.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SquareFreeRegularTriangularSet.help
-	@cp -f ${HELP}/SquareFreeRegularTriangularSet.help ${HELP}/SREGSET.help
-	@${TANGLE} -R"SquareFreeRegularTriangularSet.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SquareFreeRegularTriangularSet.input
-	@echo "SquareFreeRegularTriangularSet (SREGSET)" >>${HELPFILE}
-
-${HELP}/SquareFreeRegularTriangularSetCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SquareFreeRegularTriangularSetCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SquareFreeRegularTriangularSetCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SquareFreeRegularTriangularSetCategory.help
-	@cp -f ${HELP}/SquareFreeRegularTriangularSetCategory.help \
-           ${HELP}/SFRTCAT.help
-	@${TANGLE} -R"SquareFreeRegularTriangularSetCategory.input" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${INPUT}/SquareFreeRegularTriangularSetCategory.input
-	@echo "SquareFreeRegularTriangularSetCategory (SFRTCAT)" >>${HELPFILE}
-
-${HELP}/SquareMatrixCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create SquareMatrixCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"SquareMatrixCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/SquareMatrixCategory.help
-	@cp -f ${HELP}/SquareMatrixCategory.help ${HELP}/SMATCAT.help
-	@${TANGLE} -R"SquareMatrixCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/SquareMatrixCategory.input
-	@echo "SquareMatrixCategory (SMATCAT)" >>${HELPFILE}
-
-${HELP}/Stack.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8090 create Stack.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Stack.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Stack.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Stack.help ${HELP}/STACK.help ; \
-	 fi
-	@${TANGLE} -R"Stack.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Stack.input
-	@echo "Stack (STACK)" >>${HELPFILE}
-
-${HELP}/StackAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create StackAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"StackAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/StackAggregate.help
-	@cp -f ${HELP}/StackAggregate.help ${HELP}/SKAGG.help
-	@${TANGLE} -R"StackAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/StackAggregate.input
-	@echo "StackAggregate (SKAGG)" >>${HELPFILE}
-
-${HELP}/StepThrough.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create StepThrough.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"StepThrough.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/StepThrough.help
-	@cp -f ${HELP}/StepThrough.help ${HELP}/STEP.help
-	@${TANGLE} -R"StepThrough.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/StepThrough.input
-	@echo "StepThrough (STEP)" >>${HELPFILE}
-
-${HELP}/Stream.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8100 create Stream.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Stream.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Stream.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Stream.help ${HELP}/STREAM.help ; \
-	 fi
-	@${TANGLE} -R"Stream.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Stream.input
-	@echo "Stream (STREAM)" >>${HELPFILE}
-
-${HELP}/StreamAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create StreamAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"StreamAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/StreamAggregate.help
-	@cp -f ${HELP}/StreamAggregate.help ${HELP}/STAGG.help
-	@${TANGLE} -R"StreamAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/StreamAggregate.input
-	@echo "StreamAggregate (STAGG)" >>${HELPFILE}
-
-${HELP}/StreamTensor.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 5000 create StreamTensor.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"StreamTensor.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/StreamTensor.help
-	@cp -f ${HELP}/StreamTensor.help ${HELP}/STNSR.help
-	@${TANGLE} -R"StreamTensor.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/StreamTensor.input
-	@echo "StreamTensor (STNSR)" >>${HELPFILE}
-
-${HELP}/String.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8110 create String.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"String.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/String.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/String.help ${HELP}/STRING.help ; \
-	 fi
-	@${TANGLE} -R"String.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/String.input
-	@echo "String (STRING)" >>${HELPFILE}
-
-${HELP}/StringAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create StringAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"StringAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/StringAggregate.help
-	@cp -f ${HELP}/StringAggregate.help ${HELP}/SRAGG.help
-	@${TANGLE} -R"StringAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/StringAggregate.input
-	@echo "StringAggregate (SRAGG)" >>${HELPFILE}
-
-${HELP}/StringCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create StringCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"StringCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/StringCategory.help
-	@cp -f ${HELP}/StringCategory.help ${HELP}/STRICAT.help
-	@${TANGLE} -R"StringCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/StringCategory.input
-	@echo "StringCategory (STRICAT)" >>${HELPFILE}
-
-${HELP}/StringTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8120 create StringTable.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"StringTable.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/StringTable.help
-	@cp -f ${HELP}/StringTable.help ${HELP}/STRTBL.help
-	@${TANGLE} -R"StringTable.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/StringTable.input
-	@echo "StringTable (STRTBL)" >>${HELPFILE}
-
-${HELP}/SubSpace.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SubSpace.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SubSpace.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SubSpace.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/SubSpace.help ${HELP}/SUBSPACE.help ; \
-	 fi
-	@${TANGLE} -R"SubSpace.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SubSpace.input
-	@echo "SubSpace (SUBSPACE)" >>${HELPFILE}
-
-${HELP}/SubSpaceComponentProperty.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SubSpaceComponentProperty.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SubSpaceComponentProperty.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SubSpaceComponentProperty.help
-	@cp -f ${HELP}/SubSpaceComponentProperty.help ${HELP}/COMPPROP.help
-	@${TANGLE} -R"SubSpaceComponentProperty.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SubSpaceComponentProperty.input
-	@echo "SubSpaceComponentProperty (COMPPROP)" >>${HELPFILE}
-
-${HELP}/SuchThat.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SuchThat.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SuchThat.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SuchThat.help
-	@cp -f ${HELP}/SuchThat.help ${HELP}/SUCH.help
-	@${TANGLE} -R"SuchThat.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SuchThat.input
-	@echo "SuchThat (SUCH)" >>${HELPFILE}
-
-${HELP}/Switch.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Switch.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Switch.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Switch.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Switch.help ${HELP}/SWITCH.help ; \
-	 fi
-	@${TANGLE} -R"Switch.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Switch.input
-	@echo "Switch (SWITCH)" >>${HELPFILE}
-
-${HELP}/Symbol.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8130 create Symbol.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Symbol.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Symbol.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Symbol.help ${HELP}/SYMBOL.help ; \
-	 fi
-	@${TANGLE} -R"Symbol.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Symbol.input
-	@echo "Symbol (SYMBOL)" >>${HELPFILE}
-
-${HELP}/SymbolTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SymbolTable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SymbolTable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SymbolTable.help
-	@cp -f ${HELP}/SymbolTable.help ${HELP}/SYMTAB.help
-	@${TANGLE} -R"SymbolTable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SymbolTable.input
-	@echo "SymbolTable (SYMTAB)" >>${HELPFILE}
-
-${HELP}/SymmetricPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create SymmetricPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"SymmetricPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/SymmetricPolynomial.help
-	@cp -f ${HELP}/SymmetricPolynomial.help ${HELP}/SYMPOLY.help
-	@${TANGLE} -R"SymmetricPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/SymmetricPolynomial.input
-	@echo "SymmetricPolynomial (SYMPOLY)" >>${HELPFILE}
-
-${HELP}/Table.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8140 create Table.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Table.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Table.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Table.help ${HELP}/TABLE.help ; \
-	 fi
-	@${TANGLE} -R"Table.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Table.input
-	@echo "Table (TABLE)" >>${HELPFILE}
-
-${HELP}/TableAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create TableAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"TableAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/TableAggregate.help
-	@cp -f ${HELP}/TableAggregate.help ${HELP}/TBAGG.help
-	@${TANGLE} -R"TableAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/TableAggregate.input
-	@echo "TableAggregate (TBAGG)" >>${HELPFILE}
-
-${HELP}/Tableau.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Tableau.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Tableau.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Tableau.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Tableau.help ${HELP}/TABLEAU.help ; \
-	 fi
-	@${TANGLE} -R"Tableau.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Tableau.input
-	@echo "Tableau (TABLEAU)" >>${HELPFILE}
-
-${HELP}/TaylorSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create TaylorSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"TaylorSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/TaylorSeries.help
-	@cp -f ${HELP}/TaylorSeries.help ${HELP}/TS.help
-	@${TANGLE} -R"TaylorSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/TaylorSeries.input
-	@echo "TaylorSeries (TS)" >>${HELPFILE}
-
-${HELP}/TexFormat.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8145 create TexFormat.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"TexFormat.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/TexFormat.help
-	@cp -f ${HELP}/TexFormat.help ${HELP}/TEX.help
-	@${TANGLE} -R"TexFormat.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/TexFormat.input
-	@echo "TexFormat (TEX)" >>${HELPFILE}
-
-${HELP}/TextFile.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8150 create TextFile.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"TextFile.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/TextFile.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/TextFile.help ${HELP}/TEXTFILE.help ; \
-	 fi
-	@${TANGLE} -R"TextFile.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/TextFile.input
-	@echo "TextFile (TEXTFILE)" >>${HELPFILE}
-
-${HELP}/TheSymbolTable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create TheSymbolTable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"TheSymbolTable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/TheSymbolTable.help
-	@cp -f ${HELP}/TheSymbolTable.help ${HELP}/SYMS.help
-	@${TANGLE} -R"TheSymbolTable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/TheSymbolTable.input
-	@echo "TheSymbolTable (SYMS)" >>${HELPFILE}
-
-${HELP}/ThreeDimensionalMatrix.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ThreeDimensionalMatrix.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ThreeDimensionalMatrix.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ThreeDimensionalMatrix.help
-	@cp -f ${HELP}/ThreeDimensionalMatrix.help ${HELP}/M3D.help
-	@${TANGLE} -R"ThreeDimensionalMatrix.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ThreeDimensionalMatrix.input
-	@echo "ThreeDimensionalMatrix (M3D)" >>${HELPFILE}
-
-${HELP}/ThreeDimensionalViewport.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ThreeDimensionalViewport.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ThreeDimensionalViewport.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ThreeDimensionalViewport.help
-	@cp -f ${HELP}/ThreeDimensionalViewport.help ${HELP}/VIEW3D.help
-	@${TANGLE} -R"ThreeDimensionalViewport.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ThreeDimensionalViewport.input
-	@echo "ThreeDimensionalViewport (VIEW3D)" >>${HELPFILE}
-
-${HELP}/ThreeSpace.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create ThreeSpace.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"ThreeSpace.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/ThreeSpace.help
-	@cp -f ${HELP}/ThreeSpace.help ${HELP}/SPACE3.help
-	@${TANGLE} -R"ThreeSpace.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/ThreeSpace.input
-	@echo "ThreeSpace (SPACE3)" >>${HELPFILE}
-
-${HELP}/ThreeSpaceCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create ThreeSpaceCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"ThreeSpaceCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/ThreeSpaceCategory.help
-	@cp -f ${HELP}/ThreeSpaceCategory.help ${HELP}/SPACEC.help
-	@${TANGLE} -R"ThreeSpaceCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/ThreeSpaceCategory.input
-	@echo "ThreeSpaceCategory (SPACEC)" >>${HELPFILE}
-
-${HELP}/TranscendentalFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create TranscendentalFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"TranscendentalFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/TranscendentalFunctionCategory.help
-	@cp -f ${HELP}/TranscendentalFunctionCategory.help ${HELP}/TRANFUN.help
-	@${TANGLE} -R"TranscendentalFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/TranscendentalFunctionCategory.input
-	@echo "TranscendentalFunctionCategory (TRANFUN)" >>${HELPFILE}
-
-${HELP}/TransSolvePackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 8155 create TransSolvePackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"TransSolvePackage.help" ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/TransSolvePackage.help
-	@cp -f ${HELP}/TransSolvePackage.help ${HELP}/SOLVETRA.help
-	@${TANGLE} -R"TransSolvePackage.input" ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/TransSolvePackage.input
-	@echo "TransSolvePackage (SOLVETRA)" >>${HELPFILE}
-
-${HELP}/Tree.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Tree.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Tree.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Tree.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Tree.help ${HELP}/TREE.help ; \
-	 fi
-	@${TANGLE} -R"Tree.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Tree.input
-	@echo "Tree (TREE)" >>${HELPFILE}
-
-${HELP}/TriangularSetCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create TriangularSetCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"TriangularSetCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/TriangularSetCategory.help
-	@cp -f ${HELP}/TriangularSetCategory.help ${HELP}/TSETCAT.help
-	@${TANGLE} -R"TriangularSetCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/TriangularSetCategory.input
-	@echo "TriangularSetCategory (TSETCAT)" >>${HELPFILE}
-
-${HELP}/TrigonometricFunctionCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create TrigonometricFunctionCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"TrigonometricFunctionCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/TrigonometricFunctionCategory.help
-	@cp -f ${HELP}/TrigonometricFunctionCategory.help ${HELP}/TRIGCAT.help
-	@${TANGLE} -R"TrigonometricFunctionCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/TrigonometricFunctionCategory.input
-	@echo "TrigonometricFunctionCategory (TRIGCAT)" >>${HELPFILE}
-
-${HELP}/TubePlot.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create TubePlot.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"TubePlot.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/TubePlot.help
-	@cp -f ${HELP}/TubePlot.help ${HELP}/TUBE.help
-	@${TANGLE} -R"TubePlot.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/TubePlot.input
-	@echo "TubePlot (TUBE)" >>${HELPFILE}
-
-${HELP}/Tuple.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Tuple.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Tuple.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Tuple.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Tuple.help ${HELP}/TUPLE.help ; \
-	 fi
-	@${TANGLE} -R"Tuple.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Tuple.input
-	@echo "Tuple (TUPLE)" >>${HELPFILE}
-
-${HELP}/TwoDimensionalArray.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8160 create TwoDimensionalArray.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"TwoDimensionalArray.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/TwoDimensionalArray.help
-	@cp -f ${HELP}/TwoDimensionalArray.help ${HELP}/ARRAY2.help
-	@${TANGLE} -R"TwoDimensionalArray.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/TwoDimensionalArray.input
-	@echo "TwoDimensionalArray (ARRAY2)" >>${HELPFILE}
-
-${HELP}/TwoDimensionalArrayCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create TwoDimensionalArrayCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"TwoDimensionalArrayCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/TwoDimensionalArrayCategory.help
-	@cp -f ${HELP}/TwoDimensionalArrayCategory.help ${HELP}/ARR2CAT.help
-	@${TANGLE} -R"TwoDimensionalArrayCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/TwoDimensionalArrayCategory.input
-	@echo "TwoDimensionalArrayCategory (ARR2CAT)" >>${HELPFILE}
-
-${HELP}/TwoDimensionalViewport.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8170 create TwoDimensionalViewport.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"TwoDimensionalViewport.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/TwoDimensionalViewport.help 
-	@cp -f ${HELP}/TwoDimensionalViewport.help ${HELP}/VIEW2D.help
-# Note:no input regression file due to graphics
-	@echo "TwoDimensionalViewport (VIEW2D)" >>${HELPFILE}
-
-${HELP}/UnaryRecursiveAggregate.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnaryRecursiveAggregate.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnaryRecursiveAggregate.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnaryRecursiveAggregate.help
-	@cp -f ${HELP}/UnaryRecursiveAggregate.help ${HELP}/URAGG.help
-	@${TANGLE} -R"UnaryRecursiveAggregate.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/UnaryRecursiveAggregate.input
-	@echo "UnaryRecursiveAggregate (URAGG)" >>${HELPFILE}
-
-${HELP}/UniqueFactorizationDomain.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UniqueFactorizationDomain.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UniqueFactorizationDomain.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UniqueFactorizationDomain.help
-	@cp -f ${HELP}/UniqueFactorizationDomain.help ${HELP}/UFD.help
-	@${TANGLE} -R"UniqueFactorizationDomain.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/UniqueFactorizationDomain.input
-	@echo "UniqueFactorizationDomain (UFD)" >>${HELPFILE}
-
-${HELP}/UnivariateFormalPowerSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create UnivariateFormalPowerSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariateFormalPowerSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariateFormalPowerSeries.help
-	@cp -f ${HELP}/UnivariateFormalPowerSeries.help ${HELP}/UFPS.help
-	@${TANGLE} -R"UnivariateFormalPowerSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariateFormalPowerSeries.input
-	@echo "UnivariateFormalPowerSeries (UFPS)" >>${HELPFILE}
-
-${HELP}/UnivariateLaurentSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create UnivariateLaurentSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariateLaurentSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariateLaurentSeries.help
-	@cp -f ${HELP}/UnivariateLaurentSeries.help ${HELP}/ULS.help
-	@${TANGLE} -R"UnivariateLaurentSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariateLaurentSeries.input
-	@echo "UnivariateLaurentSeries (ULS)" >>${HELPFILE}
-
-${HELP}/UnivariatePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8180 create UnivariatePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariatePolynomial.help" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariatePolynomial.help
-	@cp -f ${HELP}/UnivariatePolynomial.help ${HELP}/UP.help
-	@${TANGLE} -R"UnivariatePolynomial.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariatePolynomial.input
-	@echo "UnivariatePolynomial (UP)" >>${HELPFILE}
-
-${HELP}/UnivariateLaurentSeriesCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnivariateLaurentSeriesCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnivariateLaurentSeriesCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnivariateLaurentSeriesCategory.help
-	@cp -f ${HELP}/UnivariateLaurentSeriesCategory.help ${HELP}/ULSCAT.help
-	@${TANGLE} -R"UnivariateLaurentSeriesCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/UnivariateLaurentSeriesCategory.input
-	@echo "UnivariateLaurentSeriesCategory (ULSCAT)" >>${HELPFILE}
-
-${HELP}/UnivariateLaurentSeriesConstructor.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create UnivariateLaurentSeriesConstructor.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariateLaurentSeriesConstructor.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariateLaurentSeriesConstructor.help
-	@cp -f ${HELP}/UnivariateLaurentSeriesConstructor.help \
-           ${HELP}/ULSCONS.help
-	@${TANGLE} -R"UnivariateLaurentSeriesConstructor.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariateLaurentSeriesConstructor.input
-	@echo "UnivariateLaurentSeriesConstructor (ULSCONS)" >>${HELPFILE}
-
-${HELP}/UnivariateLaurentSeriesConstructorCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnivariateLaurentSeriesConstructorCategory.help \
-           from ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnivariateLaurentSeriesConstructorCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnivariateLaurentSeriesConstructorCategory.help
-	@cp -f ${HELP}/UnivariateLaurentSeriesConstructorCategory.help \
-          ${HELP}/ULSCCAT.help
-	@${TANGLE} -R"UnivariateLaurentSeriesConstructorCategory.input" \
-          ${BOOKS}/bookvol10.2.pamphlet \
-          >${INPUT}/UnivariateLaurentSeriesConstructorCategory.input
-	@echo "UnivariateLaurentSeriesConstructorCategory (ULSCCAT)" \
-          >>${HELPFILE}
-
-${HELP}/UnivariatePolynomialCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnivariatePolynomialCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnivariatePolynomialCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnivariatePolynomialCategory.help
-	@cp -f ${HELP}/UnivariatePolynomialCategory.help ${HELP}/UPOLYC.help
-	@${TANGLE} -R"UnivariatePolynomialCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/UnivariatePolynomialCategory.input
-	@echo "UnivariatePolynomialCategory (UPOLYC)" >>${HELPFILE}
-
-${HELP}/UnivariatePowerSeriesCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnivariatePowerSeriesCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnivariatePowerSeriesCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnivariatePowerSeriesCategory.help
-	@cp -f ${HELP}/UnivariatePowerSeriesCategory.help ${HELP}/UPSCAT.help
-	@${TANGLE} -R"UnivariatePowerSeriesCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/UnivariatePowerSeriesCategory.input
-	@echo "UnivariatePowerSeriesCategory (UPSCAT)" >>${HELPFILE}
-
-${HELP}/UnivariatePuiseuxSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create UnivariatePuiseuxSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariatePuiseuxSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariatePuiseuxSeries.help
-	@cp -f ${HELP}/UnivariatePuiseuxSeries.help ${HELP}/UPXS.help
-	@${TANGLE} -R"UnivariatePuiseuxSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariatePuiseuxSeries.input
-	@echo "UnivariatePuiseuxSeries (UPXS)" >>${HELPFILE}
-
-${HELP}/UnivariatePuiseuxSeriesCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnivariatePuiseuxSeriesCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnivariatePuiseuxSeriesCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnivariatePuiseuxSeriesCategory.help
-	@cp -f ${HELP}/UnivariatePuiseuxSeriesCategory.help \
-            ${HELP}/UPXSCAT.help
-	@${TANGLE} -R"UnivariatePuiseuxSeriesCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/UnivariatePuiseuxSeriesCategory.input
-	@echo "UnivariatePuiseuxSeriesCategory (UPXSCAT)" >>${HELPFILE}
-
-${HELP}/UnivariatePuiseuxSeriesConstructor.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create UnivariatePuiseuxSeriesConstructor.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariatePuiseuxSeriesConstructor.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariatePuiseuxSeriesConstructor.help
-	@cp -f ${HELP}/UnivariatePuiseuxSeriesConstructor.help \
-           ${HELP}/UPXSCONS.help
-	@${TANGLE} -R"UnivariatePuiseuxSeriesConstructor.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariatePuiseuxSeriesConstructor.input
-	@echo "UnivariatePuiseuxSeriesConstructor (UPXSCONS)" >>${HELPFILE}
-
-${HELP}/UnivariatePuiseuxSeriesConstructorCategory.help: \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnivariatePuiseuxSeriesConstructorCategory.help \
-           from ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnivariatePuiseuxSeriesConstructorCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnivariatePuiseuxSeriesConstructorCategory.help
-	@cp -f ${HELP}/UnivariatePuiseuxSeriesConstructorCategory.help \
-           ${HELP}/UPXSCCA.help
-	@${TANGLE} -R"UnivariatePuiseuxSeriesConstructorCategory.input" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${INPUT}/UnivariatePuiseuxSeriesConstructorCategory.input
-	@echo "UnivariatePuiseuxSeriesConstructorCategory (UPXSCCA)" \
-           >>${HELPFILE}
-
-${HELP}/UnivariatePuiseuxSeriesWithExponentialSingularity.help: \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create \
-           UnivariatePuiseuxSeriesWithExponentialSingularity.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariatePuiseuxSeriesWithExponentialSingularity.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariatePuiseuxSeriesWithExponentialSingularity.help
-	@cp -f ${HELP}/UnivariatePuiseuxSeriesWithExponentialSingularity.help \
-           ${HELP}/UPXSSING.help
-	@${TANGLE} \
-           -R"UnivariatePuiseuxSeriesWithExponentialSingularity.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${INPUT}/UnivariatePuiseuxSeriesWithExponentialSingularity.input
-	@echo "UnivariatePuiseuxSeriesWithExponentialSingularity (UPXSSING)" \
-           >>${HELPFILE}
-
-${HELP}/UnivariateSkewPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8190 create UnivariateSkewPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariateSkewPolynomial.help" \
-          ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariateSkewPolynomial.help
-	@cp -f ${HELP}/UnivariateSkewPolynomial.help ${HELP}/OREUP.help
-	@${TANGLE} -R"UnivariateSkewPolynomial.input" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariateSkewPolynomial.input
-	@echo "UnivariateSkewPolynomial (OREUP)" >>${HELPFILE}
-
-${HELP}/UnivariateSkewPolynomialCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnivariateSkewPolynomialCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnivariateSkewPolynomialCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnivariateSkewPolynomialCategory.help
-	@cp -f ${HELP}/UnivariateSkewPolynomialCategory.help \
-            ${HELP}/OREPCAT.help
-	@${TANGLE} -R"UnivariateSkewPolynomialCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/UnivariateSkewPolynomialCategory.input
-	@echo "UnivariateSkewPolynomialCategory (OREPCAT)" >>${HELPFILE}
-
-${HELP}/UnivariateTaylorSeries.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create UnivariateTaylorSeries.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariateTaylorSeries.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariateTaylorSeries.help
-	@cp -f ${HELP}/UnivariateTaylorSeries.help ${HELP}/UTS.help
-	@${TANGLE} -R"UnivariateTaylorSeries.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariateTaylorSeries.input
-	@echo "UnivariateTaylorSeries (UTS)" >>${HELPFILE}
-
-${HELP}/UnivariateTaylorSeriesCZero.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8195 create UnivariateTaylorSeriesCZero.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UnivariateTaylorSeriesCZero.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UnivariateTaylorSeriesCZero.help
-	@cp -f ${HELP}/UnivariateTaylorSeriesCZero.help ${HELP}/UTSZ.help
-	@${TANGLE} -R"UnivariateTaylorSeriesCZero.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UnivariateTaylorSeriesCZero.input
-	@echo "UnivariateTaylorSeriesCZero (UTSZ)" >>${HELPFILE}
-
-${HELP}/UnivariateTaylorSeriesCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create UnivariateTaylorSeriesCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"UnivariateTaylorSeriesCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/UnivariateTaylorSeriesCategory.help
-	@cp -f ${HELP}/UnivariateTaylorSeriesCategory.help ${HELP}/UTSCAT.help
-	@${TANGLE} -R"UnivariateTaylorSeriesCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/UnivariateTaylorSeriesCategory.input
-	@echo "UnivariateTaylorSeriesCategory (UTSCAT)" >>${HELPFILE}
-
-${HELP}/UniversalSegment.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8200 create UniversalSegment.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"UniversalSegment.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/UniversalSegment.help
-	@cp -f ${HELP}/UniversalSegment.help ${HELP}/UNISEG.help
-	@${TANGLE} -R"UniversalSegment.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/UniversalSegment.input
-	@echo "UniversalSegment (UNISEG)" >>${HELPFILE}
-
-${HELP}/U32Vector.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8200 create U32Vector.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"U32Vector.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/U32Vector.help
-	@cp -f ${HELP}/U32Vector.help ${HELP}/U32VEC.help
-	@${TANGLE} -R"U32Vector.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/U32Vector.input
-	@echo "U32Vector (U32VEC)" >>${HELPFILE}
-
-${HELP}/Variable.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create Variable.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Variable.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Variable.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Variable.help ${HELP}/VARIABLE.help ; \
-	 fi
-	@${TANGLE} -R"Variable.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Variable.input
-	@echo "Variable (VARIABLE)" >>${HELPFILE}
-
-${HELP}/Vector.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8210 create Vector.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Vector.help" ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/Vector.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Vector.help ${HELP}/VECTOR.help ; \
-	 fi
-	@${TANGLE} -R"Vector.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Vector.input
-	@echo "Vector (VECTOR)" >>${HELPFILE}
-
-${HELP}/VectorCategory.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create VectorCategory.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"VectorCategory.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/VectorCategory.help
-	@cp -f ${HELP}/VectorCategory.help ${HELP}/VECTCAT.help
-	@${TANGLE} -R"VectorCategory.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/VectorCategory.input
-	@echo "VectorCategory (VECTCAT)" >>${HELPFILE}
-
-${HELP}/VectorSpace.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create VectorSpace.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"VectorSpace.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/VectorSpace.help
-	@cp -f ${HELP}/VectorSpace.help ${HELP}/VSPACE.help
-	@${TANGLE} -R"VectorSpace.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/VectorSpace.input
-	@echo "VectorSpace (VSPACE)" >>${HELPFILE}
-
-${HELP}/Void.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8220 create Void.help from ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"Void.help" ${BOOKS}/bookvol10.3.pamphlet \
-            >${HELP}/Void.help
-	@if [ "`basename ${AXIOM}`" != "MACOSX" ] ; then \
-	  cp -f ${HELP}/Void.help ${HELP}/VOID.help ; \
-	 fi
-	@${TANGLE} -R"Void.input" ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/Void.input
-	@echo "Void (VOID)" >>${HELPFILE}
-
-${HELP}/WeightedPolynomials.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create WeightedPolynomials.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"WeightedPolynomials.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/WeightedPolynomials.help
-	@cp -f ${HELP}/WeightedPolynomials.help ${HELP}/WP.help
-	@${TANGLE} -R"WeightedPolynomials.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/WeightedPolynomials.input
-	@echo "WeightedPolynomials (WP)" >>${HELPFILE}
-
-${HELP}/WuWenTsunTriangularSet.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8230 create WuWenTsunTriangularSet.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"WuWenTsunTriangularSet.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/WuWenTsunTriangularSet.help
-	@cp -f ${HELP}/WuWenTsunTriangularSet.help ${HELP}/WUTSET.help
-	@${TANGLE} -R"WuWenTsunTriangularSet.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/WuWenTsunTriangularSet.input
-	@echo "WuWenTsunTriangularSet (WUTSET)" >>${HELPFILE}
-
-${HELP}/XAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create XAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"XAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/XAlgebra.help
-	@cp -f ${HELP}/XAlgebra.help ${HELP}/XALG.help
-	@${TANGLE} -R"XAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/XAlgebra.input
-	@echo "XAlgebra (XALG)" >>${HELPFILE}
-
-${HELP}/XDistributedPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create XDistributedPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"XDistributedPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/XDistributedPolynomial.help
-	@cp -f ${HELP}/XDistributedPolynomial.help ${HELP}/XDPOLY.help
-	@${TANGLE} -R"XDistributedPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/XDistributedPolynomial.input
-	@echo "XDistributedPolynomial (XDPOLY)" >>${HELPFILE}
-
-${HELP}/XFreeAlgebra.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create XFreeAlgebra.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"XFreeAlgebra.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/XFreeAlgebra.help
-	@cp -f ${HELP}/XFreeAlgebra.help ${HELP}/XFALG.help
-	@${TANGLE} -R"XFreeAlgebra.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/XFreeAlgebra.input
-	@echo "XFreeAlgebra (XFALG)" >>${HELPFILE}
-
-${HELP}/XPBWPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8240 create XPBWPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"XPBWPolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/XPBWPolynomial.help
-	@cp -f ${HELP}/XPBWPolynomial.help ${HELP}/XPBWPOLY.help
-	@${TANGLE} -R"XPBWPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/XPBWPolynomial.input
-	@echo "XPBWPolynomial (XPBWPOLY)" >>${HELPFILE}
-
-${HELP}/XPolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8250 create XPolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"XPolynomial.help"  \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/XPolynomial.help
-	@cp -f ${HELP}/XPolynomial.help ${HELP}/XPOLY.help
-	@${TANGLE} -R"XPolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/XPolynomial.input
-	@echo "XPolynomial (XPOLY)" >>${HELPFILE}
-
-${HELP}/XPolynomialRing.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 8260 create XPolynomialRing.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"XPolynomialRing.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/XPolynomialRing.help
-	@cp -f ${HELP}/XPolynomialRing.help ${HELP}/XPR.help
-	@${TANGLE} -R"XPolynomialRing.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/XPolynomialRing.input
-	@echo "XPolynomialRing (XPR)" >>${HELPFILE}
-
-${HELP}/XPolynomialsCat.help: ${BOOKS}/bookvol10.2.pamphlet
-	@echo 5000 create XPolynomialsCat.help from \
-           ${BOOKS}/bookvol10.2.pamphlet
-	@${TANGLE} -R"XPolynomialsCat.help" \
-           ${BOOKS}/bookvol10.2.pamphlet \
-           >${HELP}/XPolynomialsCat.help
-	@cp -f ${HELP}/XPolynomialsCat.help ${HELP}/XPOLYC.help
-	@${TANGLE} -R"XPolynomialsCat.input" \
-            ${BOOKS}/bookvol10.2.pamphlet \
-            >${INPUT}/XPolynomialsCat.input
-	@echo "XPolynomialsCat (XPOLYC)" >>${HELPFILE}
-
-${HELP}/XRecursivePolynomial.help: ${BOOKS}/bookvol10.3.pamphlet
-	@echo 5000 create XRecursivePolynomial.help from \
-           ${BOOKS}/bookvol10.3.pamphlet
-	@${TANGLE} -R"XRecursivePolynomial.help" \
-           ${BOOKS}/bookvol10.3.pamphlet \
-           >${HELP}/XRecursivePolynomial.help
-	@cp -f ${HELP}/XRecursivePolynomial.help ${HELP}/XRPOLY.help
-	@${TANGLE} -R"XRecursivePolynomial.input" \
-            ${BOOKS}/bookvol10.3.pamphlet \
-            >${INPUT}/XRecursivePolynomial.input
-	@echo "XRecursivePolynomial (XRPOLY)" >>${HELPFILE}
-
-${HELP}/ZeroDimensionalSolvePackage.help: ${BOOKS}/bookvol10.4.pamphlet
-	@echo 8270 create ZeroDimensionalSolvePackage.help from \
-           ${BOOKS}/bookvol10.4.pamphlet
-	@${TANGLE} -R"ZeroDimensionalSolvePackage.help" \
-           ${BOOKS}/bookvol10.4.pamphlet \
-           >${HELP}/ZeroDimensionalSolvePackage.help
-	@cp -f ${HELP}/ZeroDimensionalSolvePackage.help ${HELP}/ZDSOLVE.help
-	@${TANGLE} -R"ZeroDimensionalSolvePackage.input" \
-            ${BOOKS}/bookvol10.4.pamphlet \
-            >${INPUT}/ZeroDimensionalSolvePackage.input
-	@echo "ZeroDimensionalSolvePackage (ZDSOLVE)" >>${HELPFILE}
-
-${HELP}/dcabs1.help: ${BOOKS}/bookvol10.5.pamphlet
-	@echo 9000 create dcabs1.help from ${BOOKS}/bookvol10.5.pamphlet
-	@${TANGLE} -R"dcabs1.help" ${BOOKS}/bookvol10.5.pamphlet \
-           >${HELP}/dcabs1.help
-	@${TANGLE} -R"dcabs1.input" ${BOOKS}/bookvol10.5.pamphlet \
-            >${INPUT}/dcabs1.input
-	@echo "dcabs1" >>${HELPFILE}
-
-${HELP}/dasum.help: ${BOOKS}/bookvol10.5.pamphlet
-	@echo 9110 create dasum.help from ${BOOKS}/bookvol10.5.pamphlet
-	@${TANGLE} -R"dasum.help" ${BOOKS}/bookvol10.5.pamphlet \
-           >${HELP}/dasum.help
-	@${TANGLE} -R"dasum.input" ${BOOKS}/bookvol10.5.pamphlet \
-            >${INPUT}/dasum.input
-	@echo "dasum" >>${HELPFILE}
-
-${HELP}/daxpy.help: ${BOOKS}/bookvol10.5.pamphlet
-	@echo 9120 create daxpy.help from ${BOOKS}/bookvol10.5.pamphlet
-	@${TANGLE} -R"daxpy.help" ${BOOKS}/bookvol10.5.pamphlet \
-           >${HELP}/daxpy.help
-	@${TANGLE} -R"daxpy.input" ${BOOKS}/bookvol10.5.pamphlet \
-            >${INPUT}/daxpy.input
-	@echo "daxpy" >>${HELPFILE}
-
-${HELP}/dcopy.help: ${BOOKS}/bookvol10.5.pamphlet
-	@echo 9130 create dcopy.help from ${BOOKS}/bookvol10.5.pamphlet
-	@${TANGLE} -R"dcopy.help" ${BOOKS}/bookvol10.5.pamphlet \
-           >${HELP}/dcopy.help
-	@${TANGLE} -R"dcopy.input" ${BOOKS}/bookvol10.5.pamphlet \
-            >${INPUT}/dcopy.input
-	@echo "dcopy" >>${HELPFILE}
-
-@
-
 \section{The Makefile}
 
 <<*>>=
@@ -27003,21 +17945,16 @@ ${HELP}/dcopy.help: ${BOOKS}/bookvol10.5.pamphlet
 <<layer23>>
 <<order>>
 
-all: fasthelp src ${OUT}/libdb.text ${SPADBIN}/index.html gloss
+all: fasthelp fastinput src ${OUT}/libdb.text ${SPADBIN}/index.html gloss
 	@ echo 4302 finished ${IN}
 
 fasthelp:
 	@echo 5000 making .help files with lisp
-	@ echo '(extracthelp "${BOOKS}/bookvol5.pamphlet" "${HELP}" t)' \
-               | ${LISP}
-	@ echo '(extracthelp "${BOOKS}/bookvol10.2.pamphlet" "${HELP}" t)' \
-               | ${LISP}
-	@ echo '(extracthelp "${BOOKS}/bookvol10.3.pamphlet" "${HELP}" t)' \
-               | ${LISP}
-	@ echo '(extracthelp "${BOOKS}/bookvol10.4.pamphlet" "${HELP}" t)' \
-               | ${LISP}
-	@ echo '(extracthelp "${BOOKS}/bookvol10.5.pamphlet" "${HELP}" t)' \
-               | ${LISP}
+	@ echo "(makeHelpFiles)" | ${LISP}
+
+fastinput:
+	@echo 5000 making .input files with lisp
+	@ echo "(makeInputFiles)" | ${LISP}
 
 <<newcode>>
 
@@ -27048,7 +17985,6 @@ src:	${ORDER}
 	@ echo 4304 Building nrlibS from spad sources
 
 <<genericRules>>
-<<spadhelp>>
 <<ps (DOC from SRC)>>
 <<libdb.text (OUT from IN)>>
 <<stages>>
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index be9418f..13f65cd 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -3248,5 +3248,7 @@ src/axiom-website/documentation.html add literate thinking quote<br/>
 books/bookvol9 treeshake compiler<br/>
 <a href="patches/20101024.03.tpd.patch">20101024.03.tpd.patch</a>
 books/tangle.lisp automate making help files<br/>
+<a href="patches/20101024.04.tpd.patch">20101024.04.tpd.patch</a>
+books/tangle.lisp automate making input files<br/>
  </body>
 </html>
